@@ -23,34 +23,26 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Set(WMLResource):
-    """
-    Set a space_id/project_id to be used in the subsequent actions.
-    """
+    """Set a space_id/project_id to be used in the subsequent actions."""
+
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
     def default_space(self, space_uid):
-        """
-                Set a space ID.
+        """Set a space ID.
 
-                **Parameters**
+        :param space_uid: UID of the space to be used
+        :type space_uid: str
 
-                .. important::
-                   #. **space_uid**:  GUID of the space to be used:\n
+        :return: status ("SUCCESS" if succeeded)
+        :rtype: str
 
-                      **type**: str\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: The space that is set here is used for subsequent requests.\n
-                    **return type**: str("SUCCESS"/"FAILURE")\n
-
-                **Example**
-
-                 >>>  client.set.default_space(space_uid)
+            client.set.default_space(space_uid)
 
         """
         if self._client.WSD:
@@ -92,29 +84,21 @@ class Set(WMLResource):
         else:
             raise CannotSetProjectOrSpace(reason=space_details.text)
 
-
     ##Setting project ID
     def default_project(self, project_id):
-        """
-                Set a project ID.
+        """Set a project ID.
 
-                **Parameters**
+        :param project_id: UID of the project
+        :type project_id: str
 
-                .. important::
-                   #. **project_id**:  GUID of the project\n
+        :return: status ("SUCCESS" if succeeded)
+        :rtype: str
 
-                      **type**: str\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: "SUCCESS"\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>>  client.set.default_project(project_id)
+            client.set.default_project(project_id)
         """
 
         if self._client.ICP and '1.1' == self._client.wml_credentials[u'version'].lower():
