@@ -26,7 +26,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Assets(WMLResource):
-    """Store and manage your data assets."""
+    """Store and manage data assets."""
 
     ConfigurationMetaNames = AssetsMetaNames()
     """MetaNames for Data Assets creation."""
@@ -54,7 +54,7 @@ class Assets(WMLResource):
         return self._get_asset_based_resource(asset_uid, 'data_asset', self._get_required_element_from_response)
 
     def create(self, name, file_path):
-        """Creates a data asset and uploads content to it.
+        """Create a data asset and upload content to it.
 
         :param name:  name to be given to the data asset
         :type name: str
@@ -80,7 +80,7 @@ class Assets(WMLResource):
         return self._create_asset(name, file_path)
 
     def store(self, meta_props):
-        """Creates a data asset and uploads content to it.
+        """Create a data asset and upload content to it.
 
         :param meta_props:  meta data of the space configuration. To see available meta names use:
 
