@@ -27,7 +27,7 @@ _DEFAULT_LIST_LENGTH = 0
 
 
 class Connections(WMLResource):
-    """Store and manage your Connections."""
+    """Store and manage Connections."""
 
     ConfigurationMetaNames = ConnectionMetaNames()
     """MetaNames for Connection creation."""
@@ -115,9 +115,12 @@ class Connections(WMLResource):
                 else:
                     return self._handle_response(200, u'get connection details', response)
         else:
+            params = self._client._params()
+            params['entity.flags'] = 'personal_credentials'
+
             with self.requests_retry_session() as sess:
                 response = sess.get(self._client.service_instance._href_definitions.get_connections_href(),
-                                    params=self._client._params(),
+                                    params=params,
                                     headers=header_param)
 
                 if response.status_code == 200:
@@ -126,7 +129,7 @@ class Connections(WMLResource):
                     return self._handle_response(200, u'get connection details', response)
 
     def create(self, meta_props):
-        """Creates a connection. Input to PROPERTIES field examples
+        """Create a connection. Input to PROPERTIES field examples:
 
         1. MySQL
 
@@ -198,9 +201,10 @@ class Connections(WMLResource):
                     "username": "username"
                 }
 
+        :param meta_props:  metadata of the connection configuration. To see available meta names use:
 
-        :param meta_props:  meta data of the connection configuration. To see available meta names use:
             .. code-block:: python
+
                 client.connections.ConfigurationMetaNames.get()
 
         :type meta_props: dict
@@ -360,8 +364,11 @@ class Connections(WMLResource):
         else:
             header_param = self._client._get_headers()
 
+        params = self._client._params()
+        params['entity.flags'] = 'personal_credentials'
+
         response = requests.get(self._client.service_instance._href_definitions.get_connections_href(),
-                                params=self._client._params(),
+                                params=params,
                                 headers=header_param)
 
         self._handle_response(200, u'list datasource type', response)
