@@ -87,9 +87,9 @@ class Deployments(WMLResource):
         :param artifact_uid:  published artifact UID (model or function uid)
         :type artifact_uid: str
 
-        :param meta_props: metaprops. To see the available list of metanames use:
+        :param meta_props: metaprops, to see the available list of metanames use:
 
-            .. code_block:: python
+            .. code-block:: python
 
                 client.deployments.ConfigurationMetaNames.get()
 
@@ -270,7 +270,7 @@ class Deployments(WMLResource):
 
         **Example**
 
-        .. coed-block:: python
+        .. code-block:: python
 
             deployment_uid = client.deployments.get_uid(deployment)
 
@@ -402,7 +402,7 @@ class Deployments(WMLResource):
         return status_code != 409
 
     def get_details(self, deployment_uid=None, serving_name=None, limit=None, asynchronous=False, get_all=False, _silent=False):
-        """Get information about your deployment(s).
+        """Get information about deployment(s).
         If deployment_uid is not passed, all deployment details are fetched.
 
         :param deployment_uid: Unique Id of Deployment
@@ -1241,7 +1241,7 @@ class Deployments(WMLResource):
                                  retention=retention)
 
     def get_job_details(self, job_uid=None, include=None, limit=None):
-        """Get information about your deployment job(s).
+        """Get information about deployment job(s).
         If deployment job_uid is not passed, all deployment jobs details are fetched.
 
         :param job_uid: Unique Job ID
