@@ -20,10 +20,13 @@ from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.enums import (
     TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, ForecastingAlgorithms, PredictionType, Metrics, \
     Transformers, DataConnectionTypes, PipelineTypes, PositiveLabelClass, ClassificationAlgorithmsCP4D,
-    RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D, SamplingTypes, ImputationStrategy, ForecastingPipelineTypes)
+    RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D, SamplingTypes, ImputationStrategy, ForecastingPipelineTypes,
+    TimeseriesAnomalyPredictionPipelineTypes, TimeseriesAnomalyPredictionAlgorithms)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
     NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario, \
-    TSNotSupported, ParamOutOfRange, ImputationListNotSupported, MissingEstimatorForExistingBatchedEstimator
+    TSNotSupported, TSADNotSupported, ParamOutOfRange, ImputationListNotSupported, \
+    MissingEstimatorForExistingBatchedEstimator, TimeseriesAnomalyPredictionFeatureColumnsMissing, \
+    TimeseriesAnomalyPredictionCannotBeRunAsLocalScenario, TimeseriesAnomalyPredictionUnsupportedMetric
 from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions, \
     validate_additional_params_for_optimizer, validate_optimizer_enum_values, \
     translate_imputation_string_strategy_to_enum, translate_estimator_string_to_enum, \
@@ -42,41 +45,43 @@ __all__ = [
 
 
 class AutoAI(BaseExperiment):
-    """
-    AutoAI class for pipeline models optimization automation.
+    """AutoAI class for pipeline models optimization automation.
 
-    Parameters
-    ----------
-    wml_credentials: dictionary, required
-        Credentials to Watson Machine Learning instance.
+    :param wml_credentials: credentials to Watson Machine Learning instance
+    :type wml_credentials: dict
 
-    project_id: str, optional
-        ID of the Watson Studio project.
+    :param project_id: ID of the Watson Studio project
+    :type project_id: str, optional
 
-    space_id: str, optional
-        ID of the Watson Studio Space.
+    :param space_id: ID of the Watson Studio Space
+    :type space_id: str, optional
 
-    verify: Union[bool, str], optional
-        User can pass verify the path to a CA_BUNDLE file or directory with certificates of trusted CAs.
-        If set to True, default path to truststore will be taken.
-        If set to False, no verification will be made.
+    :param verify: user can pass as verify one of following:
 
-    Example
-    -------
-    >>> from ibm_watson_machine_learning.experiment import AutoAI
-    >>>
-    >>> experiment = AutoAI(
-    >>>        wml_credentials={
-    >>>              "apikey": "...",
-    >>>              "iam_apikey_description": "...",
-    >>>              "iam_apikey_name": "...",
-    >>>              "iam_role_crn": "...",
-    >>>              "iam_serviceid_crn": "...",
-    >>>              "instance_id": "...",
-    >>>              "url": "https://us-south.ml.cloud.ibm.com"
-    >>>            },
-    >>>         project_id="...",
-    >>>         space_id="...")
+        - the path to a CA_BUNDLE file
+        - the path of directory with certificates of trusted CAs
+        - `True` - default path to truststore will be taken
+        - `False` - no verification will be made
+    :type verify: bool or str, optional
+
+    **Example**
+
+    .. code-block:: python
+
+        from ibm_watson_machine_learning.experiment import AutoAI
+
+        experiment = AutoAI(
+            wml_credentials={
+                "apikey": "...",
+                "iam_apikey_description": "...",
+                "iam_apikey_name": "...",
+                "iam_role_crn": "...",
+                "iam_serviceid_crn": "...",
+                "instance_id": "...",
+                "url": "https://us-south.ml.cloud.ibm.com"
+            },
+            project_id="...",
+            space_id="...")
     """
     # note: initialization of AutoAI enums as class properties
 
@@ -127,26 +132,24 @@ class AutoAI(BaseExperiment):
         # --- end note
 
     def runs(self, *, filter: str) -> Union['AutoPipelinesRuns', 'LocalAutoPipelinesRuns']:
-        """
-        Get the historical runs but with WML Pipeline name filter (for remote scenario).
+        """Get the historical runs but with WML Pipeline name filter (for remote scenario).
         Get the historical runs but with experiment name filter (for local scenario).
 
-        Parameters
-        ----------
-        filter: str, required
-            WML Pipeline name to filter the historical runs.
-            or experiment name to filter the local historical runs.
+        :param filter: WML Pipeline name to filter the historical runs or experiment name to filter
+            the local historical runs
+        :type filter: str
 
-        Returns
-        -------
-        AutoPipelinesRuns or LocalAutoPipelinesRuns
+        :return: object managing the list of runs
+        :rtype: AutoPipelinesRuns or LocalAutoPipelinesRuns
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(...)
-        >>>
-        >>> experiment.runs(filter='Test').list()
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+
+            experiment = AutoAI(...)
+            experiment.runs(filter='Test').list()
         """
 
         if self._workspace is None:
@@ -164,13 +167,13 @@ class AutoAI(BaseExperiment):
                   timestamp_column_name: str = None,
                   scoring: 'Metrics' = None,
                   desc: str = None,
-                  test_size: float = None, # deprecated
+                  test_size: float = None,  # deprecated
                   holdout_size: float = 0.1,
                   max_number_of_estimators: int = None,
                   train_sample_rows_test_size: float = None,
                   include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms',
-                                                      'ForecastingAlgorithms']] = None,
-                  daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None, # deprecated
+                                                      'ForecastingAlgorithms', 'TimeseriesAnomalyPredictionAlgorithms']] = None,
+                  daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,  # deprecated
                   #include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms',
                   #                                                'BatchedRegressionAlgorithms']] = None,
                   backtest_num: int = None,
@@ -178,7 +181,7 @@ class AutoAI(BaseExperiment):
                   forecast_window: int = None,
                   backtest_gap_length: int = None,
                   feature_columns: List[str] = None,
-                  pipeline_types: List[ForecastingPipelineTypes] = None,
+                  pipeline_types: List[Union['ForecastingPipelineTypes', 'TimeseriesAnomalyPredictionPipelineTypes']] = None,
                   supporting_features_at_forecast: bool = None,
                   cognito_transform_names: List['Transformers'] = None,
                   data_join_graph: 'DataJoinGraph' = None,
@@ -208,157 +211,161 @@ class AutoAI(BaseExperiment):
                   test_data_csv_separator: Union[List[str], str] = ',',
                   test_data_excel_sheet: str = None,
                   test_data_encoding: str = 'utf-8',
+                  confidence_level: float = 0.95,
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
 
-        Parameters
-        ----------
-        name: str, required
-            Name for the AutoPipelines
+        :param name: name for the AutoPipelines
+        :type name: str
 
-        prediction_type: PredictionType, required
-            Type of the prediction.
+        :param prediction_type: type of the prediction
+        :type prediction_type: PredictionType
 
-        prediction_column: str, required for multiclass, binary and regression prediction types
-            Name of the target/label column
+        :param prediction_column: name of the target/label column, required for `multiclass`, `binary` and `regression`
+            prediction types
+        :type prediction_column: str, optional
 
-        prediction_columns: List[str], required for forecasting prediction type
-            Names of the target/label columns.
+        :param prediction_columns: names of the target/label columns, required for `forecasting` prediction type
+        :type prediction_columns: list[str], optional
 
-        timestamp_column_name: str, optional, used only for forecasting prediction type
-            Name of timestamp column for time series forecasting.
+        :param timestamp_column_name: name of timestamp column for time series forecasting
+        :type timestamp_column_name: str, optional
 
-        scoring: Metrics, optional
-            Type of the metric to optimize with. Not used for forecasting.
+        :param scoring: type of the metric to optimize with, not used for forecasting
+        :type scoring: Metrics, optional
 
-        desc: str, optional
-            Description
+        :param desc: description
+        :type desc: str, optional
 
-        test_size: deprecated
-            Use `holdout_size` instead.
+        :param test_size: deprecated, use `holdout_size` instead
 
-        holdout_size: float, optional
-            Percentage of the entire dataset to leave as a holdout. Default 0.1
+        :param holdout_size: percentage of the entire dataset to leave as a holdout
+        :type holdout_size: float, optional
 
-        max_number_of_estimators: int, optional
-            Maximum number (top-K ranked by DAUB model selection) of the selected algorithm, or estimator types,
-            for example LGBMClassifierEstimator, XGBoostClassifierEstimator, or LogisticRegressionEstimator
-            to use in pipeline composition. The default is None that means the true default value will be determined by
-            the internal different algorithms, where only the highest ranked by model selection algorithm type is used.
+        :param max_number_of_estimators: maximum number (top-K ranked by DAUB model selection)
+            of the selected algorithm, or estimator types, for example `LGBMClassifierEstimator`,
+            `XGBoostClassifierEstimator`, or `LogisticRegressionEstimator` to use in pipeline composition,
+            the default is `None` that means the true default value will be determined by
+            the internal different algorithms, where only the highest ranked by model selection algorithm type is used
+        :type max_number_of_estimators: int, optional
 
-        train_sample_rows_test_size: float, optional
-            Training data sampling percentage
+        :param train_sample_rows_test_size: training data sampling percentage
+        :type train_sample_rows_test_size: float, optional
 
-        daub_include_only_estimators: deprecated
-            Use `include_only_estimators` instead.
+        :param daub_include_only_estimators: deprecated, use `include_only_estimators` instead
 
-        include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms', 'ForecastingAlgorithms']], optional
-            List of estimators to include in computation process.
-            See: AutoAI.ClassificationAlgorithms, AutoAI.RegressionAlgorithms or AutoAI.ForecastingAlgorithms
+        :param include_only_estimators: list of estimators to include in computation process, see:
+            AutoAI.ClassificationAlgorithms, AutoAI.RegressionAlgorithms or AutoAI.ForecastingAlgorithms
+        :type include_only_estimators: List[ClassificationAlgorithms or RegressionAlgorithms or ForecastingAlgorithms]], optional
 
-        backtest_num: int, optional
-            Used for forecasting prediction type. Configure number of backtests. Default value: 4
-            Value from range [0, 20]
+        :param backtest_num: number of backtests used for forecasting prediction type, default value: 4,
+            value from range [0, 20]
+        :type backtest_num: int, optional
 
-        lookback_window: int, optional
-            Used for forecasting prediction type. Configure length of lookback window. Default value: 10
-            If set to -1 lookback window will be auto-detected
+        :param lookback_window: length of lookback window used for forecasting prediction type,
+            default value: 10, if set to -1 lookback window will be auto-detected
+        :type lookback_window: int, optional
 
-        forecast_window: int, optional
-            Used for forecasting prediction type. Configure length of forecast window. Default value: 1
-            Value from range [1, 60]
+        :param forecast_window: length of forecast window used for forecasting prediction type, default value: 1,
+            value from range [1, 60]
+        :type forecast_window: int, optional
 
-        backtest_gap_length: int, optional
-            Used for forecasting prediction type. Configure gap between backtests. Default value: 0
-            Value from range [0, data length / 4]
+        :param backtest_gap_length: gap between backtests used for forecasting prediction type,
+            default value: 0, value from range [0, data length / 4]
+        :type backtest_gap_length: int, optional
 
-        feature_columns: List[str], optional
-            List of feature columns used for forecasting prediction type. May contain target column and/or supporting feature columns.
+        :param feature_columns: list of feature columns used for forecasting prediction type,
+            may contain target column and/or supporting feature columns, list of columns to be detected whether there are anomalies for timeseries anomaly prediction type
+        :type feature_columns: list[str], optional
 
-        pipeline_types: List[ForecastingPipelineTypes], optional
-            List of pipeline types to be used for forecasting prediction type.
+        :param pipeline_types: list of pipeline types to be used for forecasting or timeseries anomaly prediction type
+        :type pipeline_types: list[ForecastingPipelineTypes or TimeseriesAnomalyPredictionPipelineTypes], optional
 
-        supporting_features_at_forecast: bool, optional
-            Enables usage of future supporting feature values during forecast.
+        :param supporting_features_at_forecast: enables usage of future supporting feature values during forecast
+        :type supporting_features_at_forecast: bool, optional
 
-        cognito_transform_names: List['Transformers'], optional
-            List of transformers to include in the feature enginnering computation process.
-            See: AutoAI.Transformers
+        :param cognito_transform_names: list of transformers to include in the feature enginnering computation process,
+            see: AutoAI.Transformers
+        :type cognito_transform_names: list[Transformers], optional
 
-        csv_separator: Union[List[str], str], optional
-            The separator, or list of separators to try for separating
-            columns in a CSV file.  Not used if the file_name is not a CSV file.
-            Default is ','.
+        :param csv_separator: the separator, or list of separators to try for separating columns in a CSV file,
+            not used if the file_name is not a CSV file, default is ','
+        :type csv_separator: list[str] or str, optional
 
-        excel_sheet: Union[str, int], optional
-            Name of the excel sheet to use. Only use when xlsx file is an input. Support for number of the sheet is deprecated.
-            By default first sheet is used.
+        :param excel_sheet: name of the excel sheet to use, only applicable when xlsx file is an input,
+            support for number of the sheet is deprecated, by default first sheet is used
+        :type excel_sheet: str, optional
 
-        encoding: str, optional
-            Encoding type for CSV training file.
+        :param encoding: encoding type for CSV training file
+        :type encoding: str, optional
 
-        positive_label: str, optional
-            The positive class to report when binary classification.
-            When multiclass or regression, this will be ignored.
+        :param positive_label: the positive class to report when binary classification, when multiclass or regression,
+            this will be ignored
+        :type positive_label: str, optional
 
-        t_shirt_size: TShirtSize, optional
-            The size of the remote AutoAI POD instance (computing resources). Only applicable to a remote scenario.
-            See: AutoAI.TShirtSize
+        :param t_shirt_size: the size of the remote AutoAI POD instance (computing resources),
+            only applicable to a remote scenario, see: AutoAI.TShirtSize
+        :type t_shirt_size: TShirtSize, optional
 
-        data_join_graph: DataJoinGraph, optional
-            A graph object with definition of join structure for multiple input data sources.
-            Data preprocess step for multiple files.
+        :param data_join_graph: a graph object with definition of join structure for multiple input data sources,
+            data preprocess step for multiple files
+        :type data_join_graph: DataJoinGraph, optional
 
-        data_join_only: bool, optional
-            If True only preprocessing will be executed.
+        :param data_join_only: if `True` only preprocessing will be executed
+        :type data_join_only: bool, optional
 
-        drop_duplicates: bool, optional
-            If True duplicated rows in data will be removed before further processing. Default is True.
+        :param drop_duplicates: if `True` duplicated rows in data will be removed before further processing
+        :type drop_duplicates: bool, optional
 
-        text_processing: bool, optional
-            If True text processing will be enabled. Default is True. Applicable only on Cloud.
+        :param text_processing: if `True` text processing will be enabled, applicable only on Cloud
+        :type text_processing: bool, optional
 
-        word2vec_feature_number: int, optional
-            Number of features which will be generated from text column. Will be applied only if `text_processing`
-            is True. If `None` the default value will be taken.
+        :param word2vec_feature_number: number of features which will be generated from text column,
+            will be applied only if `text_processing` is `True`, if `None` the default value will be taken
+        :type word2vec_feature_number: int, optional
 
-        daub_give_priority_to_runtime: float, optional
-            The importance of run time over score for pipelines ranking. Can take values between 0 and 5.
-            If set to 0.0 only score is used. If set to 1 equally score and runtime are used.
-            If set to value higher than 1 the runtime gets higher importance over score.
+        :param daub_give_priority_to_runtime: the importance of run time over score for pipelines ranking,
+            can take values between 0 and 5, if set to 0.0 only score is used,
+            if set to 1 equally score and runtime are used, if set to value higher than 1
+            the runtime gets higher importance over score
+        :type daub_give_priority_to_runtime: float, optional
 
-        fairness_info: dict, optional
-            Dictionary that  specifies metadata needed for measuring fairness. It contains three key values:
-            favorable_labels, unfavorable_labels and protected_attributes. The favorable_labels attribute indicates that
-            when the class column contains one of the value from list, that is considered a positive outcome.
-            The unfavorable_labels is oposite to the favorable_labels and is obigatory for regression learning type.
-            A protected attribute is a list of features that partition the population into groups whose outcome should
-            have parity, if protected attribute is empty list then automatic detection of protected attributes will be run.
-            If passed fairness metric will be calculated.
+        :param fairness_info: dictionary that specifies metadata needed for measuring fairness,
+            it contains three key values: `favorable_labels`, `unfavorable_labels` and `protected_attributes`,
+            the `favorable_labels` attribute indicates that when the class column contains one of the value from list,
+            that is considered a positive outcome, the `unfavorable_labels` is oposite to the `favorable_labels`
+            and is obligatory for regression learning type, a protected attribute is a list of features that partition
+            the population into groups whose outcome should have parity, if protected attribute is empty list
+            then automatic detection of protected attributes will be run,
+            if `fairness_info` is passed then fairness metric will be calculated
+        :type fairness_info: fairness_info
 
-        n_parallel_data_connections: int, optional
-            Number of maximum parallel connection to data source.
-            Supported only for IBM Cloud Pak® for Data 4.0.1 and above.
+        :param n_parallel_data_connections: number of maximum parallel connection to data source,
+            supported only for IBM Cloud Pak® for Data 4.0.1 and above
+        :type n_parallel_data_connections: int, optional
 
-        categorical_imputation_strategy: ImputationStrategy, optional
-            Missing values imputation strategy for categorical columns.
+        :param categorical_imputation_strategy: missing values imputation strategy for categorical columns
 
             Possible values (only non-forecasting scenario):
+
             - ImputationStrategy.MEAN
             - ImputationStrategy.MEDIAN
             - ImputationStrategy.MOST_FREQUENT (default)
 
+        :type categorical_imputation_strategy: ImputationStrategy, optional
 
-        numerical_imputation_strategy: ImputationStrategy, optional
-            Missing values imputation strategy for numerical columns.
+
+        :param numerical_imputation_strategy: missing values imputation strategy for numerical columns
 
             Possible values (non-forecasting scenario):
+
             - ImputationStrategy.MEAN
             - ImputationStrategy.MEDIAN (default)
             - ImputationStrategy.MOST_FREQUENT
 
             Possible values (forecasting scenario):
+
             - ImputationStrategy.MEAN
             - ImputationStrategy.MEDIAN
             - ImputationStrategy.BEST_OF_DEFAULT_IMPUTERS (default)
@@ -370,7 +377,6 @@ class AutoAI(BaseExperiment):
             - ImputationStrategy.NEXT
             - ImputationStrategy.NO_IMPUTATION
 
-
         numerical_imputation_value: float, optional
             Value for filling missing values if numerical_imputation_strategy is set to ImputationStrategy.VALUE.
             For forecasting only.
@@ -420,6 +426,10 @@ class AutoAI(BaseExperiment):
         test_data_encoding: str, optional
             Encoding type for CSV user-defined holdout/test file.
 
+        confidence_level: float, optional for timeseries anomaly prediction
+            When the pipeline "PointwiseBoundedHoltWinters" or "PointwiseBoundedBATS" is used, the prediction interval
+            is calculated at a given confidence_level to decide if a data record is an anomaly or not.
+
 
         Returns
         -------
@@ -503,6 +513,10 @@ class AutoAI(BaseExperiment):
                         self._workspace.wml_client.wml_credentials['version'].startswith('3.5')):
             raise TSNotSupported()
 
+        if prediction_type == PredictionType.TIMESERIES_ANOMALY_PREDICTION and self._workspace.wml_client.ICP and \
+                self._workspace.wml_client.wml_credentials['version'].startswith(('2.5', '3.0', '3.5', '4.0', '4.5', '4.6')):
+            raise TSADNotSupported()
+
         if prediction_type in (PredictionType.FORECASTING, 'timeseries'):
             if not numerical_imputation_strategy and type(numerical_imputation_strategy) is not list:
                 numerical_imputation_strategy = ImputationStrategy.BEST_OF_DEFAULT_IMPUTERS
@@ -511,6 +525,13 @@ class AutoAI(BaseExperiment):
 
             if prediction_column is not None or prediction_columns is None:
                 raise ForecastPredictionColumnsMissing()
+        elif prediction_type == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+            if feature_columns is None or prediction_column is not None or prediction_columns is not None:
+                raise TimeseriesAnomalyPredictionFeatureColumnsMissing()
+            if scoring is not None and scoring not in (
+                    Metrics.F1_SCORE, Metrics.ACCURACY_SCORE, Metrics.BALANCED_ACCURACY, Metrics.PRECISION_SCORE,
+                    Metrics.RECALL_SCORE):
+                raise TimeseriesAnomalyPredictionUnsupportedMetric(scoring)
         else:
             if prediction_column is None or prediction_columns is not None:
                 raise NonForecastPredictionColumnMissing(prediction_type)
@@ -544,7 +565,6 @@ class AutoAI(BaseExperiment):
                 print('Parameter `train_sample_rows_test_size` will be ignored.')
                 train_sample_rows_test_size = None
 
-
         def translate_str_imputation_param(x):
             if type(x) is list and prediction_type != PredictionType.FORECASTING:
                 raise ImputationListNotSupported()
@@ -561,7 +581,10 @@ class AutoAI(BaseExperiment):
             return [translate_batched_estimator_string_to_enum(estimator) for estimator in x]
 
         def translate_str_pipeline_types_param(x):
-            return [ForecastingPipelineTypes(pipeline_type) for pipeline_type in x]
+            if prediction_type == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+                return [TimeseriesAnomalyPredictionPipelineTypes(pipeline_type) for pipeline_type in x]
+            else:
+                return [ForecastingPipelineTypes(pipeline_type) for pipeline_type in x]
 
         categorical_imputation_strategy = translate_str_imputation_param(categorical_imputation_strategy)
         numerical_imputation_strategy = translate_str_imputation_param(numerical_imputation_strategy)
@@ -610,6 +633,8 @@ class AutoAI(BaseExperiment):
         elif self._workspace is None:
             if prediction_type == PredictionType.FORECASTING:
                 raise ForecastingCannotBeRunAsLocalScenario()
+            if prediction_type == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+                raise TimeseriesAnomalyPredictionCannotBeRunAsLocalScenario()
 
             reduced_kwargs = copy.copy(kwargs)
 
@@ -705,6 +730,7 @@ class AutoAI(BaseExperiment):
                 test_data_csv_separator=test_data_csv_separator,
                 test_data_excel_sheet=test_data_excel_sheet,
                 test_data_encoding=test_data_encoding,
+                confidence_level=confidence_level,
                 **reduced_kwargs
             )
             optimizer._workspace = self._workspace
@@ -721,8 +747,7 @@ class AutoAI(BaseExperiment):
             self.ForecastingAlgorithms = ForecastingAlgorithms
 
     def _block_autoai_on_git_based_project(self):
-        """
-        Raises ForbiddenActionForGitBasedProject error for AutoAI experiments on git based project.
+        """Raises ForbiddenActionForGitBasedProject error for AutoAI experiments on git based project.
         It can be disabled by setting environment variable ENABLE_AUTOAI to 'true'
         """
         from os import environ
