@@ -26,9 +26,7 @@ __all__ = [
 
 
 class BaseEngine(ABC):
-    """
-    Base abstract class for Engines.
-    """
+    """Base abstract class for Engines."""
 
     @abstractmethod
     def get_params(self) -> dict:
