@@ -51,13 +51,10 @@ logging.getLogger('lomond').setLevel(logging.CRITICAL)
 
 
 class WMLEngine(BaseEngine):
-    """
-    WML Engine provides unified API to work with AutoAI Pipelines trainings on WML.
+    """WML Engine provides unified API to work with AutoAI Pipelines trainings on WML.
 
-    Parameters
-    ----------
-    workspace: WorkSpace, required
-        WorkSpace object with wml client and all needed parameters.
+    :param workspace: WorkSpace object with wml client and all needed parameters
+    :type workspace: WorkSpace
     """
 
     def __init__(self, workspace: 'WorkSpace') -> None:
@@ -70,10 +67,33 @@ class WMLEngine(BaseEngine):
         self._current_run_id = None
         self._20_class_limit_removal_test = False
 
+    def _get_node_id(self):
+        result = 'automl'
+        if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING:
+            result = 'autoai-ts'
+        elif self._auto_pipelines_parameters.get('prediction_type') == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+            result = 'autoai-tsad'
+        return result
+
+    def _get_learning_type(self):
+        result = self._auto_pipelines_parameters.get('prediction_type')
+        if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING:
+            result = 'timeseries'
+        elif self._auto_pipelines_parameters.get('prediction_type') == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+            result = 'timeseries_anomaly_prediction'
+        return result
+
+    def _get_runtime_name(self):
+        result = 'auto_ai.kb'
+        if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING:
+            result = 'auto_ai.ts'
+        elif self._auto_pipelines_parameters.get('prediction_type') == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+            result = 'auto_ai.tsad'
+        return result
+
     def _initialize_wml_pipeline_metadata(self, **kwargs) -> None:
-        """
-        Initialization of WML Pipeline Document (WML client Meta Parameter) with provided parameters and default ones.
-        """
+        """Initialization of WML Pipeline Document (WML client Meta Parameter)
+            with provided parameters and default ones."""
 
         self._wml_pipeline_metadata = {
             self._wml_client.pipelines.ConfigurationMetaNames.NAME:
@@ -87,7 +107,7 @@ class WMLEngine(BaseEngine):
                     'id': 'autoai',
                     'runtime_ref': 'hybrid',
                     'nodes': [{
-                        'id': 'autoai-ts' if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING else 'automl',
+                        'id': self._get_node_id(),
                         'type': 'execution_node',
                         'parameters': {
                             'stage_flag': True,
@@ -96,7 +116,7 @@ class WMLEngine(BaseEngine):
                             'encoding': self._auto_pipelines_parameters.get('encoding'),
                             'drop_duplicates': self._auto_pipelines_parameters.get('drop_duplicates'),
                             'optimization': {
-                                'learning_type': 'timeseries' if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.FORECASTING else self._auto_pipelines_parameters.get('prediction_type'),
+                                'learning_type': self._get_learning_type(),
                                 'cognito_transform_names':
                                     self._auto_pipelines_parameters.get('cognito_transform_names'),
                                 'run_cognito_flag': True,
@@ -109,7 +129,7 @@ class WMLEngine(BaseEngine):
                 }],
                 'runtimes': [{
                     'id': 'autoai',
-                    'name': 'auto_ai.kb' if self._auto_pipelines_parameters.get('prediction_type') != PredictionType.FORECASTING else 'auto_ai.ts',
+                    'name': self._get_runtime_name(),
                     'app_data': {
                         'wml_data': {
                             'hardware_spec': {}
@@ -137,7 +157,8 @@ class WMLEngine(BaseEngine):
 
         # New parameters for autoai-core which are not supported in CP4D 3.0 and CPD 3.5
         if not self._wml_client.ICP_30 and not self._wml_client.ICP_35 and \
-                self._auto_pipelines_parameters.get('prediction_type') != PredictionType.FORECASTING:
+                self._auto_pipelines_parameters.get('prediction_type') != PredictionType.FORECASTING and \
+                self._auto_pipelines_parameters.get('prediction_type') != PredictionType.TIMESERIES_ANOMALY_PREDICTION:
             # Text transformer params
             if self._auto_pipelines_parameters.get('text_processing') is not None:
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
@@ -270,6 +291,41 @@ class WMLEngine(BaseEngine):
                 self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                     'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                     'retrain_on_holdout'] = self._auto_pipelines_parameters.get('retrain_on_holdout')
+        elif self._auto_pipelines_parameters.get('prediction_type') == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'feature_columns'] = self._auto_pipelines_parameters['feature_columns']
+            if self._auto_pipelines_parameters['timestamp_column_name'] is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'timestamp_column'] = self._auto_pipelines_parameters['timestamp_column_name']
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'max_num_pipelines'] = self._auto_pipelines_parameters.get('max_num_daub_ensembles')
+            if self._auto_pipelines_parameters['pipeline_types']:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'pipelines'] = [pipeline.value for pipeline in self._auto_pipelines_parameters['pipeline_types']]
+            if self._auto_pipelines_parameters['scoring']:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'evaluation_metric'] = self._auto_pipelines_parameters['scoring']
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                'confidence_level'] = self._auto_pipelines_parameters.get('confidence_level', 0.95)
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters'][
+                'compute_pipeline_notebooks_flag'] = self._auto_pipelines_parameters.get('notebooks', False)
+            if self._auto_pipelines_parameters.get('retrain_on_holdout') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'retrain_on_holdout'] = self._auto_pipelines_parameters.get('retrain_on_holdout')
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'].pop('max_num_daub_ensembles', None)
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'].pop('cognito_transform_names', None)
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'].pop('run_cognito_flag', None)
         else:
             self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                 'pipelines'][0]['nodes'][0]['parameters']['optimization'][
@@ -414,6 +470,10 @@ class WMLEngine(BaseEngine):
                     self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
                         'pipelines'][0]['nodes'][0]['parameters']['optimization']['imputation_threshold'] = \
                         self._auto_pipelines_parameters.get('imputation_threshold')
+        elif self._auto_pipelines_parameters.get('prediction_type') == PredictionType.TIMESERIES_ANOMALY_PREDICTION:
+            # To be changed
+            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                'pipelines'][0]['nodes'][0]['parameters']['optimization'].pop('daub_adaptive_subsampling_max_mem_usage', None)
         else:
             if self._auto_pipelines_parameters.get('numerical_imputation_value') is not None or self._auto_pipelines_parameters.get('imputation_threshold'):
                 raise InvalidImputationParameterNonTS()
@@ -521,22 +581,20 @@ class WMLEngine(BaseEngine):
                                           training_results_reference: 'DataConnection',
                                           test_data_references: List['DataConnection'] = None,
                                           test_output_data: 'DataConnection' = None) -> None:
-        """
-        Initialization of wml training metadata (WML client Meta Parameter).
+        """Initialization of wml training metadata (WML client Meta Parameter).
 
-        Parameters
-        ----------
-        training_data_reference: List[DataConnection], required
-            Data storage connection details to inform where training data is stored.
+        :param training_data_reference: data storage connection details to inform where training data is stored
+        :type training_data_reference: list[DataConnection]
 
-        training_results_reference: DataConnection, required
-            Data storage connection details to store pipeline training results.
+        :param training_results_reference: data storage connection details to store pipeline training results
+        :type training_results_reference: DataConnection
 
-        test_data_references: List[DataConnection], optional
-            Data storage connection details to inform where test / holdout data is stored.
+        :param test_data_references: data storage connection details to inform where test / holdout data is stored
+        :type test_data_references: list[DataConnection], optional
 
-        test_output_data: DataConnection, optional
-            Data storage connection details to inform where joined test / holdout data is stored (joined data only).
+        :param test_output_data: data storage connection details to inform where joined test / holdout data is stored
+            (joined data only)
+        :type test_output_data: DataConnection, optional
         """
         self._wml_training_metadata = {
             self._wml_client.training.ConfigurationMetaNames.TAGS:
@@ -587,13 +645,10 @@ class WMLEngine(BaseEngine):
     #   WML Pipeline Part / AutoPipelineOptimizer Init Part  #
     ##########################################################
     def initiate_remote_resources(self, params: dict, **kwargs) -> None:
-        """
-        Initializes the AutoPipelines with supplied parameters.
+        """Initializes the AutoPipelines with supplied parameters.
 
-        Parameters
-        ----------
-        params: dict, required
-            AutoAi experiment parameters.
+        :param params: AutoAi experiment parameters
+        :type params: dict
         """
         self._auto_pipelines_parameters = params
         self._initialize_wml_pipeline_metadata(**kwargs)
@@ -606,12 +661,10 @@ class WMLEngine(BaseEngine):
         self._wml_stored_pipeline_details = self._wml_client.pipelines.store(meta_props=self._wml_pipeline_metadata, **kwargs)
 
     def get_params(self) -> dict:
-        """
-        Get configuration parameters of AutoPipelineOptimizer.
+        """Get configuration parameters of AutoPipelineOptimizer.
 
-        Returns
-        -------
-        Dictionary with AutoPipelineOptimizer parameters.
+        :return: AutoPipelineOptimizer parameters
+        :rtype: dict
         """
         if self._auto_pipelines_parameters is not None:
             self._auto_pipelines_parameters['run_id'] = self._current_run_id
@@ -627,29 +680,25 @@ class WMLEngine(BaseEngine):
             background_mode: bool = True,
             test_data_references: List['DataConnection'] = None,
             test_output_data: 'DataConnection' = None) -> dict:
-        """
-        Run a training process on WML of autoai on top of the training data referenced by training_data_connection.
+        """Run a training process on WML of autoai on top of the training data referenced by training_data_connection.
 
-        Parameters
-        ----------
-        training_data_reference: List[DataConnection], required
-            Data storage connection details to inform where training data is stored.
+        :param training_data_reference: data storage connection details to inform where training data is stored
+        :type training_data_reference: list[DataConnection]
 
-        training_results_reference: DataConnection, required
-            Data storage connection details to store pipeline training results.
+        :param training_results_reference: data storage connection details to store pipeline training results
+        :type training_results_reference: DataConnection
 
-        background_mode: bool, optional
-            Indicator if fit() method will run in background (async) or (sync).
+        :param background_mode: indicator if fit() method will run in background (async) or (sync)
+        :type background_mode: bool, optional
 
-        test_data_references: List[DataConnection], optional
-            Data storage connection details to inform where test / holdout data is stored.
+        :param test_data_references: data storage connection details to inform where test / holdout data is stored
+        :type test_data_references: list[DataConnection], optional
 
-        test_output_data: DataConnection, optional
-            Data storage connection details to store test data output (joined data only).
+        :param test_output_data: data storage connection details to store test data output (joined data only)
+        :type test_output_data: DataConnection, optional
 
-        Returns
-        -------
-        Dictionary with run details.
+        :return: run details
+        :rtype: dict
         """
         self._initialize_wml_training_metadata(training_data_reference=training_data_reference,
                                                training_results_reference=training_results_reference,
@@ -769,12 +818,10 @@ class WMLEngine(BaseEngine):
             return self._wml_client.training.get_details(training_uid=self._current_run_id, _internal=True)
 
     def get_run_status(self) -> str:
-        """
-        Check status/state of initialized AutoPipelineOptimizer run if ran in background mode
+        """Check status/state of initialized AutoPipelineOptimizer run if ran in background mode.
 
-        Returns
-        -------
-        Dictionary with run status details.
+        :return: run status
+        :rtype: str
         """
 
         if self._current_run_id is None:
@@ -783,17 +830,13 @@ class WMLEngine(BaseEngine):
         return self._wml_client.training.get_status(training_uid=self._current_run_id).get('state')
 
     def get_run_details(self, include_metrics: bool = False) -> dict:
-        """
-        Get fit/run details.
+        """Get fit/run details.
 
-        Parameters
-        ----------
-        include_metrics: bool, optional
-            Indicates to include metrics in the training details output. Default False.
+        :param include_metrics: indicates to include metrics in the training details output
+        :type include_metrics: bool, optional
 
-        Returns
-        -------
-        Dictionary with AutoPipelineOptimizer fit/run details.
+        :return: AutoPipelineOptimizer fit/run details
+        :rtype: dict
         """
 
         if self._current_run_id is None:
@@ -821,12 +864,10 @@ class WMLEngine(BaseEngine):
     #   WML Auto_AI Trained Pipelines Part / AutoPipelineOptimizer Pipelines Part   #
     #################################################################################
     def summary(self) -> 'DataFrame':
-        """
-        Prints AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
+        """Prints AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
 
-        Returns
-        -------
-        Pandas DataFrame with computed pipelines and ML metrics.
+        :return: DataFrame with computed pipelines and ML metrics
+        :rtype: pandas.DataFrame
         """
         if self._current_run_id is None:
             raise FitNeeded(reason="To list computed pipelines, first schedule a fit job by using the fit() method.")
@@ -835,17 +876,13 @@ class WMLEngine(BaseEngine):
         return create_summary(details=details, scoring=self._auto_pipelines_parameters['scoring'])
 
     def get_pipeline_details(self, pipeline_name: str = None) -> dict:
-        """
-        Fetch specific pipeline details, eg. steps etc.
+        """Fetch specific pipeline details, eg. steps etc.
 
-        Parameters
-        ----------
-        pipeline_name: str, optional
-            Pipeline name eg. Pipeline_1, if not specified, best pipeline parameters will be fetched
+        :param pipeline_name: pipeline name eg. Pipeline_1, if not specified, best pipeline parameters will be fetched
+        :type pipeline_name: str, optional
 
-        Returns
-        -------
-        Dictionary with pipeline parameters.
+        :return: pipeline parameters
+        :rtype: dict
         """
 
         if self._current_run_id is None:
@@ -902,7 +939,8 @@ class WMLEngine(BaseEngine):
                 elif self._auto_pipelines_parameters['prediction_type'] == 'regression':
                     pipeline_parameters['features_importance'] = self._get_features_importance(pipeline)
 
-                elif self._auto_pipelines_parameters['prediction_type'] == 'forecasting':
+                elif (self._auto_pipelines_parameters['prediction_type'] == 'forecasting' or
+                      self._auto_pipelines_parameters['prediction_type'] == PredictionType.TIMESERIES_ANOMALY_PREDICTION):
                     phases_to_combine_visualization = ['after_backtest_execution', 'after_holdout_execution']
                     for pipeline in run_params['entity']['status'].get('metrics', [])[::-1]:
                         pipeline_phase = pipeline['context'].get('phase')
@@ -937,14 +975,17 @@ class WMLEngine(BaseEngine):
         """Retrieve evaluation metrics data from particular pipeline details."""
         is_ml_metrics = 'ml_metrics' in pipeline_details
         is_ts_metrics = 'ts_metrics' in pipeline_details
+        is_tsad_metrics = 'tsad_metrics' in pipeline_details
 
-        if not is_ml_metrics and not is_ts_metrics:
+        if not is_ml_metrics and not is_ts_metrics and not is_tsad_metrics:
             raise NoAvailableMetrics()
 
         if is_ml_metrics:
             data = pipeline_details['ml_metrics']
         elif is_ts_metrics:
             data = pipeline_details['ts_metrics']
+        elif is_tsad_metrics:
+            data = pipeline_details['tsad_metrics']
 
         columns = [field for field in data.keys()]
         values = [[value for value in data.values()]]
@@ -1049,23 +1090,19 @@ class WMLEngine(BaseEngine):
 
     def get_pipeline(self, pipeline_name: str, local_path: str = '.',
                      persist: 'bool' = False) -> Tuple['Pipeline', bool]:
-        """
-        Download specified pipeline from WML.
+        """Download specified pipeline from WML.
 
-        Parameters
-        ----------
-        pipeline_name: str, required
-            Pipeline name, if you want to see the pipelines names, please use summary() method.
+        :param pipeline_name: pipeline name, if you want to see the pipelines names, please use summary() method
+        :type pipeline_name: str
 
-        local_path: str, optional
-            Local filesystem path, if not specified, current directory is used.
+        :param local_path: local filesystem path, if not specified, current directory is used
+        :type local_path: str, optional
 
-        persist: bool, optional
-            Indicates if selected pipeline should be stored locally.
+        :param persist: indicates if selected pipeline should be stored locally
+        :type persist: bool, optional
 
-        Returns
-        -------
-        Scikit-Learn pipeline.
+        :return: Scikit-Learn pipeline and lale check result
+        :rtype: tuple[Pipeline, bool]
         """
 
         # note: Show warning if OBM
@@ -1109,23 +1146,19 @@ class WMLEngine(BaseEngine):
         return pipelines.get(pipeline_name), check_lale
 
     def get_pipeline_notebook(self, pipeline_name: str, local_path: str = '.', filename: str = None) -> str:
-        """
-        Download specified pipeline notebook from WML.
+        """Download specified pipeline notebook from WML.
 
-        Parameters
-        ----------
-        pipeline_name: str, required
-            Pipeline name, if you want to see the pipelines names, please use summary() method.
+        :param pipeline_name: pipeline name, if you want to see the pipelines names, please use summary() method
+        :type pipeline_name: str
 
-        local_path: str, optional
-            Working directory path.
+        :param local_path: working directory path
+        :type local_path: str, optional
 
-        filename: str, optional
-            Filename under which the pipeline notebook will be saved.
+        :param filename: filename under which the pipeline notebook will be saved
+        :type filename: str, optional
 
-        Returns
-        -------
-        Path to saved pipeline notebook.
+        :return: path to saved pipeline notebook
+        :rtype: str
         """
 
         # note: Show warning if OBM
@@ -1151,20 +1184,16 @@ class WMLEngine(BaseEngine):
         )
 
     def get_best_pipeline(self, local_path: str = '.', persist: 'bool' = False) -> Tuple['Pipeline', bool]:
-        """
-        Download best pipeline from WML.
+        """Download best pipeline from WML.
 
-        Parameters
-        ----------
-        local_path: str, optional
-            Local filesystem path, if not specified, current directory is used.
+        :param local_path: local filesystem path, if not specified, current directory is used
+        :type local_path: str, optional
 
-        persist: bool, optional
-            Indicates if selected pipeline should be stored locally.
+        :param persist: indicates if selected pipeline should be stored locally
+        :type persist: bool, optional
 
-        Returns
-        -------
-        Scikit-Learn pipeline.
+        :return: Scikit-Learn pipeline and lale check result
+        :rtype: tuple[Pipeline, bool]
         """
         best_pipeline_name = self.summary().index[0]
         return self.get_pipeline(best_pipeline_name)
