@@ -27,9 +27,7 @@ __all__ = [
 
 
 class BaseAutoPipelines:
-    """
-    Base abstract class for Pipeline Optimizers.
-    """
+    """Base abstract class for Pipeline Optimizers."""
 
     @abstractmethod
     def get_params(self) -> dict:
