@@ -50,53 +50,51 @@ DATE_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 
 
 class LocalAutoPipelines(BaseAutoPipelines):
-    """
-    LocalAutoPipelines class for pipeline operation automation.
+    """LocalAutoPipelines class for pipeline operation automation.
 
-    Parameters
-    ----------
-    name: str, required
-        Name for the AutoPipelines
+    :param name: name for the AutoPipelines
+    :type name: str
 
-    prediction_type: PredictionType, required
-        Type of the prediction.
+    :param prediction_type: type of the prediction
+    :type prediction_type: PredictionType
 
-    prediction_column: str, required
-        name of the target/label column
+    :param prediction_column: name of the target/label column
+    :type prediction_column: str
 
-    scoring: Metrics, required
-        Type of the metric to optimize with.
+    :param scoring: type of the metric to optimize with
+    :type scoring: Metrics
 
-    desc: str, optional
-        Description
+    :param desc: description
+    :type desc: str, optional
 
-    holdout_size: float, optional
-        Percentage of the entire dataset to leave as a holdout. Default 0.1
+    :param holdout_size: percentage of the entire dataset to leave as a holdout
+    :type holdout_size: float, optional
 
-    max_num_daub_ensembles: int, optional
-        Maximum number (top-K ranked by DAUB model selection) of the selected algorithm, or estimator types,
-        for example LGBMClassifierEstimator, XGBoostClassifierEstimator, or LogisticRegressionEstimator
-        to use in pipeline composition. The default is None that means the true default value will be determined by the
-        internal different algorithms, where only the highest ranked by model selection algorithm type is used.
+    :param max_num_daub_ensembles: maximum number (top-K ranked by DAUB model selection) of the selected algorithm,
+        or estimator types, for example `LGBMClassifierEstimator`, `XGBoostClassifierEstimator`,
+        or `LogisticRegressionEstimator` to use in pipeline composition, the default is None that means
+        the true default value will be determined by the internal different algorithms,
+        where only the highest ranked by model selection algorithm type is used
+    :type max_num_daub_ensembles: int, optional
 
-    train_sample_rows_test_size: float, optional
-        Training data sampling percentage
+    :param train_sample_rows_test_size: training data sampling percentage
+    :type train_sample_rows_test_size: float, optional
 
-    include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
-        List of estimators to include in computation process.
+    :param include_only_estimators: list of estimators to include in computation process
+    :type include_only_estimators: list[ClassificationAlgorithms or RegressionAlgorithms], optional
 
-    cognito_transform_names: List['Transformers'], optional
-        List of transformers to include in the feature enginnering computation process.
-        See: AutoAI.Transformers
+    :param cognito_transform_names: list of transformers to include in the feature enginnering computation process,
+        see: AutoAI.Transformers
+    :type cognito_transform_names: list[Transformers], optional
 
-    _data_clients: List[Union['client', 'resource']], optional
-        Internal argument to auto-gen notebooks.
+    :param _data_clients: internal argument to auto-gen notebooks
+    :type _data_clients: list[client or resource], optional
 
-    _result_client: Union['client', 'resource'], optional
-        Internal argument to auto-gen notebooks.
+    :param _result_client: internal argument to auto-gen notebooks
+    :type _result_client: client or resource, optional
 
-    _force_local_scenario: bool, optional
-        Internal argument to force local scenario enablement.
+    :param _force_local_scenario: internal argument to force local scenario enablement
+    :type _force_local_scenario: bool, optional
     """
 
     def __init__(self,
@@ -181,36 +179,38 @@ class LocalAutoPipelines(BaseAutoPipelines):
             }
 
     def get_params(self) -> dict:
-        """
-        Get configuration parameters of AutoPipelines.
+        """Get configuration parameters of AutoPipelines.
 
-        Returns
-        -------
-        Dictionary with AutoPipelines parameters.
+        :return: AutoPipelines parameters
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI()
-        >>> local_optimizer = experiment.optimizer()
-        >>>
-        >>> local_optimizer.get_params()
-            {
-                'name': 'test name',
-                'desc': 'test description',
-                'prediction_type': 'classification',
-                'prediction_column': 'y',
-                'scoring': 'roc_auc',
-                'holdout_size': 0.1,
-                'max_num_daub_ensembles': 1,
-                'train_sample_rows_test_size': 0.8,
-                'include_only_estimators': ["ExtraTreesClassifierEstimator",
-                                                "GradientBoostingClassifierEstimator",
-                                                "LGBMClassifierEstimator",
-                                                "LogisticRegressionEstimator",
-                                                "RandomForestClassifierEstimator",
-                                                "XGBClassifierEstimator"]
-            }
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI()
+            local_optimizer = experiment.optimizer()
+
+            local_optimizer.get_params()
+
+            # Result:
+            # {
+            #     'name': 'test name',
+            #     'desc': 'test description',
+            #     'prediction_type': 'classification',
+            #     'prediction_column': 'y',
+            #     'scoring': 'roc_auc',
+            #     'holdout_size': 0.1,
+            #     'max_num_daub_ensembles': 1,
+            #     'train_sample_rows_test_size': 0.8,
+            #     'include_only_estimators': ["ExtraTreesClassifierEstimator",
+            #                                     "GradientBoostingClassifierEstimator",
+            #                                     "LGBMClassifierEstimator",
+            #                                     "LogisticRegressionEstimator",
+            #                                     "RandomForestClassifierEstimator",
+            #                                     "XGBClassifierEstimator"]
+            # }
         """
         if hasattr(self, '_result_client'):
             wml_pipeline_details = download_wml_pipeline_details_from_file(self._result_client)
@@ -225,28 +225,26 @@ class LocalAutoPipelines(BaseAutoPipelines):
         return self.params
 
     def fit(self, X: 'DataFrame', y: 'Series') -> 'Pipeline':
-        """
-        Run a training process of AutoAI locally.
+        """Run a training process of AutoAI locally.
 
-        Parameters
-        ----------
-        X: pandas.DataFrame, required
-            Training dataset.
+        :param X: training dataset
+        :type X: pandas.DataFrame
 
-        y: pandas.Series, required
-            Target values.
+        :param y: target values
+        :type y: pandas.Series
 
-        Returns
-        -------
-        Pipeline model (best found)
+        :return: pipeline model (best found)
+        :rtype: Pipeline
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI()
-        >>> local_optimizer = experiment.optimizer()
-        >>>
-        >>> fitted_best_model = local_optimizer.fit(X=test_data_x, y=test_data_y)
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI()
+            local_optimizer = experiment.optimizer()
+
+            fitted_best_model = local_optimizer.fit(X=test_data_x, y=test_data_y)
         """
         if not self._force_local_scenario:
             raise NotImplementedError("Local scenario not yet implemented.")
@@ -261,20 +259,20 @@ class LocalAutoPipelines(BaseAutoPipelines):
         return self._pdcoe.best_pipeline
 
     def get_holdout_data(self) -> Tuple['DataFrame', 'ndarray']:
-        """
-        Provide holdout part of the training dataset (X and y) to the user.
+        """Provide holdout part of the training dataset (X and y) to the user.
 
-        Returns
-        -------
-        X: DataFrame , y: ndarray
+        :return: X, y
+        :rtype: tuple[DataFrame, ndarray]
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI()
-        >>> local_optimizer = experiment.optimizer()
-        >>>
-        >>> holdout_data = local_optimizer.get_holdout_data()
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI()
+            local_optimizer = experiment.optimizer()
+
+            holdout_data = local_optimizer.get_holdout_data()
         """
         if not self._force_local_scenario:
             raise NotImplementedError("Local scenario not yet implemented.")
@@ -288,26 +286,28 @@ class LocalAutoPipelines(BaseAutoPipelines):
         return DataFrame(self._pdcoe.X_holdout, columns=columns), self._pdcoe.y_holdout
 
     def summary(self) -> 'DataFrame':
-        """
-        Prints AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
+        """Prints AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
 
-        Returns
-        -------
-        Pandas DataFrame with computed pipelines and ML metrics.
+        :return: Pandas DataFrame with computed pipelines and ML metrics
+        :rtype: pandas.DataFrame
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI()
-        >>> local_optimizer = experiment.optimizer()
-        >>>
-        >>> local_optimizer.summary()
-                           training_normalized_gini_coefficient  ...  training_f1
-            Pipeline Name                                        ...
-            Pipeline_3                                 0.359173  ...     0.449197
-            Pipeline_4                                 0.359173  ...     0.449197
-            Pipeline_1                                 0.358124  ...     0.449057
-            Pipeline_2                                 0.358124  ...     0.449057
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI()
+            local_optimizer = experiment.optimizer()
+
+            local_optimizer.summary()
+
+            # Result:
+            #                training_normalized_gini_coefficient  ...  training_f1
+            # Pipeline Name                                        ...
+            # Pipeline_3                                 0.359173  ...     0.449197
+            # Pipeline_4                                 0.359173  ...     0.449197
+            # Pipeline_1                                 0.358124  ...     0.449057
+            # Pipeline_2                                 0.358124  ...     0.449057
         """
         if hasattr(self, '_result_client'):
             details = download_experiment_details_from_file(self._result_client)
@@ -348,25 +348,23 @@ class LocalAutoPipelines(BaseAutoPipelines):
         # --- end note
 
     def get_pipeline_details(self, pipeline_name: str = None) -> dict:
-        """
-        Fetch specific pipeline details, eg. steps etc.
+        """Fetch specific pipeline details, eg. steps etc.
 
-        Parameters
-        ----------
-        pipeline_name: str, optional
-            Pipeline name eg. Pipeline_1, if not specified, best pipeline parameters will be fetched
+        :param pipeline_name: pipeline name eg. Pipeline_1, if not specified, best pipeline parameters will be fetched
+        :type pipeline_name: str, optional
 
-        Returns
-        -------
-        Dictionary with pipeline parameters.
+        :return: pipeline parameters
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI()
-        >>> local_optimizer = experiment.optimizer()
-        >>>
-        >>> pipeline_details = local_optimizer.get_pipeline_details(pipeline_name="Pipeline_1")
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI()
+            local_optimizer = experiment.optimizer()
+
+            pipeline_details = local_optimizer.get_pipeline_details(pipeline_name="Pipeline_1")
         """
         if hasattr(self, '_result_client'):
             details = download_experiment_details_from_file(self._result_client)
@@ -415,40 +413,38 @@ class LocalAutoPipelines(BaseAutoPipelines):
                      pipeline_name: str = None,
                      astype: 'PipelineTypes' = PipelineTypes.LALE,
                      persist: 'bool' = False) -> Union['Pipeline', 'TrainablePipeline']:
-        """
-        Get specified computed pipeline.
+        """Get specified computed pipeline.
 
-        Parameters
-        ----------
-        pipeline_name: str, optional
-            Pipeline name, if you want to see the pipelines names, please use summary() method.
-            If this parameter is None, the best pipeline will be fetched.
+        :param pipeline_name: pipeline name, if you want to see the pipelines names, please use summary() method,
+            if this parameter is None, the best pipeline will be fetched
+        : type pipeline_name: str, optional
 
-        astype: PipelineTypes, optional
-            Type of returned pipeline model. If not specified, lale type is chosen.
+        :param astype: type of returned pipeline model, if not specified, lale type is chosen
+        :type astype: PipelineTypes, optional
 
-        persist: bool, optional
-            Indicates if selected pipeline should be stored locally.
+        :param persist: indicates if selected pipeline should be stored locally
+        :type persist: bool, optional
 
-        Returns
-        -------
-        Scikit-Learn pipeline or Lale TrainablePipeline.
+        :return: Scikit-Learn pipeline or Lale TrainablePipeline
+        :rtype: Pipeline or TrainablePipeline
 
-        See also
-        --------
-        LocalAutoPipelines.summary()
+        See also LocalAutoPipelines.summary().
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI()
-        >>> local_optimizer = experiment.optimizer()
-        >>>
-        >>> pipeline_1 = local_optimizer.get_pipeline(pipeline_name='Pipeline_1')
-        >>> pipeline_2 = local_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=PipelineTypes.LALE)
-        >>> pipeline_3 = local_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=PipelineTypes.SKLEARN)
-        >>> type(pipeline_3)
-            <class 'sklearn.pipeline.Pipeline'>
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI()
+            local_optimizer = experiment.optimizer()
+
+            pipeline_1 = local_optimizer.get_pipeline(pipeline_name='Pipeline_1')
+            pipeline_2 = local_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=PipelineTypes.LALE)
+            pipeline_3 = local_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=PipelineTypes.SKLEARN)
+            type(pipeline_3)
+
+            # Result:
+            # <class 'sklearn.pipeline.Pipeline'>
 
         """
         # note: try to download and load pipeline model from COS (auto-gen notebook scenario)
@@ -527,25 +523,23 @@ class LocalAutoPipelines(BaseAutoPipelines):
         raise WMLClientError("Not supported in local scenario.")
 
     def predict(self, X: Union['DataFrame', 'ndarray']) -> 'ndarray':
-        """
-        Predict method called on top of the best computed pipeline.
+        """Predict method called on top of the best computed pipeline.
 
-        Parameters
-        ----------
-        X: numpy.ndarray or pandas.DataFrame, required
-            Test data for prediction.
+        :param X: test data for prediction
+        :type X: numpy.ndarray or pandas.DataFrame
 
-        Returns
-        -------
-        Numpy ndarray with model predictions.
+        :return: model predictions
+        :rtype: numpy.ndarray
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI()
-        >>> local_optimizer = experiment.optimizer()
-        >>>
-        >>> predictions = local_optimizer.predict(X=test_data)
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI()
+            local_optimizer = experiment.optimizer()
+
+            predictions = local_optimizer.predict(X=test_data)
         """
         if hasattr(self, '_result_client'):
             if isinstance(X, DataFrame) or isinstance(X, ndarray):
@@ -569,12 +563,10 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 raise TypeError("X should be either of type pandas.DataFrame or numpy.ndarray")
 
     def get_data_connections(self) -> List['DataConnection']:
-        """
-        Provides list of DataConnections with training data that user specified.
+        """Provides list of DataConnections with training data that user specified.
 
-        Returns
-        -------
-        List['DataConnection'] with populated optimizer parameters
+        :return: list of DataConnections with populated optimizer parameters
+        :rtype: list[DataConnection]
         """
         if hasattr(self, '_data_clients'):
             return self._training_data_reference
@@ -583,12 +575,10 @@ class LocalAutoPipelines(BaseAutoPipelines):
             raise NotImplementedError("Local scenario not yet implemented.")
 
     def get_preprocessed_data_connection(self) -> 'DataConnection':
-        """
-        Provides DataConnection with preprocessed training data.
+        """Provides DataConnection with preprocessed training data.
 
-        Returns
-        -------
-        DataConnection with populated optimizer parameters
+        :return: DataConnection with populated optimizer parameters
+        :rtype: DataConnection
         """
         if hasattr(self, '_result_client'):
             params = self.get_params()
@@ -613,13 +603,11 @@ class LocalAutoPipelines(BaseAutoPipelines):
             raise NotImplementedError("Local scenario not yet implemented.")
 
     def get_preprocessing_pipeline(self) -> 'DataJoinPipeline':
-        """
-        Returns preprocessing pipeline object for further usage.
+        """Get preprocessing pipeline object for further usage.
             (eg. to visualize preprocessing pipeline as graph).
 
-        Returns
-        -------
-        DataJoinPipeline
+        :return: preprocessing pipeline
+        :rtype: DataJoinPipeline
         """
         if hasattr(self, '_result_client'):
             optimizer_parameters = self.get_params()
@@ -636,20 +624,16 @@ class LocalAutoPipelines(BaseAutoPipelines):
             raise NotImplementedError("Local scenario not yet implemented.")
 
     def _train(self, train_x: 'DataFrame', train_y: 'Series') -> 'PrepDaubCogOptEstimator':
-        """
-        Prepare and run PDCOE optimizer/estimator.
+        """Prepare and run PDCOE optimizer/estimator.
 
-        Parameters
-        ----------
-        train_x: pandas.DataFrame, required
-            Training dataset.
+        :param train_x: training dataset
+        :type train_x: pandas.DataFrame
 
-        train_y: pandas.Series, required
-            Target values.
+        :param train_y: target values
+        :type train_y: pandas.Series
 
-        Returns
-        -------
-        PrepDaubCogOptEstimator
+        :return: PDCOE optimizer/estimator.
+        :rtype: PrepDaubCogOptEstimator
         """
         # Disable printing to suppress warnings from ai4ml
         with redirect_stdout(open(os.devnull, "w")):
