@@ -27,7 +27,7 @@ from ibm_watson_machine_learning.helpers.connections import (
 from ibm_watson_machine_learning.preprocessing import DataJoinPipeline
 from ibm_watson_machine_learning.utils.autoai.enums import (
     RunStateTypes, PipelineTypes, TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, DataConnectionTypes,
-    ForecastingPipelineTypes, PredictionType)
+    ForecastingPipelineTypes, PredictionType, TimeseriesAnomalyPredictionPipelineTypes)
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
     TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
@@ -54,70 +54,68 @@ __all__ = [
 
 
 class RemoteAutoPipelines(BaseAutoPipelines):
-    """
-    RemoteAutoPipelines class for pipeline operation automation on WML.
+    """RemoteAutoPipelines class for pipeline operation automation on WML.
 
-    Parameters
-    ----------
-    name: str, required
-        Name for the AutoPipelines
+    :param name: name for the AutoPipelines
+    :type name: str
 
-    prediction_type: PredictionType, required
-        Type of the prediction.
+    :param prediction_type: type of the prediction
+    :type prediction_type: PredictionType
 
-    prediction_column: str, required
-        name of the target/label column
+    :param prediction_column: name of the target/label column
+    :type prediction_column: str
 
-    scoring: Metrics, required
-        Type of the metric to optimize with.
+    :param scoring: type of the metric to optimize with
+    :type scoring: Metrics
 
-    desc: str, optional
-        Description
+    :param engine: engine for remote work on WML
+    :type engine: WMLEngine
 
-    holdout_size: float, optional
-        Percentage of the entire dataset to leave as a holdout. Default 0.1
+    :param desc: description
+    :type desc: str, optional
 
-    max_num_daub_ensembles: int, optional
-        Maximum number (top-K ranked by DAUB model selection) of the selected algorithm, or estimator types,
-        for example LGBMClassifierEstimator, XGBoostClassifierEstimator, or LogisticRegressionEstimator
-        to use in pipeline composition. The default is None that means the true default value will be determined by the
-        internal different algorithms, where only the highest ranked by model selection algorithm type is used.
+    :param holdout_size: percentage of the entire dataset to leave as a holdout, default 0.1
+    :type holdout_size: float, optional
 
-    train_sample_rows_test_size: float, optional
-        Training data sampling percentage
+    :param max_num_daub_ensembles: maximum number (top-K ranked by DAUB model selection) of the selected algorithm,
+        or estimator types, for example `LGBMClassifierEstimator`, `XGBoostClassifierEstimator`, or
+        `LogisticRegressionEstimator` to use in pipeline composition, the default is `None` that means
+        the true default value will be determined by the internal different algorithms, where only
+        the highest ranked by model selection algorithm type is used
+    :type max_num_daub_ensembles: int, optional
 
-    include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']], optional
-        List of estimators to include in computation process.
+    :param train_sample_rows_test_size: training data sampling percentage
+    :type train_sample_rows_test_size: float, optional
 
-    cognito_transform_names: List['Transformers'], optional
-        List of transformers to include in the feature enginnering computation process.
-        See: AutoAI.Transformers
+    :param include_only_estimators: list of estimators to include in computation process
+    :type include_only_estimators: list[ClassificationAlgorithms or RegressionAlgorithms], optional
 
-    csv_separator: Union[List[str], str], optional
-            The separator, or list of separators to try for separating
-            columns in a CSV file.  Not used if the file_name is not a CSV file.
-            Default is ','.
+    :param cognito_transform_names: list of transformers to include in the feature enginnering computation process,
+        see: AutoAI.Transformers
+    :type cognito_transform_names: list[Transformers], optional
 
-    excel_sheet: Union[str, int], optional
-        Name of the excel sheet to use. Only use when xlsx file is an input. Support for number of the sheet is deprecated.
-        By default first sheet is used.
+    :param csv_separator: the separator, or list of separators to try for separating columns in a CSV file,
+        not used if the file_name is not a CSV file, default is ','
+    :type csv_separator: list[str] or str, optional
 
-    encoding: str, optional
-            Encoding type for CSV training file.
+    :param excel_sheet: name of the excel sheet to use, only use when xlsx file is an input,
+        support for number of the sheet is deprecated, by default first sheet is used
+    :type excel_sheet: str, optional
 
-    positive_label: str, optional
-            The positive class to report when binary classification.
-            When multiclass or regression, this will be ignored.
+    :param encoding: encoding type for CSV training file
+    :type encoding: str, optional
 
-    t_shirt_size: TShirtSize, optional
-        The size of the remote AutoAI POD instance (computing resources). Only applicable to a remote scenario.
+    :param positive_label: the positive class to report when binary classification, when multiclass or regression,
+        this will be ignored
+    :type positive_label: str, optional
 
-    engine: WMLEngine, required
-        Engine for remote work on WML.
+    :param t_shirt_size: the size of the remote AutoAI POD instance (computing resources),
+        only applicable to a remote scenario
+    :type t_shirt_size: TShirtSize, optional
 
-    data_join_graph: DataJoinGraph, optional
-        A graph object with definition of join structure for multiple input data sources.
-        Data preprocess step for multiple files.
+    :param data_join_graph: a graph object with definition of join structure for multiple input data sources,
+        data preprocess step for multiple files
+    :type data_join_graph: DataJoinGraph, optional
 
     """
 
@@ -171,10 +169,11 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                  fairness_info: dict = None,
                  retrain_on_holdout: bool = True,
                  feature_columns: List[str] = None,
-                 pipeline_types: List['ForecastingPipelineTypes'] = None,
+                 pipeline_types: List[Union['ForecastingPipelineTypes', 'TimeseriesAnomalyPredictionPipelineTypes']] = None,
                  supporting_features_at_forecast: bool = None,
                  categorical_columns: list = None,
                  numerical_columns: list = None,
+                 confidence_level: float = 0.95,
                  **kwargs):
 
         if data_join_graph is not None:
@@ -237,6 +236,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             'supporting_features_at_forecast': supporting_features_at_forecast,
             'numerical_columns': numerical_columns,
             'categorical_columns':categorical_columns,
+            'confidence_level': confidence_level,
         }
 
         if fairness_info:
@@ -255,37 +255,39 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     #   WML Pipeline Part / Parameters for AUtoAI POD  #
     ####################################################
     def get_params(self) -> dict:
-        """
-        Get configuration parameters of AutoPipelines.
+        """Get configuration parameters of AutoPipelines.
 
-        Returns
-        -------
-        Dictionary with AutoPipelines parameters.
+        :return: AutoPipelines parameters
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> remote_optimizer.get_params()
-            {
-                'name': 'test name',
-                'desc': 'test description',
-                'prediction_type': 'classification',
-                'prediction_column': 'y',
-                'scoring': 'roc_auc',
-                'holdout_size': 0.1,
-                'max_num_daub_ensembles': 1,
-                't_shirt_size': 'm',
-                'train_sample_rows_test_size': 0.8,
-                'include_only_estimators': ["ExtraTreesClassifierEstimator",
-                                            "GradientBoostingClassifierEstimator",
-                                            "LGBMClassifierEstimator",
-                                            "LogisticRegressionEstimator",
-                                            "RandomForestClassifierEstimator",
-                                            "XGBClassifierEstimator"]
-            }
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            remote_optimizer.get_params()
+
+            # Result:
+            # {
+            #     'name': 'test name',
+            #     'desc': 'test description',
+            #     'prediction_type': 'classification',
+            #     'prediction_column': 'y',
+            #     'scoring': 'roc_auc',
+            #     'holdout_size': 0.1,
+            #     'max_num_daub_ensembles': 1,
+            #     't_shirt_size': 'm',
+            #     'train_sample_rows_test_size': 0.8,
+            #    'include_only_estimators': ["ExtraTreesClassifierEstimator",
+            #                                "GradientBoostingClassifierEstimator",
+            #                                "LGBMClassifierEstimator",
+            #                                "LogisticRegressionEstimator",
+            #                                "RandomForestClassifierEstimator",
+            #                                "XGBClassifierEstimator"]
+            # }
         """
         _params = self._engine.get_params().copy()
         del _params['autoai_pod_version']
@@ -306,55 +308,54 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             background_mode=False,
             test_data_references: List['DataConnection'] = None,
             training_data_references: List['DataConnection'] = None) -> dict:
-        """
-        Run a training process on WML of autoai on top of the training data referenced by DataConnection.
+        """Run a training process on WML of autoai on top of the training data referenced by DataConnection.
 
-        Parameters
-        ----------
-        training_data_reference: List[DataConnection], optional
-            Data storage connection details to inform where training data is stored. (Old parameter)
+        :param training_data_reference: data storage connection details to inform where training data is stored,
+            deprecated parameter, use `training_data_references` instead
 
-        training_data_references: List[DataConnection], required
-            Data storage connection details to inform where training data is stored.
-            New version of `training_data_reference`
+        :param training_data_references: data storage connection details to inform where training data is stored,
+            new version of `training_data_reference`
+        :type training_data_references: list[DataConnection]
 
-        training_results_reference: DataConnection, optional
-            Data storage connection details to store pipeline training results. Not applicable on CP4D.
+        :param training_results_reference: data storage connection details to store pipeline training results,
+            not applicable on CP4D
+        :type training_results_reference: DataConnection, optional
 
-        background_mode: bool, optional
-            Indicator if fit() method will run in background (async) or (sync).
+        :param background_mode: indicator if fit() method will run in background (async) or (sync)
+        :type background_mode: bool, optional
 
-        test_data_references: List[DataConnection], optional
-            Data storage connection details to inform where test / holdout data is stored.
+        :param test_data_references: data storage connection details to inform where test / holdout data is stored
+        :type test_data_references: list[DataConnection], optional
 
-        Returns
-        -------
-        Dictionary with run details.
+        :return: run details
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> from ibm_watson_machine_learning.helpers import DataConnection, S3Location
-        >>>
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> remote_optimizer.fit(
-        >>>     training_data_connection=[DataConnection(
-        >>>         connection_asset_id=connection_id,
-        >>>         location=S3Location(
-        >>>             bucket='automl',
-        >>>             path='german_credit_data_biased_training.csv')
-        >>>         )
-        >>>     )],
-        >>>     DataConnection(
-        >>>         connection_asset_id=connection_id,
-        >>>         location=S3Location(
-        >>>             bucket='automl',
-        >>>             path='')
-        >>>         )
-        >>>     ),
-        >>>     background_mode=False)
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            from ibm_watson_machine_learning.helpers import DataConnection, S3Location
+
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            remote_optimizer.fit(
+                training_data_connection=[DataConnection(
+                    connection_asset_id=connection_id,
+                    location=S3Location(
+                        bucket='automl',
+                        path='german_credit_data_biased_training.csv')
+                    )
+                )],
+                DataConnection(
+                    connection_asset_id=connection_id,
+                    location=S3Location(
+                        bucket='automl',
+                        path='')
+                    )
+                ),
+                background_mode=False)
         """
         if self.params.get('data_join_graph'):
             if self._workspace.wml_client.ICP_46:
@@ -555,44 +556,42 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     #   Run operations  #
     #####################
     def get_run_status(self) -> str:
-        """
-        Check status/state of initialized AutoPipelines run if ran in background mode
+        """Check status/state of initialized AutoPipelines run if ran in background mode.
 
-        Returns
-        -------
-        Dictionary with run status details.
+        :return: run status details
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> remote_optimizer.get_run_status()
-            'completed'
+        **Example**
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            remote_optimizer.get_run_status()
+
+            # Result:
+            # 'completed'
         """
         return self._engine.get_run_status()
 
     def get_run_details(self, include_metrics: bool = False, _internal=False) -> dict:
-        """
-        Get fit/run details.
+        """Get fit/run details.
 
-        Parameters
-        ----------
-        include_metrics: bool, optional
-            Indicates to include metrics in the training details output. Default False.
+        :param include_metrics: indicates to include metrics in the training details output
+        :type include_metrics: bool, optional
 
-        Returns
-        -------
-        Dictionary with AutoPipelineOptimizer fit/run details.
+        :return: AutoPipelineOptimizer fit/run details
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> remote_optimizer.get_run_details()
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            remote_optimizer.get_run_details()
         """
         if not _internal and self.params.get('data_join_graph'):
             if self._workspace.wml_client.ICP_46:
@@ -612,55 +611,57 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     #   Pipeline models operations  #
     #################################
     def summary(self) -> 'DataFrame':
-        """
-        Prints AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
+        """Print AutoPipelineOptimizer Pipelines details (autoai trained pipelines).
 
-        Returns
-        -------
-        Pandas DataFrame with computed pipelines and ML metrics.
+        :return: computed pipelines and ML metrics
+        :rtype: pandas.DataFrame
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> remote_optimizer.summary()
-                           training_normalized_gini_coefficient  ...  training_f1
-            Pipeline Name                                        ...
-            Pipeline_3                                 0.359173  ...     0.449197
-            Pipeline_4                                 0.359173  ...     0.449197
-            Pipeline_1                                 0.358124  ...     0.449057
-            Pipeline_2                                 0.358124  ...     0.449057
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            remote_optimizer.summary()
+
+            # Result:
+            #                training_normalized_gini_coefficient  ...  training_f1
+            # Pipeline Name                                        ...
+            # Pipeline_3                                 0.359173  ...     0.449197
+            # Pipeline_4                                 0.359173  ...     0.449197
+            # Pipeline_1                                 0.358124  ...     0.449057
+            # Pipeline_2                                 0.358124  ...     0.449057
         """
         return self._engine.summary()
 
     def get_pipeline_details(self, pipeline_name: str = None) -> dict:
-        """
-        Fetch specific pipeline details, eg. steps etc.
+        """Fetch specific pipeline details, eg. steps etc.
 
-        Parameters
-        ----------
-        pipeline_name: str, optional
-            Pipeline name eg. Pipeline_1, if not specified, best pipeline parameters will be fetched
+        :param pipeline_name: pipeline name eg. Pipeline_1, if not specified, best pipeline parameters will be fetched
+        :type pipeline_name: str, optional
 
-        Returns
-        -------
-        Dictionary with pipeline parameters.
+        :return: pipeline parameters
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> remote_optimizer.get_pipeline_details()
-        >>> remote_optimizer.get_pipeline_details(pipeline_name='Pipeline_4')
-            {
-                'composition_steps': ['TrainingDataset_full_4521_16', 'Split_TrainingHoldout',
-                                      'TrainingDataset_full_4068_16', 'Preprocessor_default', 'DAUB'],
-                'pipeline_nodes': ['PreprocessingTransformer', 'GradientBoostingClassifierEstimator']
-            }
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            remote_optimizer.get_pipeline_details()
+            remote_optimizer.get_pipeline_details(pipeline_name='Pipeline_4')
+
+            # Result:
+            # {
+            #     'composition_steps': ['TrainingDataset_full_4521_16', 'Split_TrainingHoldout',
+            #                           'TrainingDataset_full_4068_16', 'Preprocessor_default', 'DAUB'],
+            #     'pipeline_nodes': ['PreprocessingTransformer', 'GradientBoostingClassifierEstimator']
+            # }
         """
         return self._engine.get_pipeline_details(pipeline_name=pipeline_name)
 
@@ -668,42 +669,38 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                      pipeline_name: str = None,
                      astype: 'PipelineTypes' = PipelineTypes.LALE,
                      persist: 'bool' = False) -> Union['Pipeline', 'TrainablePipeline']:
-        """
-        Download specified pipeline from WML.
+        """Download specified pipeline from WML.
 
-        Parameters
-        ----------
-        pipeline_name: str, optional
-            Pipeline name, if you want to see the pipelines names, please use summary() method.
-            If this parameter is None, the best pipeline will be fetched.
+        :param pipeline_name: pipeline name, if you want to see the pipelines names, please use summary() method,
+            if this parameter is None, the best pipeline will be fetched
+        :type pipeline_name: str, optional
 
-        astype: PipelineTypes, optional
-            Type of returned pipeline model. If not specified, lale type is chosen.
+        :param astype: type of returned pipeline model, if not specified, lale type is chosen
+        :type astype: PipelineTypes, optional
 
-        persist: bool, optional
-            Indicates if selected pipeline should be stored locally.
+        :param persist: indicates if selected pipeline should be stored locally
+        :type persist: bool, optional
 
-        Returns
-        -------
-        Scikit-Learn pipeline.
+        :return: Scikit-Learn pipeline
+        :rtype: Pipeline or TrainablePipeline
 
-        See also
-        --------
-        RemoteAutoPipelines.summary()
+        See also RemoteAutoPipelines.summary().
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> pipeline_1 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1')
-        >>> pipeline_2 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=AutoAI.PipelineTypes.LALE)
-        >>> pipeline_3 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=AutoAI.PipelineTypes.SKLEARN)
-        >>> type(pipeline_3)
-            <class 'sklearn.pipeline.Pipeline'>
-        >>> pipeline_4 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1', persist=True)
-            Selected pipeline stored under: "absolute_local_path_to_model/model.pickle"
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            pipeline_1 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1')
+            pipeline_2 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=AutoAI.PipelineTypes.LALE)
+            pipeline_3 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1', astype=AutoAI.PipelineTypes.SKLEARN)
+            type(pipeline_3)
+            # <class 'sklearn.pipeline.Pipeline'>
+            pipeline_4 = remote_optimizer.get_pipeline(pipeline_name='Pipeline_1', persist=True)
+            # Selected pipeline stored under: "absolute_local_path_to_model/model.pickle"
 
         """
         try:
@@ -758,39 +755,35 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                              'Should be either PipelineTypes.SKLEARN or PipelineTypes.LALE')
 
     def get_pipeline_notebook(self,
-                     pipeline_name: str = None,
-                     filename: str = None,
-                     insert_to_cell: bool = False) -> str:
-        """
-        Download specified pipeline notebook from WML.
+                              pipeline_name: str = None,
+                              filename: str = None,
+                              insert_to_cell: bool = False) -> str:
+        """Download specified pipeline notebook from WML.
 
-        Parameters
-        ----------
-        pipeline_name: str, optional
-            Pipeline name, if you want to see the pipelines names, please use summary() method.
-            If this parameter is None, the best pipeline will be fetched.
+        :param pipeline_name: pipeline name, if you want to see the pipelines names, please use summary() method,
+            if this parameter is None, the best pipeline will be fetched
+        :type pipeline_name: str, optional
 
-        filename: str, optional
-            Filename under which the pipeline notebook will be saved.
+        :param filename: filename under which the pipeline notebook will be saved
+        :type filename: str, optional
 
-        insert_to_cell: bool, optional
-            If run in jupyter notebook, if set inserts the notebook into cell below.
+        :param insert_to_cell: if run in jupyter notebook, if set inserts the notebook into cell below
+        :type insert_to_cell: bool, optional
 
-        Returns
-        -------
-        Path to saved pipeline notebook.
+        :return: path to saved pipeline notebook
+        :rtype: str
 
-        See also
-        --------
-        RemoteAutoPipelines.summary()
+        See also RemoteAutoPipelines.summary().
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>> remote_optimizer = experiment.optimizer(...)
-        >>>
-        >>> pipeline_notebook_path = remote_optimizer.get_pipeline_notebook(pipeline_name='Pipeline_1')
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+            remote_optimizer = experiment.optimizer(...)
+
+            pipeline_notebook_path = remote_optimizer.get_pipeline_notebook(pipeline_name='Pipeline_1')
 
         """
         if pipeline_name is None:
@@ -838,23 +831,23 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     # note: predict on top of the best computed pipeline, best pipeline is downloaded for the first time
     def predict(self, X: Union['DataFrame', 'ndarray']=None, observations: Union['DataFrame', 'ndarray']=None,
                 supporting_features: Union['DataFrame', 'ndarray']=None) -> 'ndarray':
-        """
-        Predict method called on top of the best fetched pipeline.
+        """Predict method called on top of the best fetched pipeline.
 
-        Parameters
-        ----------
-        X: numpy.ndarray or pandas.DataFrame, required
-            Test data for prediction
-        observations: numpy.ndarray or pandas.DataFrame,
-            New observations of forecasting data that were used to train AutoAI model. Supported only for forecasting pipelines.
-        supporting_features: numpy.ndarray or pandas.DataFrame,
-            Future values of exogenous features. Supported only for forecasting pipelines.
+        :param X: test data for prediction
+        :type X: numpy.ndarray or pandas.DataFrame
 
-        Returns
-        -------
-        Numpy ndarray with model predictions.
+        :param observations: new observations of forecasting data that were used to train AutoAI model,
+            supported only for forecasting pipelines
+        :type observations: numpy.ndarray or pandas.DataFrame
+
+        :param supporting_features: future values of exogenous features, supported only for forecasting pipelines
+        :type supporting_features: numpy.ndarray or pandas.DataFrame
+
+        :return: model predictions
+        :rtype: numpy.ndarray
         """
-        is_forecasting = self.params.get('prediction_type') in (PredictionType.FORECASTING, 'timeseries')
+        is_forecasting = self.params.get('prediction_type') in (PredictionType.FORECASTING, 'timeseries',
+                                                                PredictionType.TIMESERIES_ANOMALY_PREDICTION)
 
         if not is_forecasting and X is None:
             raise ValueError("X parameter is required in predict method.")
@@ -892,13 +885,11 @@ class RemoteAutoPipelines(BaseAutoPipelines):
     # --- end note
 
     def get_data_connections(self) -> List['DataConnection']:
-        """
-        Create DataConnection objects for further user usage
+        """Create DataConnection objects for further user usage
             (eg. to handle data storage connection or to recreate autoai holdout split).
 
-        Returns
-        -------
-        List['DataConnection'] with populated optimizer parameters
+        :return: list of DataConnection with populated optimizer parameters
+        :rtype: list[DataConnection]
         """
         user_holdout_exists = True
         try:
@@ -931,13 +922,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         return data_connections
 
     def get_test_data_connections(self) -> List['DataConnection']:
-        """
-        Create DataConnection objects for further user usage
-            (To recreate autoai holdout that user specified).
+        """Create DataConnection objects for further user usage (To recreate autoai holdout that user specified).
 
-        Returns
-        -------
-        List['DataConnection'] with populated optimizer parameters
+        :return: list of DataConnection with populated optimizer parameters
+        :rtype: list[DataConnection]
         """
         optimizer_parameters = self.get_params()
         run_details = self.get_run_details(_internal=True)
@@ -962,9 +950,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         return data_connections
 
     def _validate_training_data_size(self, training_data_reference: List['DataConnection']) -> None:
-        """
-        Check size of dataset in training data connection
-        """
+        """Check size of dataset in training data connection."""
 
         for training_connection in training_data_reference:
             t_shirt_size = self._engine._auto_pipelines_parameters.get('t_shirt_size')
@@ -988,13 +974,11 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 pass  # note: data source size checking for other environment is not implemented
 
     def get_preprocessed_data_connection(self) -> 'DataConnection':
-        """
-        Create DataConnection object for further user usage (with OBM output)
+        """Create DataConnection object for further user usage (with OBM output)
             (eg. to handle data storage connection or to recreate autoai holdout split).
 
-        Returns
-        -------
-        DataConnection with populated optimizer parameters
+        :return: DataConnection with populated optimizer parameters
+        :rtype: DataConnection
         """
         optimizer_parameters = self.get_params()
 
@@ -1026,13 +1010,11 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 reason="Cannot get preprocessed data as preprocessing step was not performed.")
 
     def get_preprocessed_test_data_connection(self) -> 'DataConnection':
-        """
-        Create DataConnection object for further user usage (with OBM output)
+        """Create DataConnection object for further user usage (with OBM output)
             (eg. to handle data storage connection or to recreate autoai holdout split).
 
-        Returns
-        -------
-        DataConnection with populated optimizer parameters
+        :return: DataConnection with populated optimizer parameters
+        :rtype: DataConnection
         """
         optimizer_parameters = self.get_params()
 
@@ -1064,13 +1046,10 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 reason="Cannot get preprocessed data as preprocessing step was not performed.")
 
     def get_preprocessing_pipeline(self) -> 'DataJoinPipeline':
-        """
-        Returns preprocessing pipeline object for further usage.
-            (eg. to visualize preprocessing pipeline as graph).
+        """Returns preprocessing pipeline object for further usage. (eg. to visualize preprocessing pipeline as graph).
 
-        Returns
-        -------
-        DataJoinPipeline
+        :return: preprocessing pipeline object
+        :rtype: DataJoinPipeline
         """
         optimizer_parameters = self.get_params()
 
