@@ -32,16 +32,13 @@ from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 
 
 class AutoPipelinesRuns(BaseAutoPipelinesRuns):
-    """
-    AutoPipelinesRuns class is used to work with historical Optimizer runs.
+    """AutoPipelinesRuns class is used to work with historical Optimizer runs.
 
-    Parameters
-    ----------
-    engine: WMLEngine, required
-        WMLEngine to handle WML operations.
+    :param engine: WMLEngine to handle WML operations
+    :type engine: WMLEngine
 
-    filter: str, optional
-        Filter, user can choose which runs to fetch specifying AutoPipelines name.
+    :param filter: filter, user can choose which runs to fetch specifying AutoPipelines name
+    :type filter: str, optional
     """
 
     def __init__(self, engine: 'WMLEngine', filter: str = None) -> None:
@@ -54,13 +51,11 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         return self
 
     def list(self) -> 'DataFrame':
-        """
-        Lists historical runs/fits with status. If user has a lot of runs stored in the WML,
+        """Lists historical runs/fits with status. If user has a lot of runs stored in the WML,
         it may take long time to fetch all the information.
 
-        Returns
-        -------
-        Pandas DataFrame with runs IDs and state.
+        :return: Pandas DataFrame with runs IDs and state
+        :rtype: pandas.DataFrame
         """
 
         columns = ['timestamp', 'run_id', 'state', 'auto_pipeline_optimizer name']
@@ -112,34 +107,34 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         return runs.sort_values(by=["timestamp"], ascending=False)[:50]
 
     def get_params(self, run_id: str = None) -> dict:
-        """
-        Get executed optimizers configs parameters based on the run_id.
+        """Get executed optimizers configs parameters based on the run_id.
 
-        Parameters
-        ----------
-        run_id: str, optional
-            ID of the fit/run. If not specified, latest is taken.
+        :param run_id: ID of the fit/run, if not specified, latest is taken
+        :type run_id: str, optional
 
-        Returns
-        -------
-        Dictionary with optimizer configuration parameters.
+        :return: optimizer configuration parameters
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>>
-        >>> experiment.runs.get_params(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
-        >>> experiment.runs.get_params()
-            {
-                'name': 'test name',
-                'desc': 'test description',
-                'prediction_type': 'classification',
-                'prediction_column': 'y',
-                'scoring': 'roc_auc',
-                'holdout_size': 0.1,
-                'max_num_daub_ensembles': 1
-            }
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+
+            experiment.runs.get_params(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
+            experiment.runs.get_params()
+
+            # Result:
+            # {
+            #     'name': 'test name',
+            #     'desc': 'test description',
+            #     'prediction_type': 'classification',
+            #     'prediction_column': 'y',
+            #     'scoring': 'roc_auc',
+            #     'holdout_size': 0.1,
+            #     'max_num_daub_ensembles': 1
+            # }
         """
 
         if run_id is None:
@@ -169,6 +164,11 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                                                                        optimizer_config=optimizer_config)
         # --- end note
 
+        # note: try to find tsad node
+        tsad_node_number, tsad_runtime_number = get_node_and_runtime_index(node_name='tsad',
+                                                                           optimizer_config=optimizer_config)
+        # --- end note
+
         try:
             name = optimizer_config['entity']['name']
             description = optimizer_config['entity'].get('description', '')
@@ -270,7 +270,35 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                 'pipeline_types': pipeline_types,
                 'retrain_on_holdout': ts_parameters.get('retrain_on_holdout', True),
             }
+        elif tsad_node_number is not None:
+            tsad_parameters = optimizer_config['entity']['document']['pipelines'][0]['nodes'][tsad_node_number][
+                'parameters']['optimization']
+            tsad_wml_data = optimizer_config['entity']['document']['runtimes'][tsad_node_number]['app_data']['wml_data']
 
+            csv_separator = optimizer_config['entity']['document']['pipelines'][0]['nodes'][tsad_node_number][
+                'parameters'].get('input_file_separator', ',')
+            encoding = optimizer_config['entity']['document']['pipelines'][0]['nodes'][tsad_node_number][
+                'parameters'].get('encoding', 'utf-8')
+
+            params = {
+                'name': name,
+                'desc': description,
+                'prediction_type': tsad_parameters.get('learning_type'),
+                'feature_columns': tsad_parameters.get('feature_columns'),
+                'prediction_column': tsad_parameters.get('label'),
+                'prediction_columns': tsad_parameters.get('target_columns'),
+                'timestamp_column_name': tsad_parameters.get('timestamp_column'),
+                'holdout_size': tsad_parameters.get('holdout_param', 0.2),
+                'max_num_daub_ensembles': tsad_parameters.get('max_num_pipelines', 3),
+                'include_only_estimators': tsad_parameters.get('daub_include_only_estimators'),
+                't_shirt_size': tsad_wml_data['hardware_spec']['id'],
+                'csv_separator': csv_separator,
+                'encoding': encoding,
+                'pipeline_types': tsad_parameters.get('pipelines'),
+                'retrain_on_holdout': tsad_parameters.get('retrain_on_holdout', True),
+                'scoring': tsad_parameters.get('evaluation_metric', 'f1'),
+                'confidence_level': tsad_parameters.get('confidence_level', 0.95),
+            }
         else:
             params = {
                 'name': name,
@@ -301,25 +329,23 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         return params
 
     def get_run_details(self, run_id: str = None) -> dict:
-        """
-        Get run details. If run_id is not supplied, last run will be taken.
+        """Get run details. If run_id is not supplied, last run will be taken.
 
-        Parameters
-        ----------
-        run_id: str, optional
-            ID of the fit/run.
+        :param run_id: ID of the fit/run
+        :type run_id: str, optional
 
-        Returns
-        -------
-        Dictionary with run configuration parameters.
+        :return: run configuration parameters
+        :rtype: dict
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>>
-        >>> experiment.runs.get_run_details(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
-        >>> experiment.runs.get_run_details()
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+
+            experiment.runs.get_run_details(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
+            experiment.runs.get_run_details()
         """
         if run_id is None:
             details = self._wml_engine._wml_client.training.get_details(limit=1, _internal=True).get('resources')[0]
@@ -337,27 +363,25 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                       run_id: Optional[str] = None,
                       metadata: Dict[str, Union[List['DataConnection'], 'DataConnection', str, int]] = None
                       ) -> 'RemoteAutoPipelines':
-        """
-        Creates instance of AutoPipelinesRuns with all computed pipelines computed by AutoAi on WML.
+        """Create instance of AutoPipelinesRuns with all computed pipelines computed by AutoAi on WML.
 
-        Parameters
-        ----------
-        run_id: str, optional
-            ID of the fit/run.
+        :param run_id: ID of the fit/run
+        :type run_id: str, optional
 
-        metadata: dict, optional
-            Option to pass information about COS data reference or WSD (auto-gen notebook)
+        :param metadata: option to pass information about COS data reference or WSD (auto-gen notebook)
+        :type metadata: dict, optional
 
-        Returns
-        -------
-        AutoPipelinesRuns class instance.
+        :return: optimizer object
+        :rtype: AutoPipelinesRuns class instance
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>>
-        >>> historical_optimizer = experiment.runs.get_optimizer(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+
+            historical_optimizer = experiment.runs.get_optimizer(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
         """
         # note: normal scenario
         if metadata is None:
@@ -396,25 +420,23 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
         # --- end note
 
     def get_data_connections(self, run_id: str) -> List['DataConnection']:
-        """
-        Create DataConnection objects for further user usage
+        """Create DataConnection objects for further user usage
             (eg. to handle data storage connection or to recreate autoai holdout split).
 
-        Parameters
-        ----------
-        run_id: str, required
-            ID of the historical fit/run.
+        :param run_id: ID of the historical fit/run
+        :type run_id: str
 
-        Returns
-        -------
-        List['DataConnection'] with populated optimizer parameters
+        :return: list of DataConnections with populated optimizer parameters
+        :rtype: list['DataConnection']
 
-        Example
-        -------
-        >>> from ibm_watson_machine_learning.experiment import AutoAI
-        >>> experiment = AutoAI(credentials, ...)
-        >>>
-        >>> data_connections = experiment.runs.get_data_connections(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
+        **Example**
+
+        .. code-block:: python
+
+            from ibm_watson_machine_learning.experiment import AutoAI
+            experiment = AutoAI(credentials, ...)
+
+            data_connections = experiment.runs.get_data_connections(run_id='02bab973-ae83-4283-9d73-87b9fd462d35')
         """
         optimizer_parameters = self.get_params(run_id=run_id)
         training_data_references = self.get_run_details(run_id=run_id)['entity']['training_data_references']
