@@ -25,9 +25,7 @@ __all__ = [
 
 
 class BaseAutoPipelinesRuns:
-    """
-    Base abstract class for Pipeline Optimizers Runs.
-    """
+    """Base abstract class for Pipeline Optimizers Runs."""
 
     @abstractmethod
     def list(self) -> 'DataFrame':
@@ -46,7 +44,7 @@ class BaseAutoPipelinesRuns:
 
     @abstractmethod
     def get_optimizer(self, run_id: str):
-        """Creates instance of AutoPipelinesRuns with all computed pipelines computed by AutoAi on WML."""
+        """Create instance of AutoPipelinesRuns with all computed pipelines computed by AutoAi on WML."""
         pass
 
     @abstractmethod
