@@ -37,14 +37,11 @@ if TYPE_CHECKING:
 
 
 class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
-    """
-    LocalAutoPipelinesRuns class is used to work with historical Optimizer runs (local optimizer and
+    """LocalAutoPipelinesRuns class is used to work with historical Optimizer runs (local optimizer and
     with with data from COS, without WML API interaction).
 
-    Parameters
-    ----------
-    filter: str, optional
-        Filter, user can choose which runs to fetch specifying experiment name. (option not yet available)
+    :param filter: filter, user can choose which runs to fetch specifying experiment name (option not yet available)
+    :type filter: str, optional
     """
 
     def __init__(self, filter: str = None) -> None:
@@ -69,46 +66,45 @@ class LocalAutoPipelinesRuns(BaseAutoPipelinesRuns):
                       metadata: Dict[str, Union[List['DataConnection'],  'DataConnection', str, int]] = None,
                       wml_client: 'APIClient' = None
                       ) -> Union['LocalAutoPipelines', 'RemoteAutoPipelines']:
-        """
-        Get historical optimizer from historical experiment.
+        """Get historical optimizer from historical experiment.
 
-        Parameters
-        ----------
-        run_id: str, optional
-            ID of the local historical experiment run. (option not yet available)
+        :param run_id: ID of the local historical experiment run (option not yet available)
+        :type run_id: str, optional
 
-        metadata: dict, optional
-            Option to pass information about COS data reference or WSD (auto-gen notebook)
+        :param metadata: option to pass information about COS data reference or WSD (auto-gen notebook)
+        :type metadata: dict, optional
 
-        wml_client: ApiClient, optional
-            Only for Container type to work properly
+        :param wml_client: only for Container type to work properly
+        :type wml_client: ApiClient, optional
 
-        Example
-        -------
-        >>> metadata = dict(
-        >>>        prediction_type ='classification',
-        >>>        prediction_column='species',
-        >>>        holdout_size=0.2,
-        >>>        scoring='roc_auc',
-        >>>        max_number_of_estimators=1,
-        >>>        training_data_reference = [DataConnection(
-        >>>            connection_asset_id=connection_id,
-        >>>            location=S3Location(
-        >>>                bucket='autoai-bucket',
-        >>>                path='iris_dataset.csv',
-        >>>            )
-        >>>        )],
-        >>>        training_result_reference = DataConnection(
-        >>>            connection_asset_id=connection_id,
-        >>>            location=S3Location(
-        >>>                bucket='autoai-bucket',
-        >>>                path='.',
-        >>>                model_location="0a8266be-0f3e-4ef9-af89-856022b7c1c9/data/automl/global_output/",
-        >>>                training_status="./75eec2e0-2600-4b7e-bcf2-ea54f2471400/9236e3ab-25e2-4daa-86a8-fd009d4e1e7d/training-status.json",
-        >>>            )
-        >>>        )
-        >>>    )
-        >>> optimizer = AutoAI().runs.get_optimizer(metadata)
+        **Example**
+
+        .. code-block:: python
+
+            metadata = dict(
+                   prediction_type ='classification',
+                   prediction_column='species',
+                   holdout_size=0.2,
+                   scoring='roc_auc',
+                   max_number_of_estimators=1,
+                   training_data_reference = [DataConnection(
+                       connection_asset_id=connection_id,
+                       location=S3Location(
+                           bucket='autoai-bucket',
+                           path='iris_dataset.csv',
+                       )
+                   )],
+                   training_result_reference = DataConnection(
+                       connection_asset_id=connection_id,
+                       location=S3Location(
+                           bucket='autoai-bucket',
+                           path='.',
+                           model_location="0a8266be-0f3e-4ef9-af89-856022b7c1c9/data/automl/global_output/",
+                           training_status="./75eec2e0-2600-4b7e-bcf2-ea54f2471400/9236e3ab-25e2-4daa-86a8-fd009d4e1e7d/training-status.json",
+                       )
+                   )
+               )
+            optimizer = AutoAI().runs.get_optimizer(metadata)
         """
 
         if run_id is not None:
