@@ -20,17 +20,13 @@ __all__ = [
 
 
 class BaseExperiment(ABC):
-    """
-    Base abstract class for Experiment.
-    """
+    """Base abstract class for Experiment."""
 
     @abstractmethod
     def runs(self, *, filter: str):
         """Get the historical runs but with WML Pipeline name filter.
 
-        Parameters
-        ----------
-        filter: str, required
-            WML Pipeline name to filter the historical runs.
+        :param filter: WML Pipeline name to filter the historical runs
+        :type filter: str
         """
         pass
