@@ -329,7 +329,7 @@ class Experiments(WMLResource):
         self._list(experiment_values, header_list, limit, _DEFAULT_LIST_LENGTH)
 
     def create_revision(self, experiment_id):
-        """Creates a new experiment revision.
+        """Create a new experiment revision.
 
         :param experiment_id: Unique Id of the stored experiment
         :type experiment_id: str
@@ -421,7 +421,7 @@ class Experiments(WMLResource):
             self._list(experiment_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
 
     def clone(self, experiment_uid, space_id=None, action="copy", rev_id=None):
-        """Creates a new experiment identical with the given experiment either in the same space or in a new space.
+        """Create a new experiment identical with the given experiment either in the same space or in a new space.
         All dependent assets will be cloned too.
 
         :param experiment_uid:  Unique Id of the experiment to be cloned
