@@ -14,7 +14,6 @@
 
 from __future__ import print_function
 import ibm_watson_machine_learning._wrappers.requests as requests
-from ibm_watson_machine_learning.utils import STR_TYPE, STR_TYPE_NAME, docstring_parameter, meta_props_str_conv
 from ibm_watson_machine_learning.metanames import ExportMetaNames
 import os
 import json
@@ -29,56 +28,59 @@ class Export(WMLResource):
         self._client = client
         self.ConfigurationMetaNames = ExportMetaNames()
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def start(self, meta_props, space_id=None, project_id=None):
-        """
-            Start the export. Either space_id or project_id has to be provided and is mandatory.
-            ALL_ASSETS is by default False. No need to provide explicitly unless it has to be set to True
-            Either ALL_ASSETS or ASSET_TYPES or ASSET_IDS has to be given in the meta_props. Only one of these can be
-            provided
+        """Start the export. Either space_id or project_id has to be provided and is mandatory.
+        ALL_ASSETS is by default False. No need to provide explicitly unless it has to be set to True.
+        Either ALL_ASSETS or ASSET_TYPES or ASSET_IDS has to be given in the meta_props. Only one of these can be
+        provided.
 
-            In the meta_props:
+        In the `meta_props`:
 
-            ALL_ASSETS is a boolean. When set to True, it exports all assets in the given space
-            ASSET_IDS is an array containing the list of assets ids to be exported
-            ASSET_TYPES is for providing the asset types to be exported. All assets of that asset type will be exported
-                        Eg: wml_model, wml_model_definition, wml_pipeline, wml_function, wml_experiment,
-                        software_specification, hardware_specification, package_extension, script
+        ALL_ASSETS is a boolean. When set to True, it exports all assets in the given space.
+        ASSET_IDS is an array containing the list of assets ids to be exported.
+        ASSET_TYPES is for providing the asset types to be exported. All assets of that asset type will be exported.
 
-           **Parameters**
+                Eg: wml_model, wml_model_definition, wml_pipeline, wml_function, wml_experiment,
+                software_specification, hardware_specification, package_extension, script
 
-           .. important::
-                #. **meta_props**:  meta data. To see available meta names use **client.export_assets.ConfigurationMetaNames.get()\n
-                   **type**: dict\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
+        :param meta_props: meta data,
+            to see available meta names use ``client.export_assets.ConfigurationMetaNames.get()``
+        :type meta_props: dict
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project: str, optional
 
-           **Output**
+        :return: Response json
+        :rtype: dict
 
-           .. important::
-                **returns**: Response json\n
-                **return type**: dict\n
+        **Example**
 
-           **Example**
+        .. code-block:: python
 
-                >>> metadata = {
-                >>>    client.export_assets.ConfigurationMetaNames.NAME: "export_model",
-                >>>    client.export_assets.ConfigurationMetaNames.ASSET_IDS: ["13a53931-a8c0-4c2f-8319-c793155e7517", "13a53931-a8c0-4c2f-8319-c793155e7518"]
-                >>> }
-                >>> details = client.export_assets.start(meta_props=metadata, space_id="98a53931-a8c0-4c2f-8319-c793155e4598")
+            metadata = {
+                client.export_assets.ConfigurationMetaNames.NAME: "export_model",
+                client.export_assets.ConfigurationMetaNames.ASSET_IDS: ["13a53931-a8c0-4c2f-8319-c793155e7517",
+                                                                        "13a53931-a8c0-4c2f-8319-c793155e7518"]}
 
-                >>> metadata = {
-                >>>    client.export_assets.ConfigurationMetaNames.NAME: "export_model",
-                >>>    client.export_assets.ConfigurationMetaNames.ASSET_TYPES: ["wml_model"],
-                >>> }
-                >>> details = client.export_assets.start(meta_props=metadata, space_id="98a53931-a8c0-4c2f-8319-c793155e4598")
+            details = client.export_assets.start(meta_props=metadata, space_id="98a53931-a8c0-4c2f-8319-c793155e4598")
+
+        .. code-block:: python
+
+            metadata = {
+                client.export_assets.ConfigurationMetaNames.NAME: "export_model",
+                client.export_assets.ConfigurationMetaNames.ASSET_TYPES: ["wml_model"]}
+
+            details = client.export_assets.start(meta_props=metadata, space_id="98a53931-a8c0-4c2f-8319-c793155e4598")
+
+        .. code-block:: python
+
+            metadata = {
+                client.export_assets.ConfigurationMetaNames.NAME: "export_model",
+                client.export_assets.ConfigurationMetaNames.ALL_ASSETS: True}
+
+            details = client.export_assets.start(meta_props=metadata, space_id="98a53931-a8c0-4c2f-8319-c793155e4598")
 
-                >>> metadata = {
-                >>>    client.export_assets.ConfigurationMetaNames.NAME: "export_model",
-                >>>    client.export_assets.ConfigurationMetaNames.ALL_ASSETS: True,
-                >>> }
             """
         WMLResource._chk_and_block_create_update_for_python36(self)
 
@@ -165,37 +167,33 @@ class Export(WMLResource):
         if count > 1:
             raise WMLClientError("Only one of 'ALL_ASSETS' or 'ASSET_IDS' or 'ASSET_TYPES' can be provided")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def cancel(self, export_id, space_id=None, project_id=None):
-        """
-            Cancel an export job. 'export_id' and 'space_id'( or 'project_id' has to be provided )
-            Note: To delete a export_id job, use delete() api
+        """Cancel an export job. `space_id` or `project_id` has to be provided.
 
-            **Parameters**
+        .. note::
+            To delete a `export_id` job, use ``delete()`` api.
 
-            .. important::
-                #. **export_id**:  Export job identifier\n
-                   **type**: str\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
+        :param export_id: export job identifier
+        :type export_id: str
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
 
-            **Output**
+        :returns: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        **Example**
 
-            **Example**
+        .. code-block:: python
 
-             >>> client.export_assets.cancel(export_id='6213cf1-252f-424b-b52d-5cdd9814956c',
-             >>>                      space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
+            client.export_assets.cancel(export_id='6213cf1-252f-424b-b52d-5cdd9814956c',
+                                        space_id='3421cf1-252f-424b-b52d-5cdd981495fe')
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
 
-        Export._validate_type(export_id, u'export_id', STR_TYPE, True)
+        Export._validate_type(export_id, u'export_id', str, True)
 
         if space_id is None and project_id is None:
             raise WMLClientError("Its mandatory to provide space_id or project_id")
@@ -223,31 +221,25 @@ class Export(WMLResource):
         if "SUCCESS" == details:
             print("Export job cancelled")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def delete(self, export_id, space_id=None, project_id=None):
-        """
-            Deletes the given export_id job. 'space_id' or 'project_id' has to be provided
+        """Deletes the given `export_id` job. `space_id` or `project_id` has to be provided.
 
-            **Parameters**
+        :param export_id: export job identifier
+        :type export_id: str
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
 
-            .. important::
-                #. **export_id**:  Export job identifier\n
-                   **type**: str\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.export_assets.delete(export_id='6213cf1-252f-424b-b52d-5cdd9814956c',
-             >>>                      space_id= '98a53931-a8c0-4c2f-8319-c793155e4598')
+            client.export_assets.delete(export_id='6213cf1-252f-424b-b52d-5cdd9814956c',
+                                        space_id= '98a53931-a8c0-4c2f-8319-c793155e4598')
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
@@ -258,7 +250,7 @@ class Export(WMLResource):
         if space_id is not None and project_id is not None:
             raise WMLClientError("Either 'space_id' or 'project_id' can be provided, not both")
 
-        Export._validate_type(export_id, u'export_id', STR_TYPE, True)
+        Export._validate_type(export_id, u'export_id', str, True)
 
         href = self._client.service_instance._href_definitions.export_href(export_id)
 
@@ -280,48 +272,38 @@ class Export(WMLResource):
         if "SUCCESS" == details:
             print("Export job deleted")
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
-    def get_details(self, export_id=None, space_id=None, project_id=None, limit=None, asynchronous=False, get_all=False):
+    def get_details(self, export_id=None, space_id=None, project_id=None, limit=None, asynchronous=False,
+                    get_all=False):
+        """Get metadata of the given export job. if no `export_id` is specified all exports metadata is returned.
+
+        :param export_id: export job identifier
+        :type export_id: str, optional
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all: if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
+
+        :return: export(s) metadata
+        :rtype: dict (if export_id is not None) or {"resources": [dict]} (if export_id is None)
+
+        **Example**
+
+        .. code-block:: python
+
+            details = client.export_assets.get_details(export_id, space_id= '98a53931-a8c0-4c2f-8319-c793155e4598')
+            details = client.export_assets.get_details()
+            details = client.export_assets.get_details(limit=100)
+            details = client.export_assets.get_details(limit=100, get_all=True)
+            details = []
+            for entry in client.export_assets.get_details(limit=100, asynchronous=True, get_all=True):
+                details.extend(entry)
         """
-            Get metadata of the given export job. if no export_id is specified all
-            exports metadata is returned.
-
-           **Parameters**
-
-           .. important::
-                #. **export_id**: export job identifier (optional)\n
-                   **type**: str\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
-                #. **limit**:  limit number of fetched records (optional)\n
-                   **type**: int\n
-                #. **asynchronous**:  if True, it will work as a generator (optional)\n
-                   **type**: bool\n
-                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-                   **type**: bool\n
-
-           **Output**
-
-           .. important::
-                **returns**: export(s) metadata\n
-                **return type**: dict\n
-                dict (if export_id is not None) or {"resources": [dict]} (if export_id is None)\n
-
-           .. note::
-                If export_id is not specified, all export(s) metadata is fetched\n
-
-           **Example**
-
-             >>> details = client.export_assets.get_details(export_id, space_id= '98a53931-a8c0-4c2f-8319-c793155e4598')
-             >>> details = client.export_assets.get_details()
-             >>> details = client.export_assets.get_details(limit=100)
-             >>> details = client.export_assets.get_details(limit=100, get_all=True)
-             >>> details = []
-             >>> for entry in client.export_assets.get_details(limit=100, asynchronous=True, get_all=True):
-             >>>    details.extend(entry)
-         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
 
@@ -331,7 +313,7 @@ class Export(WMLResource):
         if space_id is not None and project_id is not None:
             raise WMLClientError("Either 'space_id' or 'project_id' can be provided, not both")
         
-        Export._validate_type(export_id, u'export_id', STR_TYPE, False)
+        Export._validate_type(export_id, u'export_id', str, False)
         Export._validate_type(limit, u'limit', int, False)
 
         href = self._client.service_instance._href_definitions.exports_href()
@@ -351,28 +333,20 @@ class Export(WMLResource):
             return self._get_artifact_details(href, export_id, limit, 'export job', query_params=params)
     
     def list(self, space_id=None, project_id=None, limit=None):
-        """
-            List export jobs. If limit is set to None there will be only first 50 records shown.
+        """Print export jobs in a table format. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all export jobs in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.export_assets.list()
+            client.export_assets.list()
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
@@ -397,28 +371,20 @@ class Export(WMLResource):
         self._list(values, [u'ID', u'NAME', u'CREATED', u'STATUS'], limit, _DEFAULT_LIST_LENGTH)
 
     @staticmethod
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_id(export_details):
-        """
-                Get ID of export job from export details
+        """Get ID of export job from export details.
 
-                **Parameters**
+        :param export_details: metadata of the export job
+        :type export_details: dict
 
-                .. important::
+        :return: ID of the export job
+        :rtype: str
 
-                   #. **export_details**:  Metadata of the export job\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: ID of the export job\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> id = client.export_assets.get_id(export_details)
+            id = client.export_assets.get_id(export_details)
         """
         Export._validate_type(export_details, u'export_details', object, True)
 
@@ -426,37 +392,30 @@ class Export(WMLResource):
                                                            u'export_details',
                                                            [u'metadata', u'id'])
 
-    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_exported_content(self, export_id, space_id=None, project_id=None, file_path=None):
-        """
-            Get the exported content as a zip file
+        """Get the exported content as a zip file.
 
-            **Parameters**
-
-            .. important::
-                #. **export_id**:  export job identifier\n
-                   **type**: str\n
-                #. **space_id**:  Space identifier\n
-                   **type**: str\n
-                #. **project_id**:  Project identifier\n
-                   **type**: str\n
-                #. **file_path**:  name of local file to create. This should be absolute path of the file and
-                                  the file shouldn't exist\n
-                   **type**: str\n
+        :param export_id: export job identifier
+        :type export_id: str
+        :param space_id: space identifier
+        :type space_id: str, optional
+        :param project_id: project identifier
+        :type project_id: str, optional
+        :param file_path: name of local file to create, this should be absolute path of the file
+            and the file shouldn't exist
+        :type file_path: str, optional
 
 
-            **Output**
+        :return: path to the downloaded function content
+        :rtype: str
 
-            .. important::
+        **Example**
 
-               **returns**: Path to the downloaded function content\n
-               **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.exports.get_exported_content(export_id,
-             >>>                                     space_id= '98a53931-a8c0-4c2f-8319-c793155e4598'
-             >>>                                     file_path='/home/user/my_exported_content.zip')
+            client.exports.get_exported_content(export_id,
+                                                space_id='98a53931-a8c0-4c2f-8319-c793155e4598',
+                                                file_path='/home/user/my_exported_content.zip')
         """
         if not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Not supported in this release")
@@ -477,7 +436,7 @@ class Export(WMLResource):
         if os.path.isfile(file_path):
             raise WMLClientError(u'File with name: \'{}\' already exists.'.format(file_path))
 
-        Export._validate_type(file_path, u'file_path', STR_TYPE, True)
+        Export._validate_type(file_path, u'file_path', str, True)
 
         href = self._client.service_instance._href_definitions.export_content_href(export_id)
 
