@@ -25,7 +25,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Functions(WMLResource):
-    """Store and manage your functions."""
+    """Store and manage functions."""
 
     # ConfigurationMetaNames = FunctionMetaNames()
     #"""MetaNames for python functions creation."""
@@ -689,7 +689,7 @@ class Functions(WMLResource):
             self._list(function_values, [u'GUID', u'NAME', u'CREATED', u'TYPE'], limit, _DEFAULT_LIST_LENGTH)
 
     def clone(self, function_uid, space_id=None, action="copy", rev_id=None):
-        """Creates a new function identical with the given function either in the same space or in a new space.
+        """Create a new function identical with the given function either in the same space or in a new space.
         All dependent assets will be cloned too.
 
         :param function_uid: UID of the function to be cloned
@@ -774,9 +774,9 @@ class Functions(WMLResource):
         :type function_uid: str
 
         :param rev_uid: Unique id of the function revision
-        :type rev_uid : int
+        :type rev_uid: int
 
-        :returns: stored function revision metadata
+        :return: stored function revision metadata
         :rtype: dict
 
         **Example**
