@@ -21,10 +21,8 @@ __all__ = [
 
 
 class BaseConnection(ABC):
-    """
-    Base class for storage Connections.
-    """
+    """Base class for storage Connections."""
 
     def to_dict(self) -> dict:
-        """Return a json dictionary representing this model."""
+        """Get a json dictionary representing this model."""
         return vars(self)
