@@ -39,9 +39,7 @@ if TYPE_CHECKING:
 
 
 class BaseDataConnection(ABC):
-    """
-    Base class for  DataConnection.
-    """
+    """Base class for DataConnection."""
 
     def __init__(self):
 
@@ -80,9 +78,7 @@ class BaseDataConnection(ABC):
     def _fill_experiment_parameters(self, prediction_type: str, prediction_column: str, holdout_size: float,
                                     csv_separator: str = ',', excel_sheet: Union[str, int] = None,
                                     encoding: str = 'utf-8') -> None:
-        """
-        To be able to recreate a holdout split, this method need to be called.
-        """
+        """To be able to recreate a holdout split, this method need to be called."""
         self.auto_pipeline_params = {
             'prediction_type': prediction_type,
             'prediction_column': prediction_column,
@@ -404,7 +400,7 @@ class BaseDataConnection(ABC):
                 return False  # if we are in WS, ignore this check even if there was some error
 
     def _is_data_asset_normal(self) -> bool:
-        """Returns true if data asset is normal data asset - not connected data asset"""
+        """Returns `True` if data asset is normal data asset - not connected data asset."""
         try:
             if self.type == 'data_asset':
                 if self.connection is not None and hasattr(self.connection, 'href'):
