@@ -20,11 +20,9 @@ __all__ = [
 
 
 class BaseLocation(ABC):
-    """
-    Base class for storage Location.
-    """
+    """Base class for storage Location."""
     def to_dict(self) -> dict:
-        """Return a json dictionary representing this model."""
+        """Get a json dictionary representing this model."""
         return vars(self)
 
     def _get_file_size(self, **kwargs) -> 'int':
