@@ -69,24 +69,24 @@ if TYPE_CHECKING:
 
 
 class DataConnection(BaseDataConnection):
-    """
-    Data Storage Connection class needed for WML training metadata (input data).
+    """Data Storage Connection class needed for WML training metadata (input data).
 
-    Parameters
-    ----------
-    connection: Union['NFSConnection', 'ConnectionAsset'], optional
-        connection parameters of specific type
+    :param connection: connection parameters of specific type
+    :type connection: NFSConnection or ConnectionAsset, optional
 
-    location: Union[S3Location, FSLocation, AssetLocation],
-        required location parameters of specific type
+    :param location: required location parameters of specific type
+    :type location: Union[S3Location, FSLocation, AssetLocation]
 
-    data_join_node_name: Union[str, List[str]], optional
-        Names for node(s). If no value provided, data file name will be used as node name. If str will be passed,
-        it will became node name. If multiple names will be passed, several nodes will have the same data connection
-        (used for excel files with multiple sheets).
+    :param data_join_node_name: name(s) for node(s):
 
-    data_asset_id: str, optional,
-        Data asset ID if DataConnection should be pointing out to Data Asset.
+        - `None` - data file name will be used as node name
+        - str - it will became node name
+        - list[str] - multiple names passed, several nodes will have the same data connection
+          (used for excel files with multiple sheets)
+    :type data_join_node_name:  None or str or list[str], optional
+
+    :param data_asset_id: data asset ID if DataConnection should be pointing out to data asset
+    :type data_asset_id: str, optional
     """
 
     def __init__(self,
@@ -192,17 +192,16 @@ class DataConnection(BaseDataConnection):
             self.location.userfs = True
 
     def set_client(self, wml_client):
-        """
-        Set initialized wml client in connection to enable write/read operations with connection to service.
+        """Set initialized wml client in connection to enable write/read operations with connection to service.
 
-        Parameters
-        ----------
-        wml_client: APIClient, required
-            Wml client to connect to service.
+        :param wml_client: WML client to connect to service
+        :type wml_client: APIClient
 
-        Example
-        -------
-        >>> DataConnection.set_client(wml_client)
+        **Example**
+
+        .. code-block:: python
+
+            DataConnection.set_client(wml_client)
         """
         self._wml_client = wml_client
 
@@ -210,21 +209,19 @@ class DataConnection(BaseDataConnection):
 
     @classmethod
     def from_studio(cls, path: str) -> List['DataConnection']:
-        """
-        Create DataConnections from the credentials stored (connected) in Watson Studio. Only for COS.
+        """Create DataConnections from the credentials stored (connected) in Watson Studio. Only for COS.
 
-        Parameters
-        ----------
-        path: str, required
-            Path in COS bucket to the training dataset.
+        :param path: path in COS bucket to the training dataset
+        :type path: str
 
-        Returns
-        -------
-        List with DataConnection objects.
+        :return: list with DataConnection objects
+        :rtype: list[DataConnection]
 
-        Example
-        -------
-        >>> data_connections = DataConnection.from_studio(path='iris_dataset.csv')
+        **Example**
+
+        .. code-block:: python
+
+            data_connections = DataConnection.from_studio(path='iris_dataset.csv')
         """
         try:
             from project_lib import Project
@@ -272,12 +269,10 @@ class DataConnection(BaseDataConnection):
             return [cpy(id) for id in self.id]
 
     def _to_dict(self) -> dict:
-        """
-        Convert DataConnection object to dictionary representation.
+        """Convert DataConnection object to dictionary representation.
 
-        Returns
-        -------
-        Dictionary
+        :return: DataConnection dictionary representation
+        :rtype: dict
         """
 
         if self.id and type(self.id) is list:
@@ -316,17 +311,13 @@ class DataConnection(BaseDataConnection):
 
     @classmethod
     def _from_dict(cls, _dict: dict) -> 'DataConnection':
-        """
-        Create a DataConnection object from dictionary
+        """Create a DataConnection object from dictionary.
 
-        Parameters
-        ----------
-        _dict: dict, required
-            A dictionary data structure with information about data connection reference.
+        :param _dict: a dictionary data structure with information about data connection reference
+        :type _dict: dict
 
-        Returns
-        -------
-        DataConnection
+        :return: DataConnection object
+        :rtype: DataConnection
         """
         # TODO: remove S3 implementation
         if _dict['type'] == DataConnectionTypes.S3:
@@ -443,6 +434,33 @@ class DataConnection(BaseDataConnection):
             y_train = DataFrame(y_train, columns=self.auto_pipeline_params['prediction_columns'])
             y_holdout = DataFrame(y_holdout, columns=self.auto_pipeline_params['prediction_columns'])
 
+            return X_train, X_holdout, y_train, y_holdout
+        elif self.auto_pipeline_params.get('feature_columns') is not None:
+            # timeseries anomaly detection
+            try_import_autoai_ts_libs()
+            from autoai_ts_libs.utils.holdout_utils import make_holdout_split
+            from autoai_ts_libs.utils.constants import LEARNING_TYPE_TIMESERIES_ANOMALY_PREDICTION
+
+            # Note: imputation is not supported
+            X_train, X_holdout, y_train, y_holdout, _, _, _, _ = make_holdout_split(
+                dataset=data,
+                learning_type=LEARNING_TYPE_TIMESERIES_ANOMALY_PREDICTION,
+                test_size=self.auto_pipeline_params.get('holdout_size'),
+                # lookback_window=self.auto_pipeline_params.get('lookback_window'),
+                feature_columns=self.auto_pipeline_params.get('feature_columns'),
+                timestamp_column=self.auto_pipeline_params.get('timestamp_column_name'),
+                # n_jobs=None,
+                # tshirt_size=None,
+                return_only_holdout=False
+            )
+
+            X_columns = self.auto_pipeline_params['feature_columns']
+
+            X_train = DataFrame(X_train, columns=X_columns)
+            X_holdout = DataFrame(X_holdout, columns=X_columns)
+            y_train = DataFrame(y_train, columns=X_columns)
+            y_holdout = DataFrame(y_holdout, columns=X_columns)
+
             return X_train, X_holdout, y_train, y_holdout
 
         else:
@@ -533,97 +551,89 @@ class DataConnection(BaseDataConnection):
              sample_rows_limit: Optional[int] = None,
              sample_percentage_limit: Optional[float] = None,
              **kwargs) -> Union['DataFrame', Tuple['DataFrame', 'DataFrame'], bytes]:
-        """
-        Download dataset stored in remote data storage. Returns batch up to 1GB.
+        """Download dataset stored in remote data storage. Returns batch up to 1GB.
 
-        Parameters
-        ----------
-        with_holdout_split: bool, optional
-            If True, data will be split to train and holdout dataset as it was by AutoAI.
+        :param with_holdout_split: if `True`, data will be split to train and holdout dataset as it was by AutoAI
+        :type with_holdout_split: bool, optional
 
-        csv_separator: str, optional
-            Separator / delimiter for CSV file, default is ','
+        :param csv_separator: separator / delimiter for CSV file
+        :type csv_separator: str, optional
 
-        excel_sheet: Union[str, int], optional
-            Excel file sheet name to use. Only use when xlsx file is an input. Support for number of the sheet is deprecated.
+        :param excel_sheet: excel file sheet name to use, only use when xlsx file is an input,
+            support for number of the sheet is deprecated
+        :type excel_sheet: str, optional
 
-        encoding: str, optional
-            Encoding type of the CSV
+        :param encoding: encoding type of the CSV
+        :type encoding: str, optional
 
-        raw: bool, optional
-            Default False. If False there wil be applied simple data preprocessing (the same as in the backend).
-            If True, data will be not preprocessed.
+        :param raw: if `False` there wil be applied simple data preprocessing (the same as in the backend),
+            if `True`, data will be not preprocessed
+        :type raw: bool, optional
 
-        binary: bool, optional
-            Indicates to retrieve data in binary mode. The result will be a python binary type variable.
-            Default False.
+        :param binary: indicates to retrieve data in binary mode, the result will be a python binary type variable
+        :type binary: bool, optional
 
-        read_to_file: str, optional
-            Stream read data to file under path specified as value of this parameter.
-            Use this parameter to prevent keeping data in-memory.
+        :param read_to_file: stream read data to file under path specified as value of this parameter,
+            use this parameter to prevent keeping data in-memory
+        :type read_to_file: str, optional
 
-        number_of_batch_rows: int, optional
-            Number of rows to read in each batch when reading from flight connection.
+        :param number_of_batch_rows: number of rows to read in each batch when reading from flight connection
+        :type number_of_batch_rows: int, optional
 
-        sampling_type: str, optional
-            A sampling strategy how to read the data.
+        :param sampling_type: a sampling strategy how to read the data
+        :type sampling_type: str, optional
 
-        sample_size_limit: int, optional
-            Upper limit for overall data that should be downloaded in bytes, Default: 1 GB. If more than one of:
-            sample_size_limit, sample_rows_limit, sample_percentage_limit are set, then downloaded data is limited to the lowest threshold.
+        :param sample_size_limit: upper limit for overall data that should be downloaded in bytes, default: 1 GB
+        :type sample_size_limit: int, optional
 
-        sample_rows_limit: int, optional
-            Upper limit for overall data that should be downloaded in number of rows. If more than one of:
-            sample_size_limit, sample_rows_limit, sample_percentage_limit are set, then downloaded data is limited to the lowest threshold.
+        :param sample_rows_limit: upper limit for overall data that should be downloaded in number of rows
+        :type sample_rows_limit: int, optional
 
-        sample_percentage_limit: float, optional
-            Upper limit for overall data that should be downloaded in percent of all dataset.
-            This parameter is ignored, when `sampling_type` parameter is set to `first_n_records`.
-            Must be a float number between 0 and 1. If more than one of:
-            sample_size_limit, sample_rows_limit, sample_percentage_limit are set, then downloaded data is limited to the lowest threshold.
+        :param sample_percentage_limit: upper limit for overall data that should be downloaded
+            in percent of all dataset, this parameter is ignored, when `sampling_type` parameter is set
+            to `first_n_records`, must be a float number between 0 and 1
+        :type sample_percentage_limit: float, optional
 
-        Returns
-        -------
-        pandas.DataFrame contains dataset from remote data storage : Xy_train
+        .. note::
 
-        or
+            If more than one of: `sample_size_limit`, `sample_rows_limit`, `sample_percentage_limit` are set,
+            then downloaded data is limited to the lowest threshold.
 
-        Tuple[pandas.DataFrame, pandas.DataFrame, pandas.DataFrame, pandas.DataFrame] : X_train, X_holdout, y_train, y_holdout
+        :return: one of:
 
-        or
+            - pandas.DataFrame contains dataset from remote data storage : Xy_train
+            - Tuple[pandas.DataFrame, pandas.DataFrame, pandas.DataFrame, pandas.DataFrame] : X_train, X_holdout, y_train, y_holdout
+            - Tuple[pandas.DataFrame, pandas.DataFrame] : X_test, y_test containing training data and holdout data from
+              remote storage
+            - bytes object, auto holdout split from backend (only train data provided)
 
-        Tuple[pandas.DataFrame, pandas.DataFrame] : X_test, y_test
-        containing training data and holdout data from remote storage.
+        **Examples**
 
-        or
+        .. code-block:: python
 
-        bytes object
+            train_data_connections = optimizer.get_data_connections()
 
-        Auto holdout split from backend (only train data provided)
+            data = train_data_connections[0].read() # all train data
 
-        Example
-        -------
-        >>> train_data_connections = optimizer.get_data_connections()
-        >>>
-        >>> data = train_data_connections[0].read() # all train data
-        >>> # or
-        >>> X_train, X_holdout, y_train, y_holdout = train_data_connections[0].read(with_holdout_split=True) # train and holdout data
+            # or
 
-        User provided train and test data
+            X_train, X_holdout, y_train, y_holdout = train_data_connections[0].read(with_holdout_split=True) # train and holdout data
 
-        Example
-        -------
-        >>> optimizer.fit(training_data_reference=[DataConnection],
-        >>>               training_results_reference=DataConnection,
-        >>>               test_data_reference=DataConnection)
-        >>>
-        >>> test_data_connection = optimizer.get_test_data_connections()
-        >>> X_test, y_test = test_data_connection.read() # only holdout data
-        >>>
-        >>> # and
-        >>>
-        >>> train_data_connections = optimizer.get_data_connections()
-        >>> data = train_connections[0].read() # only train data
+        User provided train and test data:
+
+        .. code-block:: python
+
+            optimizer.fit(training_data_reference=[DataConnection],
+                          training_results_reference=DataConnection,
+                          test_data_reference=DataConnection)
+
+            test_data_connection = optimizer.get_test_data_connections()
+            X_test, y_test = test_data_connection.read() # only holdout data
+
+            # and
+
+            train_data_connections = optimizer.get_data_connections()
+            data = train_connections[0].read() # only train data
         """
 
         # enables flight automatically for CP4D 4.0.x, 4.5.x, for 3.0 and 3.5 we do not have a flight service there
@@ -924,7 +934,8 @@ class DataConnection(BaseDataConnection):
             return data
 
         if raw or (self.auto_pipeline_params.get('prediction_column') is None
-                   and self.auto_pipeline_params.get('prediction_columns') is None):
+                   and self.auto_pipeline_params.get('prediction_columns') is None
+                   and self.auto_pipeline_params.get('feature_columns') is None):
             return data
 
         else:
@@ -969,16 +980,13 @@ class DataConnection(BaseDataConnection):
                     return test_X  # return one dataframe
 
     def write(self, data: Union[str, 'DataFrame'], remote_name: str = None, **kwargs) -> None:
-        """
-        Upload file to a remote data storage.
+        """Upload file to a remote data storage.
 
-        Parameters
-        ----------
-        data: str, required
-            Local path to the dataset or pandas.DataFrame with data.
+        :param data: local path to the dataset or pandas.DataFrame with data
+        :type data: str
 
-        remote_name: str, required
-            Name that dataset should be stored with in remote data storage.
+        :param remote_name: name that dataset should be stored with in remote data storage
+        :type remote_name: str
         """
         # enables flight automatically for CP4D 4.0.x, for 3.0 and 3.5 we do not have a flight service there
         use_flight = kwargs.get(
@@ -1173,33 +1181,31 @@ class DataConnection(BaseDataConnection):
 
 # TODO: Remove S3 Implementation for connection
 class S3Connection(BaseConnection):
-    """
-    Connection class to COS data storage in S3 format.
+    """Connection class to COS data storage in S3 format.
 
-    Parameters
-    ----------
-    endpoint_url: str, required
-        S3 data storage url (COS)
+    :param endpoint_url: S3 data storage url (COS)
+    :type endpoint_url: str
 
-    access_key_id: str, optional
-        access_key_id of the S3 connection (COS)
+    :param access_key_id: access_key_id of the S3 connection (COS)
+    :type access_key_id: str, optional
 
-    secret_access_key: str, optional
-        secret_access_key of the S3 connection (COS)
+    :param secret_access_key: secret_access_key of the S3 connection (COS)
+    :type secret_access_key: str, optional
 
-    api_key: str, optional
-        API key of the S3 connection (COS)
+    :param api_key: API key of the S3 connection (COS)
+    :type api_key: str, optional
 
-    service_name: str, optional
-        Service name of the S3 connection (COS)
+    :param service_name: service name of the S3 connection (COS)
+    :type service_name: str, optional
 
-    auth_endpoint: str, optional
-        Authentication endpoint url of the S3 connection (COS)
+    :param auth_endpoint: authentication endpoint url of the S3 connection (COS)
+    :type auth_endpoint: str, optional
     """
 
     def __init__(self, endpoint_url: str, access_key_id: str = None, secret_access_key: str = None,
                  api_key: str = None, service_name: str = None, auth_endpoint: str = None,
                  resource_instance_id: str = None, _internal_use=False) -> None:
+
         if not _internal_use:
             warn(message="S3 DataConnection is deprecated! Please use data_asset_id instead.")
 
@@ -1230,25 +1236,22 @@ class S3Connection(BaseConnection):
 
 
 class S3Location(BaseLocation):
-    """
-    Connection class to COS data storage in S3 format.
+    """Connection class to COS data storage in S3 format.
 
-    Parameters
-    ----------
-    bucket: str, required
-        COS bucket name
+    :param bucket: COS bucket name
+    :type bucket: str
 
-    path: str, required
-        COS data path in the bucket.
+    :param path: COS data path in the bucket
+    :type path: str
 
-    excel_sheet: str, optional
-        Name of excel sheet if pointed dataset is excel file used for Batched Deployment scoring.
+    :param excel_sheet: name of excel sheet if pointed dataset is excel file used for Batched Deployment scoring
+    :type excel_sheet: str, optional
 
-    model_location: str, optional
-        Path to the pipeline model in the COS.
+    :param model_location: path to the pipeline model in the COS
+    :type model_location: str, optional
 
-    training_status: str, optional
-        Path t the training status json in COS.
+    :param training_status: path to the training status json in COS
+    :type training_status: str, optional
     """
 
     def __init__(self, bucket: str, path: str, **kwargs) -> None:
@@ -1280,9 +1283,7 @@ class S3Location(BaseLocation):
 
 
 class ContainerLocation(BaseLocation):
-    """
-    Connection class to default COS in user Project/Space.
-    """
+    """Connection class to default COS in user Project/Space."""
 
     def __init__(self, path: Optional[str] = None, **kwargs) -> None:
         if path is None:
@@ -1318,9 +1319,7 @@ class ContainerLocation(BaseLocation):
 
 
 class FSLocation(BaseLocation):
-    """
-    Connection class to File Storage in CP4D.
-    """
+    """Connection class to File Storage in CP4D."""
 
     def __init__(self, path: Optional[str] = None) -> None:
         if path is None:
@@ -1570,23 +1569,20 @@ class AssetLocation(BaseLocation):
 
 
 class ConnectionAssetLocation(BaseLocation):
+    """Connection class to COS data storage.
+
+    :param bucket: COS bucket name
+    :type bucket: str
+
+    :param file_name: COS data path in the bucket
+    :type file_name: str
+
+    :param model_location: path to the pipeline model in the COS
+    :type model_location: str, optional
+
+    :param training_status: path to the training status json in COS
+    :type training_status: str, optional
     """
-        Connection class to COS data storage.
-
-        Parameters
-        ----------
-        bucket: str, required
-            COS bucket name
-
-        file_name: str, required
-            COS data path in the bucket
-
-        model_location: str, optional
-            Path to the pipeline model in the COS.
-
-        training_status: str, optional
-            Path t the training status json in COS.
-        """
 
     def __init__(self, bucket: str, file_name: str, **kwargs) -> None:
         self.bucket = bucket
@@ -1612,13 +1608,10 @@ class ConnectionAssetLocation(BaseLocation):
 
 
 class ConnectionAsset(BaseConnection):
-    """
-    Connection class for Connection Asset
+    """Connection class for Connection Asset.
 
-    Parameters
-    ----------
-    connection_id: str, required
-        Connection asset ID
+    :param connection_id: connection asset ID
+    :type connection_id: str
     """
 
     def __init__(self, connection_id: str):
@@ -1626,13 +1619,10 @@ class ConnectionAsset(BaseConnection):
 
 
 class NFSConnection(BaseConnection):
-    """
-    Connection class to file storage in CP4D of NFS format.
+    """Connection class to file storage in CP4D of NFS format.
 
-    Parameters
-    ----------
-    connection_id: str, required
-        Connection ID from the project on CP4D
+    :param asset_id: asset ID from the project on CP4D
+    :type asset_id: str
     """
 
     def __init__(self, asset_id: str):
@@ -1641,13 +1631,10 @@ class NFSConnection(BaseConnection):
 
 
 class NFSLocation(BaseLocation):
-    """
-    Location class to file storage in CP4D of NFS format.
+    """Location class to file storage in CP4D of NFS format.
 
-    Parameters
-    ----------
-    path: str, required
-        Data path form the project on CP4D.
+    :param path: data path form the project on CP4D
+    :type path: str
     """
 
     def __init__(self, path: str):
@@ -1675,13 +1662,10 @@ class NFSLocation(BaseLocation):
 
 
 class CP4DAssetLocation(AssetLocation):
-    """
-    Connection class to data assets in CP4D.
+    """Connection class to data assets in CP4D.
 
-    Parameters
-    ----------
-    asset_id: str, required
-        Asset ID from the project on CP4D.
+    :param asset_id: asset ID from the project on CP4D
+    :type asset_id: str
     """
 
     def __init__(self, asset_id: str) -> None:
@@ -1695,13 +1679,10 @@ class CP4DAssetLocation(AssetLocation):
 
 
 class WMLSAssetLocation(AssetLocation):
-    """
-    Connection class to data assets in WML Server.
+    """Connection class to data assets in WML Server.
 
-    Parameters
-    ----------
-    asset_id: str, required
-        Asset ID of the file loaded on space in WML Server.
+    :param asset_id: asset ID of the file loaded on space in WML Server
+    :type asset_id: str
     """
 
     def __init__(self, asset_id: str) -> None:
@@ -1715,13 +1696,10 @@ class WMLSAssetLocation(AssetLocation):
 
 
 class CloudAssetLocation(AssetLocation):
-    """
-    Connection class to data assets as input data references to batch deployment job on Cloud.
+    """Connection class to data assets as input data references to batch deployment job on Cloud.
 
-    Parameters
-    ----------
-    asset_id: str, required
-        Asset ID of the file loaded on space on Cloud.
+    :param asset_id: asset ID of the file loaded on space on Cloud
+    :type asset_id: str
     """
 
     def __init__(self, asset_id: str) -> None:
@@ -1736,13 +1714,10 @@ class CloudAssetLocation(AssetLocation):
 
 
 class WSDAssetLocation(BaseLocation):
-    """
-    Connection class to data assets in WS Desktop.
+    """Connection class to data assets in WS Desktop.
 
-    Parameters
-    ----------
-    asset_id: str, required
-        Asset ID from the project on WS Desktop.
+    :param asset_id: asset ID from the project on WS Desktop
+    :type asset_id: str
     """
 
     def __init__(self, asset_id: str) -> None:
@@ -1834,15 +1809,12 @@ class WSDAssetLocation(BaseLocation):
 
 
 class DeploymentOutputAssetLocation(BaseLocation):
-    """
-    Connection class to data assets where output of batch deployment will be stored.
+    """Connection class to data assets where output of batch deployment will be stored.
 
-    Parameters
-    ----------
-    name: str, required
-        name of .csv file which will be saved as data asset.
-    description: str, optional
-        description of the data asset
+    :param name: name of .csv file which will be saved as data asset
+    :type name: str
+    :param description: description of the data asset
+    :type description: str, optional
     """
 
     def __init__(self, name: str, description: str = "") -> None:
@@ -1851,16 +1823,12 @@ class DeploymentOutputAssetLocation(BaseLocation):
 
 
 class DatabaseLocation(BaseLocation):
-    """
-    Location class to Database.
+    """Location class to Database.
 
-    Parameters
-    ----------
-    schema_name: str, required
-        Database schema name.
-
-    table_name: str, required
-        Database table name
+    :param schema_name: database schema name
+    :type schema_name: str
+    :param table_name: database table name
+    :type table_name: str
     """
 
     def __init__(self, schema_name: str, table_name: str, **kwargs) -> None:
