@@ -22,7 +22,7 @@ from typing import List, Optional, Iterable, Generator
 from ibm_watson_machine_learning.utils.autoai.errors import InvalidSamplingType
 from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, SamplingTypes
 from ibm_watson_machine_learning.wml_client_error import (
-    DataStreamError, WrongLocationProperty, WrongFileLocation, SpaceIDandProjectIDCannotBeNone)
+    DataStreamError, WrongLocationProperty, WrongFileLocation, SpaceIDandProjectIDCannotBeNone, EmptyDataSource)
 from ibm_watson_machine_learning.utils.utils import is_lib_installed, prepare_interaction_props_for_cos
 
 is_lib_installed(lib_name='pyarrow', install=True)
@@ -336,7 +336,7 @@ class FlightConnection:
         logger.debug(f"Flight port: {self.flight_port}")
 
     def authenticate(self) -> 'flight.ClientAuthHandler':
-        """Creates an authenticator object for Flight Service."""
+        """Create an authenticator object for Flight Service."""
 
         class TokenClientAuthHandler(flight.ClientAuthHandler):
             """Authenticator implementation from pyarrow flight."""
@@ -503,6 +503,7 @@ class FlightConnection:
             # Reading of batch finished, result commited."
             self._q_put_nowait((thread_number, 0))
 
+
         except Exception as e:
             logger.debug(f"GD {thread_number}: Some error occurred. Error: {e}")
             self._q_put_nowait((thread_number, 0))
@@ -538,9 +539,15 @@ class FlightConnection:
         """Provides unified reading method for flight chunks."""
         logger.debug(f"RC {thread_number}: Waiting for next mini batch from Flight Service...")
         # Flight Service could split one batch into several chunks to have better performance
-        mini_batch, metadata = reader.read_chunk()
-        logger.debug(f"RC {thread_number}: Mini batch received from Flight Service.")
-        data = pa.Table.from_batches(batches=[mini_batch]).to_pandas()
+        try:
+            mini_batch, metadata = reader.read_chunk()
+            logger.debug(f"RC {thread_number}: Mini batch received from Flight Service.")
+            data = pa.Table.from_batches(batches=[mini_batch]).to_pandas()
+        except StopIteration as stop_iteration_error:
+            if self.row_size == 0:
+                raise EmptyDataSource()
+            raise stop_iteration_error
+
         if len(data) == 1:
             row_size = sys.getsizeof(data.iloc[0].values)
 
@@ -679,7 +686,7 @@ class FlightConnection:
                                   "data_nrows": self.downloaded_data_nrows,
                                   "data_batch_size": sys.getsizeof(data),
                                   "data_batch_nrows": len(data),
-                                  "no_batches": ceil(self.downloaded_data_nrows / len(data))}
+                                  "no_batches": ceil(self.downloaded_data_nrows / len(data)) if len(data) > 0 else 0}
                     yield data, data_stats
                 else:
                     yield data
@@ -835,6 +842,7 @@ class FlightConnection:
             return self.number_of_batch_rows
 
         while True:
+            self._check_for_breaking_exceptions()
             if self.row_size == -1:
                 raise TypeError("Data could not be read. Try to use a binary read mode.")
 
@@ -974,7 +982,7 @@ class FlightConnection:
             break
 
     def create_logical_batch(self, timeout: int = 60 * 10, _type: str = 'logical') -> 'pd.DataFrame':
-        """Creates a logical batch for sampling, logical batch is larger ~2GB.
+        """Create a logical batch for sampling, logical batch is larger ~2GB.
         If used with normal read, it will return all of the collected data, max 1GB based on a limitation.
         """
         max_rows = self._get_max_rows(_type=_type)
@@ -1245,6 +1253,8 @@ class FlightConnection:
                     raise TypeError(msg)
                 if 'Internal error occurred' in msg:
                     raise TypeError(msg)
+                if "Cannot fetch data via Flight Service. Verify if data were saved" in msg:
+                    raise EmptyDataSource()  # raise one common error if data couldn't be read.
 
     def _get_sampling_strategy(self):
         """
@@ -1257,7 +1267,7 @@ class FlightConnection:
             PredictionType.CLASSIFICATION, PredictionType.BINARY, PredictionType.MULTICLASS
         )
         truncate_sampling_pred_types = (
-            PredictionType.FORECASTING
+            PredictionType.FORECASTING, PredictionType.TIMESERIES_ANOMALY_PREDICTION
         )
 
         if self.sampling_type == SamplingTypes.RANDOM and self.learning_type in random_sampling_pred_types:
