@@ -24,7 +24,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class HwSpec(WMLResource):
-    """Store and manage your hardware specs."""
+    """Store and manage hardware specs."""
 
     ConfigurationMetaNames = HwSpecMetaNames()
     """MetaNames for Hardware Specification."""
