@@ -23,7 +23,7 @@ from ibm_watson_machine_learning.href_definitions import HrefDefinitions
 
 
 class ServiceInstanceNewPlan:
-    """Connect, get details and check usage of your Watson Machine Learning service instance."""
+    """Connect, get details and check usage of Watson Machine Learning service instance."""
 
     def __init__(self, client):
         self._logger = logging.getLogger(__name__)
@@ -52,7 +52,7 @@ class ServiceInstanceNewPlan:
         self.details = None
 
     def get_instance_id(self):
-        """Get instance id of your Watson Machine Learning service.
+        """Get instance id of Watson Machine Learning service.
 
         :return: instance id
         :rtype: str
@@ -84,7 +84,7 @@ class ServiceInstanceNewPlan:
         return self._wml_credentials['apikey']
 
     def get_url(self):
-        """Get instance url of your Watson Machine Learning service.
+        """Get instance url of Watson Machine Learning service.
 
         :return: instance url
         :rtype: str
@@ -98,7 +98,7 @@ class ServiceInstanceNewPlan:
         return self._wml_credentials['url']
 
     def get_username(self):
-        """Get username for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data.
+        """Get username for Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data.
 
         :return: username
         :rtype: str
@@ -118,7 +118,7 @@ class ServiceInstanceNewPlan:
             raise WMLClientError("Not applicable for Cloud")
 
     def get_password(self):
-        """Get password for your Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data.
+        """Get password for Watson Machine Learning service. Applicable only for IBM Cloud Pak® for Data.
 
         :return: password
         :rtype: str
@@ -138,7 +138,7 @@ class ServiceInstanceNewPlan:
             raise WMLClientError("Not applicable for Cloud")
 
     def get_details(self):
-        """Get information about your Watson Machine Learning instance.
+        """Get information about Watson Machine Learning instance.
 
         :return: metadata of service instance
         :rtype: dict
