@@ -642,7 +642,7 @@ def convert_zip_to_bytes(filename):
                 byte_arr = f.read()
 
         except InvalidConfigurationException as ex:
-            logger.error(str(ex))
+            logger.error(repr(ex))
             raise InvalidConfigurationException("Zip file does not exist.")
         except Exception as identifier:
             raise FLException(
