@@ -25,7 +25,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class ModelDefinition(WMLResource):
-    """Store and manage your model definitions."""
+    """Store and manage model definitions."""
 
     ConfigurationMetaNames = ModelDefinitionMetaNames()
 
@@ -809,7 +809,7 @@ class ModelDefinition(WMLResource):
             raise WMLClientError('Unable to update attachment because of server error. Try again later')
 
     def create_revision(self, model_definition_uid):
-        """Creates revision for the given model definition. Revisions are immutable once created.
+        """Create revision for the given model definition. Revisions are immutable once created.
         The metadata and attachment at model definition is taken and a revision is created out of it.
 
         :param model_definition_uid: model definition ID
