@@ -29,6 +29,7 @@ from ibm_watson_machine_learning.wml_client_error import WMLClientError
 
 logger = logging.getLogger(__name__)
 
+
 def process_heartbeat(client, **kwargs):
     try:
         config_dict = kwargs.get('config_dict')
@@ -117,8 +118,7 @@ if fl_path not in sys.path:
 
 
 class Party(WMLResource):
-    """ 
-    The Party class embodies a Federated Learning party, with methods to run, cancel, and query local training.
+    """The Party class embodies a Federated Learning party, with methods to run, cancel, and query local training.
     Refer to the ``client.remote_training_system.create_party()`` API for more information about creating an
     instance of the Party class. 
     """
@@ -198,33 +198,38 @@ class Party(WMLResource):
         self.Party.start()
 
     def run(self, aggregator_id=None, experiment_id=None, asynchronous=True, verify=True, timeout: int = 60 * 10):
-        """
-        Connect to a Federated Learning aggregator and run local training.
-        Exactly one of aggregator_id and experiment_id must be supplied.  
+        """Connect to a Federated Learning aggregator and run local training.
+        Exactly one of `aggregator_id` and `experiment_id` must be supplied.
 
-        **Parameters**
+        :param aggregator_id: aggregator identifier
 
-        .. important::
-           #. **aggregator_id**:  aggregator identifier\n
-              * If aggregator_id is supplied, the party will connect to the given aggregator.\n
-              **type**: str\n
-           #. **experiment_id**:  experiment identifier\n
-              * If experiment_id is supplied, the party will connect to the most recently created aggregator for the experiment.\n
-              **type**: str\n
-           #. **asynchronous**:\n
-              * True  - party starts to run the job in the background and progress can be checked later.\n
-              * False - method will wait until training is complete and then print the job status.\n
-              **type**: bool\n
-           #. **verify**:  verify certificate\n
-              **type**: bool\n
-           #. **timeout**:  timeout in seconds.\n
-              * If the aggregator is not ready within timeout seconds, exit.\n
-              **type**: int, or None for no timeout\n
+            * If aggregator_id is supplied, the party will connect to the given aggregator.
 
+        :type aggregator_id: str, optional
+        :param experiment_id: experiment identifier
+
+            * If experiment_id is supplied, the party will connect to the most recently created aggregator
+                for the experiment.
+
+        :type experiment_id: str, optional
+        :param asynchronous:
+            * `True`  - party starts to run the job in the background and progress can be checked later
+            * `False` - method will wait until training is complete and then print the job status
+        :type asynchronous: bool, optional
+        :param verify: verify certificate
+        :type verify: bool, optional
+        :param timeout: timeout in seconds
+
+              * If the aggregator is not ready within timeout seconds, exit.
+
+        :type timeout: int, or None for no timeout
 
         **Examples**
-         >>> party.run( aggregator_id = "69500105-9fd2-4326-ad27-7231aeb37ac8", asynchronous = True, verify = True )
-         >>> party.run( experiment_id = "2466fa06-1110-4169-a166-01959adec995", asynchronous = False )
+
+        .. code-block:: python
+
+            party.run( aggregator_id = "69500105-9fd2-4326-ad27-7231aeb37ac8", asynchronous = True, verify = True )
+            party.run( experiment_id = "2466fa06-1110-4169-a166-01959adec995", asynchronous = False )
 
         """
         from ibmfl.exceptions import FLException
@@ -336,89 +341,77 @@ class Party(WMLResource):
             logger.exception(ex)
 
     def monitor_logs(self, log_level="INFO"):
-        """
-        Enable logging of the training job to standard output.
-        This method should be called before calling the run() method.
+        """Enable logging of the training job to standard output.
+        This method should be called before calling the ``run()`` method.
 
-        **Parameters**
-
-        .. important::
-           #. **log_level**:  log level specified by user\n
-              **type**: str\n
-
-        **Output**
-
-        .. important::
-            **returns**: This method only outputs the logs to stdout\n
-            **return type**: None\n
+        :param log_level: log level specified by user
+        :type log_level: str, optional
 
         **Example**
-         >>> party.monitor_logs()
+
+        .. code-block:: python
+
+            party.monitor_logs()
 
         """
         self.log_level = log_level
 
     def monitor_metrics(self, metrics_file="-"):
-        """
-        Enable output of training metrics.
+        """Enable output of training metrics.
 
-        **Parameters**
+        :param metrics_file: a filename specified by user to which the metrics should be written
+        :type metrics_file: str, optional
 
-        .. important::
-           #. **metrics_file**:  a filename specified by user to which the metrics should be written\n
-              **type**: str\n
-
-        **Output**
-
-        .. important::
-            **returns**: This method outputs the metrics to stdout if a filename is not specified\n
-            **return type**: None\n
+        .. note::
+            This method outputs the metrics to stdout if a filename is not specified
 
         **Example**
-         >>> party.monitor_metrics()
+
+        .. code-block:: python
+
+            party.monitor_metrics()
 
         """
         self.metrics_output = metrics_file
 
     def is_running(self):
-        """
-        Check if the training job is running
+        """Check if the training job is running.
 
-        **Output**
-
-        .. important::
-             **returns**: If the job is running\n
-             **return type**: bool\n
+        :return: if the job is running
+        :rtype: bool
 
         **Example**
-         >>> party.is_running()
+
+        .. code-block:: python
+
+            party.is_running()
 
         """
         return not self.connection.stopped
 
-    def get_round(self):  
+    def get_round(self):
+        """Get the current round number.
 
-        """
-        Get the current round number
-
-        **Output**
-
-        .. important::
-             **returns**: The current round number\n
-             **return type**: int\n
+        :return: the current round number
+        :rtype: int
 
         **Example**
-         >>> party.get_round()
+
+        .. code-block:: python
+
+            party.get_round()
 
         """
         return self.Party.proto_handler.metrics_recorder.get_round_no()
 
     def cancel(self):
-        """
-        Stop the local connection to the training on the party side
+        """Stop the local connection to the training on the party side.
 
         **Example**
-         >>> party.cancel()
+
+        .. code-block:: python
+
+            party.cancel()
 
         """
         self.Party.stop_connection()
