@@ -24,7 +24,7 @@ import json
 
 
 class Pipelines(WMLResource):
-    """Store and manage your pipelines."""
+    """Store and manage pipelines."""
 
     ConfigurationMetaNames = PipelineMetanames()
     """MetaNames for pipelines creation."""
@@ -644,7 +644,7 @@ class Pipelines(WMLResource):
             self._list(pipeline_values, [u'GUID', u'NAME', u'CREATED'], limit, _DEFAULT_LIST_LENGTH)
 
     def clone(self, pipeline_uid, space_id=None, action="copy", rev_id=None):
-        """Creates a new pipeline identical with the given pipeline either in the same space or in a new space.
+        """Create a new pipeline identical with the given pipeline either in the same space or in a new space.
         All dependent assets will be cloned too.
 
         :param pipeline_uid: uid of the pipeline to be cloned
