@@ -24,7 +24,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class PkgExtn(WMLResource):
-    """Store and manage your software Packages Extension specs."""
+    """Store and manage software Packages Extension specs."""
 
     ConfigurationMetaNames = PkgExtnMetaNames()
     """MetaNames for Package Extensions creation."""
@@ -157,16 +157,16 @@ class PkgExtn(WMLResource):
 
 
             # if pkg_extn_details["entity"]["package_extension"]["type"] in ["conda_yml", "pip_zip"]:
-            if not self._client.ICP:
-                put_response = requests.put(
-                    href,
-                    data=read_in_chunks()
-                )
-            else:
-                with open(file_path, 'rb') as f:
+            with open(file_path, 'rb') as file_object:
+                if not self._client.ICP:
                     put_response = requests.put(
                         href,
-                        files={'file': (file_path, f.read(), 'application/octet-stream')}
+                        data=file_object.read()
+                    )
+                else:
+                    put_response = requests.put(
+                        href,
+                        files={'file': (file_path, file_object.read(), 'application/octet-stream')}
                     )
 
             if put_response.status_code == 201 or put_response.status_code == 200:
