@@ -27,7 +27,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class PlatformSpaces(WMLResource):
-    """Store and manage your spaces."""
+    """Store and manage spaces."""
 
     ConfigurationMetaNames = SpacesPlatformMetaNames()
     """MetaNames for spaces creation."""
