@@ -32,19 +32,18 @@ if TYPE_CHECKING:
 
 
 class DataJoinPipeline:
-    """
-    Class representing abstract data join pipeline.
-
-    Parameters
-    ----------
-    preprocessed_data_connection: DataConnection, required
-        Populated DataConnection with preprocessed data join information.
-    optimizer: RemoteAutoPipeline, required
-        Optimizer with initialized pipeline metadata, required for running an OBM training in predict method.
-    """
+    """Class representing abstract data join pipeline."""
     VisualizationTypes = VisualizationTypes
 
     def __init__(self, preprocessed_data_connection: 'DataConnection', optimizer: 'RemoteAutoPipelines') -> None:
+        """
+        :param preprocessed_data_connection: populated DataConnection with preprocessed data join information
+        :type preprocessed_data_connection: DataConnection
+
+        :param optimizer: optimizer with initialized pipeline metadata, required for running an OBM training
+            in predict method
+        :type optimizer: RemoteAutoPipeline
+        """
         self._obm_json = preprocessed_data_connection._download_obm_json()
         self._pipeline_json = self._obm_json['Pipeline']
         self._obm_pipeline_graph_builder = OBMPipelineGraphBuilder(self._obm_json)
@@ -57,12 +56,10 @@ class DataJoinPipeline:
     def visualize(self, astype: 'VisualizationTypes' = VisualizationTypes.INPLACE) -> None:
         """Display graph in the notebook or as a rendered image.
 
-        Parameters
-        ----------
-        astype: VisualizationTypes, optional
-            Specify a type of visualization for this graph. Default is VisualizationTypes.INPLACE
-            (when in notebook env, picture will be displayed in the cell output).
-            VisualizationTypes.PDF indicates to render a pdf document with visualization.
+        :param astype: specify a type of visualization for this graph, default is VisualizationTypes.INPLACE
+            (when in notebook env, picture will be displayed in the cell output),
+            VisualizationTypes.PDF indicates to render a pdf document with visualization
+        :type astype: VisualizationTypes, optional
         """
         if hasattr(self, 'lale_pipeline'):
             self.lale_pipeline.visualize()
@@ -108,13 +105,11 @@ class DataJoinPipeline:
     #     return self._optimizer.get_preprocessed_data_connection().read()
 
     def pretty_print(self, ipython_display: bool = False) -> None:
-        """
-        Prints code which generates OBM data preprocessing.
+        """Print code which generates OBM data preprocessing.
 
-        Parameters
-        ----------
-        ipython_display: bool, optional
-            If method executed in jupyter notebooks/ipython set this flag to true in order to get syntax highlighting.
+        :param ipython_display: if method executed in jupyter notebooks/ipython set this flag to true in order
+            to get syntax highlighting
+        :type ipython_display: bool, optional
         """
         if hasattr(self, 'lale_pipeline'):
             if ipython_display:
@@ -161,13 +156,10 @@ class DataJoinPipeline:
 
 
 class OBMPipelineGraphBuilder:
-    """
-    Class for extracting particular elements from OBM output json with pipeline description.
+    """Class for extracting particular elements from OBM output json with pipeline description.
 
-    Parameters
-    ----------
-    pipeline_json: dict, required
-        Dictionary with loaded obm.json file.
+    :param pipeline_json: dictionary with loaded obm.json file
+    :type pipeline_json: dict
     """
 
     def __init__(self, obm_json: dict) -> None:
@@ -188,50 +180,48 @@ class OBMPipelineGraphBuilder:
 
     @staticmethod
     def get_step_details(msg_json) -> Tuple[str, int, str]:
-        """
-        Getting particular step name, iteration number and step description.
-        """
+        """Get particular step name, iteration number and step description."""
         name = msg_json['feature_engineering_components']['obm'][0]['step_name'].split(':')[1]
         iteration = msg_json['feature_engineering_components']['obm'][0]['iteration']
         text = msg_json['message']['text']
         return name, iteration, text
 
     def get_step_types(self) -> List[str]:
-        """For all steps return their types."""
+        """For all steps get their types."""
         return [message['feature_engineering_components']['obm'][0]['step_type'] for message in self.pipeline_json]
 
     def get_last_non_join_iteration(self) -> int:
-        """Returns a number of the last step before join."""
+        """Get a number of the last step before join."""
         return self.get_step_types().index('join')
 
     def get_selection_iteration(self) -> int:
-        """Returns feature selection step number."""
+        """Get feature selection step number."""
         return self.get_step_types().index('feature selection') + 1
 
     def get_join_iterations(self) -> List[int]:
-        """Returns list of join step numbers."""
+        """Get list of join step numbers."""
         steps_types = [message['feature_engineering_components']['obm'][0]['step_type'] for message in
                        self.pipeline_json]
         return [i + 1 for i, x in enumerate(steps_types) if x == "join"]
 
     @staticmethod
     def get_join_extractors(msg_json: dict) -> Union[dict, None]:
-        """Returns extractors if exist."""
+        """Get extractors if exist."""
         return msg_json['feature_engineering_components']['obm'][0].get('extractors')
 
     @staticmethod
     def get_extractor_columns(extractor_json: dict) -> List[str]:
-        """Returns all columns names from particular extractor."""
+        """Get all columns names from particular extractor."""
         return extractor_json['columns']
 
     @staticmethod
     def get_extractor_transformations(extractor_json: dict) -> Dict[str, str]:
-        """Returns a dictionary with all transformations names."""
+        """Get a dictionary with all transformations names."""
         return extractor_json['transformations']
 
     @staticmethod
     def get_join_info(msg_json: dict) -> Tuple[List[str], List[List[str]]]:
-        """Returns join_tables and keys if exist."""
+        """Get join_tables and keys if exist."""
         join_path = msg_json['feature_engineering_components']['obm'][0].get('join_path')
         if join_path is not None:
             return join_path.get("tables"), join_path.get("join_keys")
@@ -240,7 +230,7 @@ class OBMPipelineGraphBuilder:
 
     @staticmethod
     def get_tables_info(table_json: dict) -> Dict[str, Tuple[List[str], List[str]]]:
-        """Returns information about all tables such as name and a list of column names if exists."""
+        """Get information about all tables such as name and a list of column names if exists."""
         tables_info = {}
         for _, table in enumerate(table_json):
             column_names = [name for _, name in enumerate(table_json.get(table).get('training_column_types'))]
@@ -250,17 +240,17 @@ class OBMPipelineGraphBuilder:
 
     @staticmethod
     def get_main_table_name(obm_json: dict) -> str:
-        """Returns the name of the main table for OneBM"""
+        """Get the name of the main table for OneBM"""
         return obm_json.get("OneButtonMachine").get("main_table")
 
     @staticmethod
     def get_time_column_for_table(tables_json: dict, table_name: str) -> str:
-        """Returns the name of the timestamp column for the table. """
+        """Get the name of the timestamp column for the table. """
         return tables_json.get(table_name).get("timestamp_column_name")
 
     @staticmethod
     def get_group_by_key(tables_json, main_table) -> str:
-        """Returns the name of the primary key for the main table if present.
+        """Get the name of the primary key for the main table if present.
         This key is used for all group by operations after joins. If there is no primary key,
         row_id of the main table is used internally."""
         main_table_info = tables_json.get(main_table)
@@ -286,7 +276,7 @@ class OBMPipelineGraphBuilder:
         return obm_json.get("Category").get("categorical_column_names")
 
     def build_extractors_subgraph(self, msg_json: dict, join_iteration: int) -> None:
-        """Creates sub-graph for extractors representation."""
+        """Create sub-graph for extractors representation."""
         extractors = self.get_join_extractors(msg_json)
         join_iteration = str(join_iteration)
 
@@ -320,7 +310,7 @@ class OBMPipelineGraphBuilder:
                         self.graph_json['edges'][transformation].add(str(self.selection_iteration))
 
     def build_preprocessing_prefix(self) -> 'lale.operators.TrainableIndividualOp':
-        """Creats a Lale pipeline corresponding to the data join pipeline. This pipeline has all the information to 
+        """Create a Lale pipeline corresponding to the data join pipeline. This pipeline has all the information to
         create a pipeline that can be used to perform transform, but not for fit."""
         from lale.expressions import (Expr, it, replace, sum, max, count, day_of_month,
                                       day_of_week, day_of_year, month, hour, minute, min,
@@ -538,7 +528,7 @@ class OBMPipelineGraphBuilder:
         return Relational(operator=nested_pipeline)
 
     def build_graph(self) -> Tuple[dict, 'Digraph']:
-        """Creates a graphviz Digraph with pipeline representation."""
+        """Create a graphviz Digraph with pipeline representation."""
         for msg in self.pipeline_json:
             name, iteration, text = self.get_step_details(msg)
             self.graph.node(str(iteration), name, tooltip=text)
