@@ -142,41 +142,41 @@ class Table(BaseOBMJson):
 
 
 class DataJoinGraph(Digraph, BaseOBMJson):
-    """
-    DataJoinGraph class - helper class for handling multiple data sources for AutoAI experiment.
+    """DataJoinGraph class - helper class for handling multiple data sources for AutoAI experiment.
 
     You can define the overall relations between each of data source and see these defined relations
     in a form of string representation calling print(ObmGraph) or to leverage graphviz library
     and make entire graph visualization.
 
-    Parameters
-    ----------
-    t_shirt_size: enum TShirtSize, optional
-        The size of the computation POD.
+    :param t_shirt_size: the size of the computation POD
+    :type t_shirt_size: enum TShirtSize, optional
 
-    Example
-    -------
-    >>> data_join_graph = DataJoinGraph()
-    >>> # or
-    >>> data_join_graph = DataJoinGraph(t_shirt_size=DataJoinGraph.TShirtSize.L)
-​
-    >>> data_join_graph.node(name="main")
-    >>> data_join_graph.node(name="customers")
-    >>> data_join_graph.node(name="transactions")
-    >>> data_join_graph.node(name="purchases")
-    >>> data_join_graph.node(name="products")
-​
-    >>> data_join_graph.edge(from_node="main", to_node="customers",
-    >>>                from_column=["group_customer_id"], to_column=["group_customer_id"])
-    >>> data_join_graph.edge(from_node="main", to_node="transactions",
-    >>>                from_column=["transaction_id"], to_column=["transaction_id"])
-    >>> data_join_graph.edge(from_node="main", to_node="purchases",
-    >>>                from_column=["group_id"], to_column=["group_id"])
-    >>> data_join_graph.edge(from_node="transactions", to_node="products",
-    >>>                from_column=["product_id"], to_column=["product_id"])
-​
-    >>> print(data_join_graph)
-    >>> data_join_graph.visualize()
+
+    **Example**
+
+    .. code-block:: python
+
+        data_join_graph = DataJoinGraph()
+        # or
+        data_join_graph = DataJoinGraph(t_shirt_size=DataJoinGraph.TShirtSize.L)
+
+        data_join_graph.node(name="main")
+        data_join_graph.node(name="customers")
+        data_join_graph.node(name="transactions")
+        data_join_graph.node(name="purchases")
+        data_join_graph.node(name="products")
+
+        data_join_graph.edge(from_node="main", to_node="customers",
+                             from_column=["group_customer_id"], to_column=["group_customer_id"])
+        data_join_graph.edge(from_node="main", to_node="transactions",
+                             from_column=["transaction_id"], to_column=["transaction_id"])
+        data_join_graph.edge(from_node="main", to_node="purchases",
+                             from_column=["group_id"], to_column=["group_id"])
+        data_join_graph.edge(from_node="transactions", to_node="products",
+                             from_column=["product_id"], to_column=["product_id"])
+
+        print(data_join_graph)
+        data_join_graph.visualize()
     """
     TShirtSize = TShirtSize
     NodeTemplate = """<
@@ -236,28 +236,28 @@ class DataJoinGraph(Digraph, BaseOBMJson):
              csv_separator: Optional[str] = None,
              sheet_name: Optional[str] = None,
              main: Optional[bool] = False) -> None:
-        """
-        Add node to the graph. The node is representing the particular data source for training.
+        """Add node to the graph. The node is representing the particular data source for training.
         The node added as a first one will be set as main one. If you want to set another node as a main, please
         set a `main` argument to True.
 
-        Parameters
-        ----------
-        name: str, required
-            The name/id of the node, it must be the same as id passed to particular linked DataConnection.
-        timestamp_column_name: str, optional
-            The name of the column, which includes dates.
-        timestamp_format: str, optional
-            Format of dates contained in column named 'timestamp_column_name'.
-        csv_separator: str, optional
-            Separator used in source csv file.
-        sheet_name: str, optional
-            Used for xlsx files to indicate which sheet is used.
-        main: bool, optional
-            If you want to set this node as a main one, please set a `main` argument to True.
-        Example
-        -------
-        >>> data_join_graph.node(name="main")
+        :param name: the name/id of the node, it must be the same as id passed to particular linked DataConnection
+        :type name: str
+        :param timestamp_column_name: the name of the column, which includes dates
+        :type timestamp_column_name: str, optional
+        :param timestamp_format: format of dates contained in column named 'timestamp_column_name'
+        :type timestamp_format: str, optional
+        :param csv_separator: separator used in source csv file
+        :type csv_separator: str, optional
+        :param sheet_name: used for xlsx files to indicate which sheet is used
+        :type sheet_name: str, optional
+        :param main: if you want to set this node as a main one, please set a `main` argument to `True`
+        :type main: bool, optional
+
+        **Example**
+
+        .. code-block:: python
+
+            data_join_graph.node(name="main")
         """
         self.node_edges[name] = set()
 
@@ -278,29 +278,28 @@ class DataJoinGraph(Digraph, BaseOBMJson):
         # --- end note
 
     def edge(self, from_node, to_node, from_column: List[str], to_column: List[str]):
-        """
-        Add edge to the graph. The edge defines the connection between two DataConnections.
+        """Add edge to the graph. The edge defines the connection between two DataConnections.
         eg. main --- from column customer_id to column customer_id --> customers
 
-        Parameters
-        ----------
-        from_node: str, required
-            The starting Node.
+        :param from_node: the starting Node
+        :type from_node: str
 
-        to_node: str, required
-            The ending Node
+        :param to_node: the ending Node
+        :type to_node: str
 
-        from_column: List[str], required
-            The list of columns located in the starting Node in order, these columns will be connected to
-            the ending Node columns.
+        :param from_column: the list of columns located in the starting Node in order, these columns
+            will be connected to the ending Node columns
+        :type from_column: list[str]
 
-        to_column: List[str], required
-            The list of columns located in the ending Node.
+        :param to_column: the list of columns located in the ending Node
+        :type to_column: list[str]
 
-        Example
-        -------
-        >>> data_join_graph.edge(from_node="main", to_node="transactions",
-        >>>                from_column=["transaction_id"], to_column=["transaction_id"])
+        **Example**
+
+        .. code-block :: python
+
+            data_join_graph.edge(from_node="main", to_node="transactions",
+                                 from_column=["transaction_id"], to_column=["transaction_id"])
         """
         self.node_edges[from_node] |= set(from_column)
         self.node_edges[to_node] |= set(to_column)
@@ -417,32 +416,20 @@ class DataJoinGraph(Digraph, BaseOBMJson):
         return data_join_graph
 
     def pretty_print(self, show_imports: bool = True, ipython_display: bool = False) -> Union[str, None]:
-        """Returns the Python source code representation of the DataJoinGraph.
+        """Get the Python source code representation of the DataJoinGraph.
 
-        Parameters
-        ----------
-        show_imports : bool, default True
+        :param show_imports: whether to include import statements in the pretty-printed code
+        :type show_imports: bool, optional
 
-            Whether to include import statements in the pretty-printed code.
+        :param ipython_display:
+            - `False` - return the pretty-printed code as a plain old Python string
+            - `True` - pretty-print in notebook cell output with syntax highlighting
+            - 'input' - create a new notebook cell with pretty-printed code as input
 
-        ipython_display : union type, default False
+        :type ipython_display: bool or str
 
-            - False
-
-              Return the pretty-printed code as a plain old Python string.
-
-            - True:
-
-              Pretty-print in notebook cell output with syntax highlighting.
-
-            - 'input'
-
-              Create a new notebook cell with pretty-printed code as input.
-
-        Returns
-        -------
-        str or None
-            If called with ipython_display=False, return pretty-printed Python source code as a Python string.
+        :return: if called with `ipython_display=False`, return pretty-printed Python source code as a Python string
+        :rtype: str or None
         """
         nodes_str = ""
         for node in self.nodes:
