@@ -290,7 +290,7 @@ class RemoteTrainingSystem(WMLResource):
 
         **Example**
 
-        .. code_block:: python
+        .. code-block:: python
 
             client.remote_training_systems.create_revision(remote_training_system_id)
         """
@@ -309,7 +309,7 @@ class RemoteTrainingSystem(WMLResource):
         :type remote_training_system_id: str
 
         :param rev_id: Unique id of the remote system revision
-        :type rev_id : int
+        :type rev_id: int
 
         :return: stored remote system revision metadata
         :rtype: dict
@@ -375,7 +375,7 @@ class RemoteTrainingSystem(WMLResource):
                                  "client.remote_training_systems.ConfigurationMetaNames.DATA_HANDLER")
 
     def create_party(self, remote_training_system_id, party_metadata):
-        """Creates a party object using the specified remote training system id and the party metadata.
+        """Create a party object using the specified remote training system id and the party metadata.
 
         :param remote_training_system_id: remote training system identifier
         :type remote_training_system_id: str
