@@ -33,7 +33,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Repository(WMLResource):
-    """Store and manage your models, functions, spaces, pipelines and experiments
+    """Store and manage models, functions, spaces, pipelines and experiments
     using Watson Machine Learning Repository.
     
     To view ModelMetaNames, use:
@@ -188,7 +188,7 @@ class Repository(WMLResource):
 
     def clone(self, artifact_id, space_id=None, action="copy", rev_id=None):
         # """ it is not supported in v4ga
-        #     Creates a new resource(models, runtimes, libraries, experiments, functions, pipelines) identical with the model either in the same space or in a new space. All dependent assets will be cloned too.
+        #     Create a new resource(models, runtimes, libraries, experiments, functions, pipelines) identical with the model either in the same space or in a new space. All dependent assets will be cloned too.
         #
         #     **Parameters**
         #
