@@ -27,7 +27,8 @@ from ibm_watson_machine_learning.libs.repo.mlrepository import MetaProps, MetaNa
 from ibm_watson_machine_learning.href_definitions import API_VERSION, SPACES,PIPELINES, LIBRARIES, EXPERIMENTS, RUNTIMES, DEPLOYMENTS
 
 
-def LibraryDefinition(name, version, filepath, description=None, platform=None, model_definition=None, custom=None, command=None, tags=None, space_uid=None):
+def LibraryDefinition(name, version, filepath, description=None, platform=None, model_definition=None, custom=None,
+                      command=None, tags=None, space_uid=None):
     WMLResource._validate_type(name, 'name', str, True)
     WMLResource._validate_type(version, 'version', str, True)
     WMLResource._validate_type(platform, 'platform', dict, False)
@@ -64,12 +65,14 @@ def LibraryDefinition(name, version, filepath, description=None, platform=None,
 
 
 class Runtimes(WMLResource):
-    """
-        Creates Runtime Specs and associated Custom Libraries.
+    """Create Runtime Specs and associated Custom Libraries.
 
-        .. note::
-            There are a list of pre-defined runtimes available. To see the list of pre-defined runtimes, use:\n
-            >>> client.runtimes.list(pre_defined=True)
+    .. note::
+        There are a list of pre-defined runtimes available. To see the list of pre-defined runtimes, use:
+
+        .. code-block:: python
+
+            client.runtimes.list(pre_defined=True)
     """
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
@@ -127,34 +130,29 @@ class Runtimes(WMLResource):
         return self.get_library_uid(details)
 
     def store_library(self, meta_props):
-        """
-               Create a library.\n
+        """Create a library.
 
-               **Parameters**
+        :param meta_props:  metadata of the library configuration. To see available meta names use:
 
-               .. important::
+            .. code-block:: python
 
-                    #. **meta_props**:  meta data of the libraries configuration. To see available meta names use:\n
-                                        >>> client.runtimes.LibraryMetaNames.get()
+                client.runtimes.LibraryMetaNames.get()
 
-                       **type**: dict\n
+        :type meta_props: dict
+        :return: metadata of the library created
+        :rtype: dict
 
-               **Output**
+        **Example**
 
-               .. important::
+        .. code-block:: python
 
-                    **returns**: Metadata of the library created.\n
-                    **return type**: dict\n
-
-               **Example**
-
-                >>> library_details = client.runtimes.store_library({
-                >>> client.runtimes.LibraryMetaNames.NAME: "libraries_custom",
-                >>> client.runtimes.LibraryMetaNames.DESCRIPTION: "custom libraries for scoring",
-                >>> client.runtimes.LibraryMetaNames.FILEPATH: custom_library_path,
-                >>> client.runtimes.LibraryMetaNames.VERSION: "1.0",
-                >>> client.runtimes.LibraryMetaNames.PLATFORM: {"name": "python", "versions": ["3.5"]}
-                >>> })
+            library_details = client.runtimes.store_library({
+                client.runtimes.LibraryMetaNames.NAME: "libraries_custom",
+                client.runtimes.LibraryMetaNames.DESCRIPTION: "custom libraries for scoring",
+                client.runtimes.LibraryMetaNames.FILEPATH: custom_library_path,
+                client.runtimes.LibraryMetaNames.VERSION: "1.0",
+                client.runtimes.LibraryMetaNames.PLATFORM: {"name": "python", "versions": ["3.5"]}
+            })
         """
 
         if self._client.ICP_30:
@@ -250,51 +248,51 @@ class Runtimes(WMLResource):
         return details['metadata']['guid']
 
     def store(self, meta_props):
-        """
-               Create a runtime.\n
+        """Create a runtime.
 
-               **Parameters**
+        :param meta_props:  metadata of the runtime configuration. To see available meta names use:
 
-               .. important::
+            .. code-block:: python
 
-                    #. **meta_props**:  meta data of the runtime configuration. To see available meta names use:\n
-                                        >>> client.runtimes.ConfigurationMetaNames.get()
+                client.runtimes.ConfigurationMetaNames.get()
 
-                       **type**: dict\n
+        :type meta_props: dict
 
-               **Output**
+        :return: metadata of the runtime created
+        :rtype: dict
 
-               .. important::
+        **Examples**
 
-                    **returns**: Metadata of the runtime created\n
-                    **return type**: dict\n
+        Creating a library:
 
-               **Example**
+        .. code-block:: python
 
-                Creating a library\n
+            lib_meta = {
+                client.runtimes.LibraryMetaNames.NAME: "libraries_custom",
+                client.runtimes.LibraryMetaNames.DESCRIPTION: "custom libraries for scoring",
+                client.runtimes.LibraryMetaNames.FILEPATH: "/home/user/my_lib.zip",
+                client.runtimes.LibraryMetaNames.VERSION: "1.0",
+                client.runtimes.LibraryMetaNames.PLATFORM: {"name": "python", "versions": ["3.5"]}
+            }
 
-                >>> lib_meta = {
-                >>> client.runtimes.LibraryMetaNames.NAME: "libraries_custom",
-                >>> client.runtimes.LibraryMetaNames.DESCRIPTION: "custom libraries for scoring",
-                >>> client.runtimes.LibraryMetaNames.FILEPATH: "/home/user/my_lib.zip",
-                >>> client.runtimes.LibraryMetaNames.VERSION: "1.0",
-                >>> client.runtimes.LibraryMetaNames.PLATFORM: {"name": "python", "versions": ["3.5"]}
-                >>> }
-                >>> custom_library_details = client.runtimes.store_library(lib_meta)
-                >>> custom_library_uid = client.runtimes.get_library_uid(custom_library_details)
+            custom_library_details = client.runtimes.store_library(lib_meta)
+            custom_library_uid = client.runtimes.get_library_uid(custom_library_details)
 
-                Creating a runtime\n
+        Creating a runtime:
 
-                >>> runtime_meta = {
-                >>> client.runtimes.ConfigurationMetaNames.NAME: "runtime_spec_python_3.5",
-                >>> client.runtimes.ConfigurationMetaNames.DESCRIPTION: "test",
-                >>> client.runtimes.ConfigurationMetaNames.PLATFORM: {
-                >>> "name": "python",
-                >>>  "version": "3.5"
-                >>> },
-                >>> client.runtimes.ConfigurationMetaNames.LIBRARIES_UIDS: [custom_library_uid] # already existing lib is linked here
-                >>> }
-                >>> runtime_details = client.runtimes.store(runtime_meta)
+        .. code-block:: python
+
+            runtime_meta = {
+                client.runtimes.ConfigurationMetaNames.NAME: "runtime_spec_python_3.5",
+                client.runtimes.ConfigurationMetaNames.DESCRIPTION: "test",
+                client.runtimes.ConfigurationMetaNames.PLATFORM: {
+                    "name": "python",
+                    "version": "3.5"
+                },
+                client.runtimes.ConfigurationMetaNames.LIBRARIES_UIDS: [custom_library_uid] # already existing lib is linked here
+            }
+
+            runtime_details = client.runtimes.store(runtime_meta)
 
         """
 
@@ -319,35 +317,28 @@ class Runtimes(WMLResource):
 
         return self.get_details(runtime_uid)
 
-    def get_details(self, runtime_uid=None,pre_defined=False, limit=None):
-        """
-           Get metadata of stored runtime(s). If runtime UID is not specified returns all runtimes metadata.
+    def get_details(self, runtime_uid=None, pre_defined=False, limit=None):
+        """Get metadata of stored runtime(s). If runtime UID is not specified returns all runtimes metadata.
 
-           **Parameters**
+        :param runtime_uid: runtime UID
+        :type runtime_uid: str, optional
+        :param pre_defined: boolean indicating to display predefined runtimes only
+        :type pre_defined: bool, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **runtime_uid**: runtime UID (optional)\n
-                   **type**: str\n
-                #. **pre_defined**:  Boolean indicating to display predefined runtimes only. Default value is set to 'False'\n
-                   **type**: bool\n
-                #. **limit**:  limit number of fetched records (optional)\n
-                   **type**: int\n
+        :return: metadata of runtime(s)
+        :rtype:
+            - **dict** - if runtime_uid is not None
+            - **{"resources": [dict]}** - if runtime_uid is None
 
-           **Output**
+        **Examples**
 
-           .. important::
-                **returns**: metadata of runtime(s)\n
-                **return type**: dict
-                The output can be {"resources": [dict]} or a dict\n
+        .. code-block:: python
 
-           .. note::
-                If UID is not specified, all runtimes metadata is fetched\n
-
-           **Example**
-
-            >>> runtime_details = client.runtimes.get_details(runtime_uid)
-            >>> runtime_details = client.runtimes.get_details(runtime_uid=runtime_uid)
-            >>> runtime_details = client.runtimes.get_details()
+            runtime_details = client.runtimes.get_details(runtime_uid)
+            runtime_details = client.runtimes.get_details(runtime_uid=runtime_uid)
+            runtime_details = client.runtimes.get_details()
         """
 
         if self._client.ICP_30:
@@ -367,32 +358,25 @@ class Runtimes(WMLResource):
          return self._get_artifact_details(url, runtime_uid, limit, 'runtime specs')
 
     def get_library_details(self, library_uid=None, limit=None):
-        """
-           Get metadata of stored librarie(s). If library UID is not specified returns all libraries metadata.
+        """Get metadata of stored librarie(s). If library UID is not specified returns all libraries metadata.
 
-           **Parameters**
+        :param library_uid: library UID
+        :type library_uid: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **library_uid**: library UID (optional)\n
-                   **type**: str\n
-                #. **limit**:  limit number of fetched records (optional)\n
-                   **type**: int\n
+        :return: metadata of library(s)
+        :rtype:
+            - **dict** - if runtime_uid is not None
+            - **{"resources": [dict]}** - if runtime_uid is None
 
-           **Output**
+        **Examples**
 
-           .. important::
-                **returns**: metadata of library(s)\n
-                **return type**: dict
-                The output can be {"resources": [dict]} or a dict\n
+        .. code-block:: python
 
-           .. note::
-                If UID is not specified, all libraries metadata is fetched\n
-
-           **Example**
-
-            >>> library_details = client.runtimes.get_library_details(library_uid)
-            >>> library_details = client.runtimes.get_library_details(library_uid=library_uid)
-            >>> library_details = client.runtimes.get_library_details()
+            library_details = client.runtimes.get_library_details(library_uid)
+            library_details = client.runtimes.get_library_details(library_uid=library_uid)
+            library_details = client.runtimes.get_library_details()
         """
 
         if self._client.ICP_30:
@@ -410,25 +394,20 @@ class Runtimes(WMLResource):
 
     @staticmethod
     def get_href(details):
-        """
-            Get runtime_href from runtime details.
+        """Get runtime href from runtime details.
 
-            **Parameters**
+        :param details: metadata of the runtime
+        :type details: dict
 
-            .. important::
-                #. **runtime_details**:  Metadata of the runtime\n
-                   **type**: dict\n
+        :return: runtime href
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: runtime href\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-
-             >>> runtime_details = client.runtimes.get_details(runtime_uid)
-             >>> runtime_href = client.runtimes.get_href(runtime_details)
+            runtime_details = client.runtimes.get_details(runtime_uid)
+            runtime_href = client.runtimes.get_href(runtime_details)
         """
 
         Runtimes._validate_type(details, u'details', dict, True)
@@ -447,25 +426,20 @@ class Runtimes(WMLResource):
 
     @staticmethod
     def get_uid(details):
-        """
-            Get runtime_uid from runtime details.
+        """Get runtime uid from runtime details.
 
-            **Parameters**
+        :param details: metadata of the runtime
+        :type details: dict
 
-            .. important::
-                #. **runtime_details**:  Metadata of the runtime\n
-                   **type**: dict\n
+        :return: runtime UID
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: runtime UID\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-
-             >>> runtime_details = client.runtimes.get_details(runtime_uid)
-             >>> runtime_uid = client.runtimes.get_uid(runtime_details)
+            runtime_details = client.runtimes.get_details(runtime_uid)
+            runtime_uid = client.runtimes.get_uid(runtime_details)
         """
 
         Runtimes._validate_type(details, u'details', dict, True)
@@ -484,25 +458,20 @@ class Runtimes(WMLResource):
 
     @staticmethod
     def get_library_href(library_details):
-        """
-            Get library_href from library details.
+        """Get library href from library details.
 
-            **Parameters**
+        :param library_details: metadata of the library
+        :type library_details: dict
 
-            .. important::
-                #. **library_details**:  Metadata of the library\n
-                   **type**: dict\n
+        :return: library href
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: library href\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-
-             >>> library_details = client.runtimes.get_library_details(library_uid)
-             >>> library_url = client.runtimes.get_library_href(library_details)
+            library_details = client.runtimes.get_library_details(library_uid)
+            library_url = client.runtimes.get_library_href(library_details)
         """
 
         Runtimes._validate_type(library_details, u'library_details', dict, True)
@@ -512,25 +481,20 @@ class Runtimes(WMLResource):
 
     @staticmethod
     def get_library_uid(library_details):
-        """
-            Get library_uid from library details.
+        """Get library uid from library details.
 
-            **Parameters**
+        :param library_details: metadata of the library
+        :type library_details: dict
 
-            .. important::
-                #. **library_details**:  Metadata of the library\n
-                   **type**: dict\n
+        :return: library UID
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: library UID\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-
-             >>> library_details = client.runtimes.get_library_details(library_uid)
-             >>> library_uid = client.runtimes.get_library_uid(library_details)
+            library_details = client.runtimes.get_library_details(library_uid)
+            library_uid = client.runtimes.get_library_uid(library_details)
         """
 
         Runtimes._validate_type(library_details, u'library_details', dict, True)
@@ -557,27 +521,21 @@ class Runtimes(WMLResource):
         ))
 
     def delete(self, runtime_uid, with_libraries=False):
-        """
-            Delete a runtime.
+        """Delete a runtime.
 
-            **Parameters**
+        :param runtime_uid: runtime UID
+        :type runtime_uid: str
+        :param with_libraries: boolean value indicating an option to delete the libraries associated with the runtime
+        :type with_libraries: bool, optional
 
-            .. important::
-                #. **runtime_uid**:  Runtime UID\n
-                   **type**: str\n
-                #. **with_libraries**:  Boolean value indicating an option to delete the libraries associated with the runtime\n
-                   **type**: bool\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
+        **Example**
 
-            **Output**
+        .. code-block:: python
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
-
-            **Example**
-
-             >>> client.runtimes.delete(deployment_uid)
+            client.runtimes.delete(deployment_uid)
         """
 
         if self._client.ICP_30:
@@ -615,12 +573,13 @@ class Runtimes(WMLResource):
         return self._handle_response(204, u'runtime deletion', response_delete, False)
 
     def _delete_orphaned_libraries(self):
-        """
-            Delete all custom libraries without runtime.
+        """Delete all custom libraries without runtime.
 
-            A way you might use me is:
+        **Example**
 
-            >>> client.runtimes.delete_orphaned_libraries()
+        .. code-block:: python
+
+            client.runtimes.delete_orphaned_libraries()
         """
         lib_details = self.get_library_details()
         details = self.get_details()
@@ -638,24 +597,19 @@ class Runtimes(WMLResource):
                     pass
 
     def delete_library(self, library_uid):
-        """
-            Delete a library.
+        """Delete a library.
 
-            **Parameters**
+        :param library_uid: library UID
+        :type library_uid: str
 
-            .. important::
-                #. **library_uid**:  Library UID\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.runtimes.delete_library(library_uid)
+            client.runtimes.delete_library(library_uid)
         """
 
         if self._client.ICP_30:
@@ -668,28 +622,20 @@ class Runtimes(WMLResource):
 
         return self._handle_response(204, u'library deletion', response_delete, False)
 
-    def list(self, limit=None,pre_defined=False):
-        """
-           List stored runtimes. If limit is set to None there will be only first 50 records shown.
+    def list(self, limit=None, pre_defined=False):
+        """Print stored runtimes in a table format. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param pre_defined: boolean indicating to display predefined runtimes only
+        :type pre_defined: bool, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
-                #. **pre_defined**:  Boolean indicating to display predefined runtimes only. Default value is set to 'False'\n
-                   **type**: bool\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of runtimes in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.runtimes.list()
-            >>> client.runtimes.list(pre_defined=True)
+            client.runtimes.list()
+            client.runtimes.list(pre_defined=True)
         """
 
         if self._client.ICP_30:
@@ -702,13 +648,14 @@ class Runtimes(WMLResource):
         self._list(values, [u'GUID', u'NAME', u'CREATED', u'PLATFORM'], limit, 50)
 
     def _list_runtimes_for_libraries(self): # TODO make public when the time'll come
-        """
-           List runtimes uids for libraries.
+        """Print runtimes uids for libraries in a table format.
 
-           A way you might use me is:
+        **Example**
 
-           >>> client.runtimes.list_runtimes_for_libraries()
-           >>> client.runtimes.list_runtimes_for_libraries(library_uid)
+        .. code-block:: python
+
+            client.runtimes.list_runtimes_for_libraries()
+            client.runtimes.list_runtimes_for_libraries(library_uid)
         """
         details = self.get_library_details()
         runtime_details = self.get_details()
@@ -728,28 +675,21 @@ class Runtimes(WMLResource):
         print(table)
 
     def list_libraries(self, runtime_uid=None, limit=None):
-        """
-           List stored libraries. If runtime UID is not provided, all libraries are listed else, libraries associated with a runtime are listed. If limit is set to None there will be only first 50 records shown.
+        """Print stored libraries in a table format. If runtime UID is not provided, all libraries are listed else,
+        libraries associated with a runtime are listed. If limit is set to None there will be only first 50 records
+        shown.
 
-           **Parameters**
+        :param runtime_uid: runtime UID
+        :type runtime_uid: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **runtime_uid**:  runtime UID (optional)\n
-                   **type**: str\n
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of libraries in a table format.\n
-                **return type**: None\n
-
-
-           **Example**
-
-            >>> client.runtimes.list_libraries()
-            >>> client.runtimes.list_libraries(runtime_uid)
+            client.runtimes.list_libraries()
+            client.runtimes.list_libraries(runtime_uid)
         """
 
         if self._client.ICP_30:
@@ -783,36 +723,23 @@ class Runtimes(WMLResource):
 
             print(table)
 
-    def download_configuration(self, runtime_uid, filename=None):
-        """
-                Downloads configuration file for runtime with specified uid.
+    def download_configuration(self, runtime_uid, filename='runtime_configuration.yaml'):
+        """Downloads configuration file for runtime with specified uid.
 
-                **Parameters**
+        :param runtime_uid: UID of runtime
+        :type runtime_uid: str
+        :param filename: filename of downloaded archive
+        :type filename: str, optional
 
-                .. important::
+        :return: path to the downloaded runtime configuration
+        :rtype: str
 
-                    #. **runtime_uid**:  UID of runtime\n
-                       **type**: str\n
-                    #. **filename**:  filename of downloaded archive (optional)\n
-                       **default value**: runtime_configuration.yaml\n
-                       **type**: str\n
+        **Example**
 
+        .. code-block:: python
 
-                **Output**
-
-                .. important::
-
-                    **returns**: Path to the downloaded runtime configuration\n
-                    **return type**: str\n
-
-                .. note::
-
-                   If filename is not specified, the default filename is "runtime_configuration.yaml".\n
-
-                **Example**
-
-                   >>> filename="runtime.yml"
-                   >>> client.runtimes.download_configuration(runtime_uid, filename=filename)
+            filename="runtime.yml"
+            client.runtimes.download_configuration(runtime_uid, filename=filename)
         """
 
         if self._client.ICP_30:
@@ -829,9 +756,6 @@ class Runtimes(WMLResource):
             download_url,
             headers=self._client._get_headers())
 
-        if filename is None:
-            filename = 'runtime_configuration.yaml'
-
         if response_get.status_code == 200:
             with open(filename, "wb") as new_file:
                 new_file.write(response_get.content)
@@ -846,34 +770,22 @@ class Runtimes(WMLResource):
             raise WMLClientError(u'Unable to download configuration content: ' + response_get.text)
 
     def download_library(self, library_uid, filename=None):
-        """
-                Downloads library content with specified uid.
+        """Downloads library content with specified uid.
 
-                **Parameters**
+        :param library_uid: UID of library
+        :type library_uid: str
+        :param filename: filename of downloaded archive, default value: `<LIBRARY-NAME>-<LIBRARY-VERSION>.zip`
+        :type filename: str, optional
 
-                .. important::
+        :return: path to the downloaded library content
+        :rtype: str
 
-                      #. **library_uid**:  UID of library\n
-                         **type**: str\n
-                      #. **filename**:  filename of downloaded archive (optional)\n
-                         **default value**: <LIBRARY-NAME>-<LIBRARY-VERSION>.zip\n
-                         **type**: str\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                       **returns**: Path to the downloaded library content\n
-                       **return type**: str\n
-
-                .. note::
-
-                    If filename is not specified, the default filename is "<LIBRARY-NAME>-<LIBRARY-VERSION>.zip".\n
-
-                **Example**
-
-                    >>> filename="library.tgz"
-                    >>> client.runtimes.download_library(runtime_uid, filename=filename)
+            filename="library.tgz"
+            client.runtimes.download_library(runtime_uid, filename=filename)
         """
 
         if self._client.ICP_30:
@@ -905,29 +817,25 @@ class Runtimes(WMLResource):
             raise WMLClientError(u'Unable to download library content: ' + response_get.text)
 
     def update_library(self, library_uid, changes):
-        """
-                Updates existing library metadata.
+        """Updates existing library metadata.
 
-                **Parameters**
+        :param library_uid: UID of library which definition should be updated
+        :type library_uid: str
+        :param changes: elements which should be changed, where keys are ConfigurationMetaNames
+        :type changes: dict
 
-                .. important::
-                    #. **library_uid**:  UID of library which definition should be updated\n
-                       **type**: str\n
-                    #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-                       **type**: dict\n
+        :return: metadata of updated library
+        :rtype: dict
 
-                **Output**
+        **Example**
 
-                .. important::
-                    **returns**: metadata of updated library\n
-                    **return type**: dict\n
+        .. code-block:: python
 
-                **Example**
+            metadata = {
+                client.runtimes.LibraryMetaNames.NAME: "updated_lib"
+            }
 
-                 >>> metadata = {
-                 >>> client.runtimes.LibraryMetaNames.NAME:"updated_lib"
-                 >>> }
-                 >>> library_details = client.runtimes.update_library(library_uid, changes=metadata)
+            library_details = client.runtimes.update_library(library_uid, changes=metadata)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -950,29 +858,25 @@ class Runtimes(WMLResource):
         return updated_details
 
     def update_runtime(self, runtime_uid, changes):
-        """
-                Updates existing runtime metadata.
+        """Updates existing runtime metadata.
 
-                **Parameters**
+        :param runtime_uid: UID of runtime which definition should be updated
+        :type runtime_uid: str
+        :param changes: elements which should be changed, where keys are ConfigurationMetaNames
+        :type changes: dict
 
-                .. important::
-                    #. **runtime_uid**:  UID of runtime which definition should be updated\n
-                       **type**: str\n
-                    #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-                       **type**: dict\n
+        :return: metadata of updated runtime
+        :rtype: dict
 
-                **Output**
+        **Example**
 
-                .. important::
-                    **returns**: metadata of updated runtime\n
-                    **return type**: dict\n
+        .. code-block:: python
 
-                **Example**
+            metadata = {
+                client.runtimes.ConfigurationMetaNames.NAME: "updated_runtime"
+            }
 
-                 >>> metadata = {
-                 >>> client.runtimes.ConfigurationMetaNames.NAME:"updated_runtime"
-                 >>> }
-                 >>> runtime_details = client.runtimes.update(runtime_uid, changes=metadata)
+            runtime_details = client.runtimes.update(runtime_uid, changes=metadata)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -995,44 +899,32 @@ class Runtimes(WMLResource):
         return updated_details
 
     def clone_runtime(self, runtime_uid, space_id=None, action="copy", rev_id=None):
-        """
-                Creates a new runtime identical with the given runtime either in the same space or in a new space. All dependent assets will be cloned too.
+        """Create a new runtime identical with the given runtime either in the same space or in a new space.
+        All dependent assets will be cloned too.
 
-                **Parameters**
+        :param runtime_uid: UID of the runtime to be cloned
+        :type runtime_uid: str
+        :param space_id: UID of the space to which the runtime needs to be cloned
+        :type space_id: str, optional
+        :param action: action specifying "copy" or "move"
+        :type action: str, optional
+        :param rev_id: revision ID of the runtime
+        :type rev_id: str, optional
 
-                .. important::
-                    #. **model_id**:  Guid of the runtime to be cloned:\n
+        :return: metadata of the runtime cloned
+        :rtype**: dict
 
-                       **type**: str\n
+        .. note::
 
-                    #. **space_id**: Guid of the space to which the runtime needs to be cloned. (optional)
+            * If revision id is not specified, all revisions of the artifact are cloned.
 
-                       **type**: str\n
+            * Space guid is mandatory for "move" action.
 
-                    #. **action**: Action specifying "copy" or "move". (optional)
+        **Example**
 
-                       **type**: str\n
+        .. code-block:: python
 
-                    #. **rev_id**: Revision ID of the runtime. (optional)
-
-                       **type**: str\n
-
-                **Output**
-
-                .. important::
-
-                        **returns**: Metadata of the runtime cloned.\n
-                        **return type**: dict\n
-
-                **Example**
-                 >>> client.runtimes.clone_runtime(runtime_uid=artifact_id,space_id=space_uid,action="copy")
-
-                .. note::
-                    * If revision id is not specified, all revisions of the artifact are cloned\n
-
-                    * Default value of the parameter action is copy\n
-
-                    * Space guid is mandatory for move action\n
+            client.runtimes.clone_runtime(runtime_uid=artifact_id,space_id=space_uid,action="copy")
 
         """
         if self._client.ICP_30:
@@ -1058,44 +950,32 @@ class Runtimes(WMLResource):
         return details
 
     def clone_library(self, library_uid, space_id=None, action="copy", rev_id=None):
-        """
-                Creates a new function library with the given library either in the same space or in a new space. All dependent assets will be cloned too.
+        """Create a new function library with the given library either in the same space or in a new space.
+        All dependent assets will be cloned too.
 
-                **Parameters**
+        :param library_uid: UID of the library to be cloned
+        :type library_uid: str
+        :param space_id: UID of the space to which the library needs to be cloned
+        :type space_id: str, optional
+        :param action: action specifying "copy" or "move"
+        :type action: str, optional
+        :param rev_id: revision ID of the library
+        :type rev_id: str, optional
 
-                .. important::
-                    #. **model_id**:  Guid of the library to be cloned:\n
+        :return: metadata of the library cloned
+        :rtype: dict
 
-                       **type**: str\n
+        .. note::
 
-                    #. **space_id**: Guid of the space to which the library needs to be cloned. (optional)
+            * If revision id is not specified, all revisions of the artifact are cloned.
 
-                       **type**: str\n
+            * Space guid is mandatory for "move" action.
 
-                    #. **action**: Action specifying "copy" or "move". (optional)
+        **Example**
 
-                       **type**: str\n
+        .. code-block:: python
 
-                    #. **rev_id**: Revision ID of the library. (optional)
-
-                       **type**: str\n
-
-                **Output**
-
-                .. important::
-
-                        **returns**: Metadata of the library cloned.\n
-                        **return type**: dict\n
-
-                **Example**
-                 >>> client.runtmes.clone_library(library_uid=artifact_id,space_id=space_uid,action="copy")
-
-                .. note::
-                    * If revision id is not specified, all revisions of the artifact are cloned\n
-
-                    * Default value of the parameter action is copy\n
-
-                    * Space guid is mandatory for move action\n
+            client.runtimes.clone_library(library_uid=artifact_id, space_id=space_uid, action="copy")
 
         """
         if self._client.ICP_30:
