@@ -25,36 +25,31 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Script(WMLResource):
-    """
-    Store and manage your scripts assets.
+    """Store and manage scripts assets."""
 
-    """
     ConfigurationMetaNames = ScriptMetaNames()
-    """MetaNames for script Assets creation."""
+    """MetaNames for script assets creation."""
 
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
     def get_details(self, script_uid=None):
-        """
-            Get script asset details. If no script_uid is passed, details for all script assets will be returned.
+        """Get script asset details. If no script_uid is passed, details for all script assets will be returned.
 
-            **Parameters**
+        :param script_uid: Unique id of script
+        :type script_uid: str, optional
 
-            .. important::
-                #. **script_uid**: Unique id  of script\n
-                   **type**: str\n
+        :return: metadata of the stored script asset
+        :rtype:
+            - **dict** - if runtime_uid is not None
+            - **{"resources": [dict]}** - if runtime_uid is None
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: Metadata of the stored script asset\n
-                **return type**: dict\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> script_details = client.scripts.get_details(script_uid)
+            script_details = client.scripts.get_details(script_uid)
 
         """
         def get_required_elements(response):
@@ -79,36 +74,27 @@ class Script(WMLResource):
         return self._get_asset_based_resource(script_uid, 'script', get_required_elements)
 
     def store(self, meta_props, file_path):
-        """
-                Creates a Scripts asset and uploads content to it.
+        """Create a script asset and upload content to it.
 
-                **Parameters**
+        :param meta_props: name to be given to the script asset
+        :type meta_props: str
+        :param file_path: path to the content file to be uploaded
+        :type file_path: str
 
-                .. important::
-                   #. **meta_props**:  Name to be given to the Scripts asset\n
+        :return: metadata of the stored script asset
+        :rtype: dict
 
-                      **type**: str\n
+        **Example**
 
-                   #. **file_path**:  Path to the content file to be uploaded\n
+        .. code-block:: python
 
-                      **type**: str\n
+            metadata = {
+                client.script.ConfigurationMetaNamess.NAME: 'my first script',
+                client.script.ConfigurationMetaNames.DESCRIPTION: 'description of the script',
+                client.script.ConfigurationMetaNames.SOFTWARE_SPEC_UID: '0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda'
+            }
 
-                **Output**
-
-                .. important::
-
-                    **returns**: metadata of the stored Scripts asset\n
-                    **return type**: dict\n
-
-                **Example**
-
-                 >>> metadata = {
-                 >>>        client.script.ConfigurationMetaNamess.NAME: 'my first script',
-                 >>>        client.script.ConfigurationMetaNames.DESCRIPTION: 'description of the script',
-                 >>>        client.script.ConfigurationMetaNames.SOFTWARE_SPEC_UID: '0cdb0f1e-5376-4f4d-92dd-da3b69aa9bda'
-                 >>>    }
-                 >>>
-                 >>> asset_details = client.scripts.store(meta_props=metadata,file_path="/path/to/file")
+            asset_details = client.scripts.store(meta_props=metadata, file_path="/path/to/file")
 
         """
         if self._client.project_type == 'local_git_storage':
@@ -440,24 +426,16 @@ class Script(WMLResource):
 
 
     def list(self, limit=None):
-        """
-           List stored scripts. If limit is set to None there will be only first 50 records shown.
+        """Print stored scripts in a table format. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all script in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.script.list()
+            client.script.list()
         """
 
         Script._validate_type(limit, u'limit', int, False)
@@ -480,33 +458,24 @@ class Script(WMLResource):
         self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
 
     def download(self, asset_uid, filename, rev_uid=None):
+        """Download the content of a script asset.
+
+        :param asset_uid: the Unique Id of the script asset to be downloaded
+        :type asset_uid: str
+        :param filename: filename to be used for the downloaded file
+        :type filename: str
+        :param rev_uid: revision id
+        :type rev_uid: str, optional
+
+        :return: path to the downloaded asset content
+        :rtype: str
+
+        **Example**
+
+        .. code-block:: python
+
+            client.script.download(asset_uid, "script_file")
         """
-            Download the content of a script asset.
-
-            **Parameters**
-
-            .. important::
-
-                 #. **asset_uid**:  The Unique Id of the script asset to be downloaded\n
-                    **type**: str\n
-
-                 #. **filename**:  filename to be used for the downloaded file\n
-                    **type**: str\n
-
-                 #. **rev_uid**:  Revision id\n
-                    **type**: str\n
-
-            **Output**
-
-            .. important::
-
-                 **returns**: Path to the downloaded asset content\n
-                 **return type**: str\n
-
-            **Example**
-
-             >>> client.script.download(asset_uid,"script_file")
-         """
         if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not applicable for this release')
 
@@ -578,52 +547,40 @@ class Script(WMLResource):
 
     @staticmethod
     def get_id(asset_details):
-        """
-                Get Unique Id of stored script asset.
+        """Get Unique Id of stored script asset.
 
-                **Parameters**
+        :param asset_details: metadata of the stored script asset
+        :type asset_details: dict
 
-                .. important::
+        :return: Unique Id of stored script asset
+        :rtype: str
 
-                   #. **asset_details**:  Metadata of the stored script asset\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of stored script asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                     >>> asset_uid = client.script.get_id(asset_details)
+            asset_uid = client.script.get_id(asset_details)
         """
 
         return Script.get_uid(asset_details)
 
     @staticmethod
     def get_uid(asset_details):
-        """
-                Get Unique Id  of stored script asset. This method is deprecated. Use 'get_id(asset_details)' instead
+        """Get Unique Id  of stored script asset.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id(asset_details)`` instead.
 
-                .. important::
+        :param asset_details: metadata of the stored script asset
+        :type asset_details: dict
 
-                   #. **asset_details**:  Metadata of the stored script asset\n
-                      **type**: dict\n
+        :return: Unique Id of stored script asset
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of stored script asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> asset_uid = client.script.get_uid(asset_details)
+            asset_uid = client.script.get_uid(asset_details)
         """
         Script._validate_type(asset_details, u'asset_details', object, True)
         Script._validate_type_of_details(asset_details, DATA_ASSETS_DETAILS_TYPE)
@@ -631,28 +588,22 @@ class Script(WMLResource):
         return WMLResource._get_required_element_from_dict(asset_details, u'data_assets_details',
                                                            [u'metadata', u'guid'])
 
-
     @staticmethod
     def get_href(asset_details):
-        """
-            Get url of stored scripts asset.
+        """Get url of stored scripts asset.
 
-           **Parameters**
+        :param asset_details: stored script details
+        :type asset_details: dict
 
-           .. important::
-                #. **asset_details**:  stored script details\n
-                   **type**: dict\n
+        :return: href of stored script asset
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: href of stored script asset\n
-                **return type**: str\n
+        .. code-block:: python
 
-           **Example**
-
-             >>> asset_details = client.script.get_details(asset_uid)
-             >>> asset_href = client.script.get_href(asset_details)
+            asset_details = client.script.get_details(asset_uid)
+            asset_href = client.script.get_href(asset_details)
 
         """
         Script._validate_type(asset_details, u'asset_details', object, True)
@@ -661,25 +612,23 @@ class Script(WMLResource):
         return WMLResource._get_required_element_from_dict(asset_details, u'asset_details', [u'metadata', u'href'])
 
     def update(self, script_uid, meta_props=None, file_path=None):
-        """
-        Update script with either metadata or attachment or both.
+        """Update script with either metadata or attachment or both.
 
-        **Parameters**
+        :param script_uid: script UID
+        :type script_uid: str
+        :param meta_props: changes for script matadata
+        :type meta_props: dict, optional
+        :param file_path: file path to new attachment
+        :type file_path: str, optional
 
-        .. important::
-            #. **param script_uid**:  Script UID.\n
-               **type**: str\n
-
-        **Output**
-
-        .. important::
-
-            **returns**: Updated metadata of script.\n
-            **return type**: dict\n
+        :return: updated metadata of script
+        :rtype: dict
 
         **Example**
 
-            >>> script_details = client.script.update(model_uid, meta, content_path)
+        .. code-block:: python
+
+            script_details = client.script.update(model_uid, meta, content_path)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -840,24 +789,19 @@ class Script(WMLResource):
             raise WMLClientError('Unable to update attachment because of server error. Try again later')
 
     def delete(self, asset_uid):
-        """
-            Delete a stored script asset.
+        """Delete a stored script asset.
 
-            **Parameters**
+        :param asset_uid: UID of script asset
+        :type asset_uid: str
 
-            .. important::
-                #. **asset_uid**:  Unique Id of script asset\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.script.delete(asset_uid)
+            client.script.delete(asset_uid)
 
         """
         Script._validate_type(asset_uid, u'asset_uid', str, True)
@@ -875,26 +819,20 @@ class Script(WMLResource):
             return self._handle_response(204, u'delete assets', response)
 
     def create_revision(self, script_uid):
-        """
-        Creates revision for the given script. Revisions are immutable once created.
-        The metadata and attachment at script_uid is taken and a revision is created out of it
+        """Create revision for the given script. Revisions are immutable once created.
+        The metadata and attachment at `script_uid` is taken and a revision is created out of it.
 
-        **Parameters**
+        :param script_uid: script ID
+        :type script_uid: str
 
-        .. important::
-            #. **script_uid**: Script ID. Mandatory.\n
-               **type**: str\n
-
-        ** Output**
-
-        .. important::
-
-            **returns**: Stored script revisions metadata.\n
-            **return type**: dict\n
+        :return: stored script revisions metadata
+        :rtype: dict
 
         **Example**
 
-            >>> script_revision = client.scripts.create_revision(script_uid)
+        .. code-block:: python
+
+            script_revision = client.scripts.create_revision(script_uid)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
         # We need to enable this once we add functionality for WSD
@@ -931,27 +869,18 @@ class Script(WMLResource):
             return final_response
 
     def list_revisions(self, script_uid, limit=None):
-        """
-        List all revisions for the given script uid.
+        """Print all revisions for the given script uid in a table format.
 
-        **Parameters**
-
-        .. important::
-            #. **script_uid**: Stored script ID.\n
-               **type**: str\n
-
-            #. **limit**: Limit number of fetched records (optional).\n
-               **type**: int\n
-
-        **Output**
-
-        .. important::
-                This method only prints the list of all script in a table format.\n
-                **return type**: None\n
+        :param script_uid: stored script ID
+        :type script_uid: str
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
         **Example**
 
-            >>> client.scripts.list_revisions(script_uid)
+        .. code-block:: python
+
+            client.scripts.list_revisions(script_uid)
         """
         # We need to enable this once we add functionality for WSD
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -978,29 +907,22 @@ class Script(WMLResource):
 
         self._list(script_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
 
-    def get_revision_details(self, script_uid=None, rev_uid=None):
-        """
-        Get metadata of script_uid revision.
+    def get_revision_details(self, script_uid, rev_uid=None):
+        """Get metadata of script revision.
 
-        **Paramaters**
+        :param script_uid: script ID
+        :type script_uid: str
+        :param rev_uid: revision ID, if this parameter is not provided, returns latest revision if existing else error
+        :type rev_uid: int, optional
 
-        .. important::
-            #. **script_uid**: Script ID. Mandatory.\n
-               **type**: str\n
-
-            #. **rev_uid**: Revision ID. If this parameter is not provided, returns latest revision if existing else error.\n
-               **type**: int\n
-
-        **Output**
-
-        .. important::
-
-            **returns**: Stored script(s) metadata\n
-            **return type**: dict\n
+        :return: stored script(s) metadata
+        :rtype: dict
 
         **Example**
 
-            >>> script_details = client.scripts.get_revision_details(script_uid, rev_uid)
+        .. code-block:: python
+
+            script_details = client.scripts.get_revision_details(script_uid, rev_uid)
         """
         # We need to enable this once we add functionality for WSD
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
