@@ -25,10 +25,8 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Shiny(WMLResource):
-    """
-    Store and manage your shiny assets.
+    """Store and manage shiny assets."""
 
-    """
     ConfigurationMetaNames = ShinyMetaNames()
     """MetaNames for Shiny Assets creation."""
 
@@ -37,24 +35,21 @@ class Shiny(WMLResource):
         self._ICP = client.ICP
 
     def get_details(self, shiny_uid=None):
-        """
-            Get shiny asset details. If no shiny_uid is passed, details for all shiny assets will be returned.
+        """Get shiny asset details. If no shiny_uid is passed, details for all shiny assets will be returned.
 
-            **Parameters**
+        :param shiny_uid: Unique id of shiny asset
+        :type shiny_uid: str, optional
 
-            .. important::
-                #. **shiny_uid**:  Unique id  of shiny asset\n
-                   **type**: str\n
+        :return: metadata of the stored shiny asset
+        :rtype:
+          - **dict** - if runtime_uid is not None
+          - **{"resources": [dict]}** - if runtime_uid is None
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: Metadata of the stored shiny asset\n
-                **return type**: dict\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> shiny_details = client.shiny.get_details(shiny_uid)
+            shiny_details = client.shiny.get_details(shiny_uid)
 
         """
         def get_required_elements(response):
@@ -72,32 +67,25 @@ class Shiny(WMLResource):
         return self._get_asset_based_resource(shiny_uid, 'shiny_asset', get_required_elements)
 
     def store(self, meta_props, file_path):
-        """
-                Creates a shiny asset and uploads content to it.
+        """Create a shiny asset and uploads content to it.
 
-                **Parameters**
+        :param meta_props: metadata of shiny asset
+        :type meta_props: dict
+        :param file_path: path to the content file to be uploaded
+        :type file_path: str
 
-                .. important::
-                   #. **name**:  Name to be given to the shiny asset\n
+        :return: metadata of the stored shiny asset
+        :rtype: dict
 
-                      **type**: str\n
+        **Example**
 
-                   #. **file_path**:  Path to the content file to be uploaded\n
+        .. code-block:: python
 
-                      **type**: str\n
+            meta_props = {
+                client.shiny.ConfigurationMetaNames.NAME: "shiny app name"
+            }
 
-                **Output**
-
-                .. important::
-
-                    **returns**: metadata of the stored shiny asset\n
-                    **return type**: dict\n
-
-                **Example**
-                 >>> meta_props = {
-                 >>>    client.shiny.ConfigurationMetaNames.NAME: "shiny app name"
-                 >>> }
-                 >>> shiny_details = client.shiny.store(meta_props,file_path="/path/to/file")
+            shiny_details = client.shiny.store(meta_props, file_path="/path/to/file")
         """
         if self._client.project_type == 'local_git_storage':
             raise ForbiddenActionForGitBasedProject(reason="Storing Shiny apps is not supported for git based project.")
@@ -309,24 +297,17 @@ class Shiny(WMLResource):
                 raise WMLClientError("Failed while creating a shiny asset. Try again.")
 
     def list(self, limit=None):
-        """
-           List stored shiny assets. If limit is set to None there will be only first 50 records shown.
+        """Print stored shiny assets in a table format. If limit is set to None
+        there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all shiny assets in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-                    >>> client.shiny.list()
+            client.shiny.list()
 
         """
 
@@ -349,28 +330,23 @@ class Shiny(WMLResource):
         self._list(space_values, [u'NAME', u'ASSET_TYPE', u'ASSET_ID'], None, _DEFAULT_LIST_LENGTH)
 
     def download(self, shiny_uid, filename, rev_uid=None):
-        """
-            Download the content of a shiny asset.
+        """Download the content of a shiny asset.
 
-            **Parameters**
+        :param shiny_uid: the Unique Id of the shiny asset to be downloaded
+        :type shiny_uid: str
+        :param filename: filename to be used for the downloaded file
+        :type filename: str
+        :param rev_uid: revision id
+        :type rev_uid: str, optional
 
-            .. important::
-                 #. **shiny_uid**:  The Unique Id of the shiny asset to be downloaded\n
-                    **type**: str\n
+        :return: path to the downloaded shiny asset content
+        :rtype: str
 
-                 #. **filename**:  filename to be used for the downloaded file\n
-                    **type**: str\n
+        **Example**
 
-                 #. **rev_uid**:  Revision id\n
-                    **type**: str\n
-            **Output**
+        .. code-block:: python
 
-                 **returns**: Path to the downloaded shiny asset content\n
-                 **return type**: str\n
-
-            **Example**
-
-                  >>> client.shiny.download(shiny_uid,"shiny_asset.zip")
+            client.shiny.download(shiny_uid, "shiny_asset.zip")
 
          """
         if rev_uid is not None and self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -438,27 +414,19 @@ class Shiny(WMLResource):
 
     @staticmethod
     def get_id(shiny_details):
-        """
-                Get Unique Id of stored shiny asset.
+        """Get Unique Id of stored shiny asset.
 
-                **Parameters**
+        :param shiny_details: metadata of the stored shiny asset
+        :type shiny_details: dict
 
-                .. important::
+        :return: Unique Id of stored shiny asset
+        :rtype: str
 
-                   #. **shiny_details**:  Metadata of the stored shiny asset\n
-                      **type**: dict\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of stored shiny asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                     >>> shiny_uid = client.shiny.get_id(shiny_details)
+            shiny_uid = client.shiny.get_id(shiny_details)
 
         """
 
@@ -466,27 +434,21 @@ class Shiny(WMLResource):
 
     @staticmethod
     def get_uid(shiny_details):
-        """
-                Get Unique Id  of stored shiny asset. This method is deprecated. Use 'get_id(shiny_details)' instead
+        """Get Unique Id  of stored shiny asset.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id(shiny_details)`` instead.
 
-                .. important::
+        :param shiny_details: metadata of the stored shiny asset
+        :type shiny_details: dict
 
-                   #. **shiny_details**:  Metadata of the stored shiny asset\n
-                      **type**: dict\n
-                      **type**: dict\n
+        :return: Unique Id of stored shiny asset
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of stored shiny asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                     >>> shiny_uid = client.shiny.get_uid(shiny_details)
+            shiny_uid = client.shiny.get_uid(shiny_details)
 
         """
         Shiny._validate_type(shiny_details, u'shiny_details', object, True)
@@ -495,28 +457,22 @@ class Shiny(WMLResource):
         return WMLResource._get_required_element_from_dict(shiny_details, u'data_assets_details',
                                                            [u'metadata', u'guid'])
 
-
     @staticmethod
     def get_href(shiny_details):
-        """
-            Get url of stored shiny asset.
+        """Get url of stored shiny asset.
 
-           **Parameters**
+        :param shiny_details: stored shiny asset details
+        :type shiny_details: dict
 
-           .. important::
-                #. **shiny_details**:  stored shiny asset details\n
-                   **type**: dict\n
+        :return: href of stored shiny asset
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: href of stored shiny asset\n
-                **return type**: str\n
+        .. code-block:: python
 
-           **Example**
-
-             >>> shiny_details = client.shiny.get_details(shiny_uid)
-             >>> shiny_href = client.shiny.get_href(shiny_details)
+            shiny_details = client.shiny.get_details(shiny_uid)
+            shiny_href = client.shiny.get_href(shiny_details)
         """
         Shiny._validate_type(shiny_details, u'shiny_details', object, True)
         Shiny._validate_type_of_details(shiny_details, DATA_ASSETS_DETAILS_TYPE)
@@ -524,18 +480,23 @@ class Shiny(WMLResource):
         return WMLResource._get_required_element_from_dict(shiny_details, u'shiny_details', [u'metadata', u'href'])
 
     def update(self, shiny_uid, meta_props=None, file_path=None):
-        """
-            Update shiny with either metadata or attachment or both.
+        """Update shiny with either metadata or attachment or both.
 
-            :param shiny_uid:  Shiny UID
-            :type shiny_uid: str
+        :param shiny_uid:  Shiny UID
+        :type shiny_uid: str
+        :param meta_props: changes to shiny metadata
+        :type meta_props: dict, optional
+        :param file_path: file path to new attachment
+        :type file_path: str, optional
 
-            :returns: updated metadata of shiny asset
-            :rtype: dict
+        :return: updated metadata of shiny asset
+        :rtype: dict
 
-            A way you might use me is:
+        **Example**
 
-            >>> script_details = client.script.update(model_uid, meta, content_path)
+        .. code-block:: python
+
+            script_details = client.script.update(model_uid, meta, content_path)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -664,24 +625,19 @@ class Shiny(WMLResource):
             raise WMLClientError('Unable to update attachment because of server error. Try again later')
 
     def delete(self, shiny_uid):
-        """
-            Delete a stored shiny asset.
+        """Delete a stored shiny asset.
 
-            **Parameters**
+        :param shiny_uid: Unique Id of shiny asset
+        :type shiny_uid: str
 
-            .. important::
-                #. **shiny_uid**:  Unique Id of shiny asset\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
+        
+        .. code-block:: python
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
-
-            **Example**
-
-             >>> client.shiny.delete(shiny_uid)
+            client.shiny.delete(shiny_uid)
 
         """
         Shiny._validate_type(shiny_uid, u'shiny_uid', str, True)
@@ -699,17 +655,20 @@ class Shiny(WMLResource):
             return self._handle_response(204, u'delete assets', response)
 
     def create_revision(self, shiny_uid):
-        """
-           Creates revision for the given Shiny asset. Revisions are immutable once created.
-           The metadata and attachment at script_uid is taken and a revision is created out of it
+        """Create revision for the given Shiny asset. Revisions are immutable once created.
+        The metadata and attachment at `script_uid` is taken and a revision is created out of it.
 
-           :param shiny_uid: Shiny asset ID. Mandatory
-           :type shiny_uid: str
+        :param shiny_uid: shiny asset ID
+        :type shiny_uid: str
 
-           :returns: stored shiny asset revisions metadata
-           :rtype: dict
+        :return: stored shiny asset revisions metadata
+        :rtype: dict
 
-           >>> shiny_revision = client.shiny.create_revision(shiny_uid)
+        **Example**
+
+        .. code-block:: python
+
+            shiny_revision = client.shiny.create_revision(shiny_uid)
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -739,19 +698,21 @@ class Shiny(WMLResource):
             return final_response
 
     def list_revisions(self, shiny_uid, limit=None):
-        """
-           List all revisions for the given shiny asset uid.
+        """Print all revisions for the given shiny asset uid in a table format.
 
-           :param shiny_uid: Stored shiny asset ID.
-           :type shiny_uid: str
+        :param shiny_uid: stored shiny asset ID
+        :type shiny_uid: str
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           :param limit: limit number of fetched records (optional)
-           :type limit: int
+        :return: stored shiny revisions details
+        :rtype: table
 
-           :returns: stored shiny revisions details
-           :rtype: table
+        **Example**
 
-           >>> client.shiny.list_revisions(shiny_uid)
+        .. code-block:: python
+
+            client.shiny.list_revisions(shiny_uid)
         """
 
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
@@ -779,21 +740,21 @@ class Shiny(WMLResource):
         self._list(shiny_values, [u'GUID', u'REVISION_ID', u'NAME', u'REVISION_COMMIT'], limit, _DEFAULT_LIST_LENGTH)
 
     def get_revision_details(self, shiny_uid=None, rev_uid=None):
-        """
-           Get metadata of shiny_uid revision.
+        """Get metadata of `shiny_uid` revision.
 
-           :param script_uid: Shiny asset ID. Mandatory
-           :type script_uid: str
+        :param shiny_uid: shiny asset ID
+        :type shiny_uid: str, optional
+        :param rev_uid: revision ID, if this parameter is not provided, returns latest revision if existing else error
+        :type rev_uid: int, optional
 
-           :param rev_uid: Revision ID. If this parameter is not provided, returns latest revision if existing else error
-           :type rev_uid: int
+        :return: stored shiny(s) metadata
+        :rtype: dict
 
-           :returns: stored shiny(s) metadata
-           :rtype: dict
+        **Example**
 
-           A way you might use me is:
+        .. code-block:: python
 
-           >>> shiny_details = client.shiny.get_revision_details(shiny_uid, rev_uid)
+            shiny_details = client.shiny.get_revision_details(shiny_uid, rev_uid)
         """
         if self._client.ICP_30 is None and not self._client.CLOUD_PLATFORM_SPACES and not self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError(u'Not supported in this release')
