@@ -26,7 +26,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Spaces(WMLResource):
-    """Store and manage your spaces. This is applicable only for IBM Cloud Pak® for Data."""
+    """Store and manage spaces. This is applicable only for IBM Cloud Pak® for Data."""
 
     ConfigurationMetaNames = SpacesMetaNames()
     """MetaNames for spaces creation."""
