@@ -24,12 +24,11 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class SwSpec(WMLResource):
-    """
-    Store and manage your software specs.
+    """Store and manage software specs."""
 
-    """
     ConfigurationMetaNames = SwSpecMetaNames()
     """MetaNames for Software Specification creation."""
+
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
@@ -68,25 +67,23 @@ class SwSpec(WMLResource):
                                 "do_12.10":  "9100fd72-8159-4eb9-8a0b-a87e12eefa36",
                                 "hybrid_0.2":  "9b3f9040-9cee-4ead-8d7a-780600f542f7"}
 
-    def get_details(self,sw_spec_uid=None):
-        """
-            Get software specification details. If no sw_spec_id is passed, details for all software specifications will be returned.
+    def get_details(self, sw_spec_uid=None):
+        """Get software specification details. If no sw_spec_id is passed, details for all software specifications
+        will be returned.
 
-            **Parameters**
+        :param sw_spec_uid: UID of software specification
+        :type sw_spec_uid: str, optional
 
-            .. important::
-                **returns**: sw_spec UID\n
-                **return type**: str
+        :return: metadata of the stored software specification(s)
+        :rtype:
+          - **dict** - if `sw_spec_uid` is not None
+          - **{"resources": [dict]}** - if `sw_spec_uid` is None
 
-            **Output**
+        **Example**
 
-            .. important::
-                #. **sw_spec_details**:  Metadata of the stored sw_spec\n
-                   **type**: dict\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> sw_spec_details = client.software_specifications.get_details(sw_spec_uid)
+            sw_spec_details = client.software_specifications.get_details(sw_spec_uid)
 
         """
         if self._client.WSD_20:
@@ -128,33 +125,32 @@ class SwSpec(WMLResource):
                 return self._handle_response(200, u'get sw specs details', response)
 
     def store(self, meta_props):
-        """
-                Create a software specification.
+        """Create a software specification.
 
-                **Parameters**
+        :param meta_props: metadata of the space configuration. To see available meta names use:
 
-                .. important::
-                   #. **meta_props**:  meta data of the space configuration. To see available meta names use:\n
-                                    >>> client.software_specifications.ConfigurationMetaNames.get()
+            .. code-block:: python
 
-                      **type**: dict\n
+                client.software_specifications.ConfigurationMetaNames.get()
 
-                **Output**
+        :type meta_props: dict
 
-                .. important::
+        :return: metadata of the stored space
+        :rtype: dict
 
-                    **returns**: metadata of the stored space\n
-                    **return type**: dict\n
+        **Example**
 
-                **Example**
+        .. code-block:: python
 
-                 >>> meta_props = {
-                 >>>    client.software_specifications.ConfigurationMetaNames.NAME: "skl_pipeline_heart_problem_prediction",
-                 >>>    client.software_specifications.ConfigurationMetaNames.DESCRIPTION: "description scikit-learn_0.20",
-                 >>>    client.software_specifications.ConfigurationMetaNames.PACKAGE_EXTENSIONS_UID: [],
-                 >>>    client.software_specifications.ConfigurationMetaNames.SOFTWARE_CONFIGURATIONS: {},
-                 >>>    client.software_specifications.ConfigurationMetaNames.BASE_SOFTWARE_SPECIFICATION_ID: "guid"
-                 >>> }
+            meta_props = {
+                client.software_specifications.ConfigurationMetaNames.NAME: "skl_pipeline_heart_problem_prediction",
+                client.software_specifications.ConfigurationMetaNames.DESCRIPTION: "description scikit-learn_0.20",
+                client.software_specifications.ConfigurationMetaNames.PACKAGE_EXTENSIONS_UID: [],
+                client.software_specifications.ConfigurationMetaNames.SOFTWARE_CONFIGURATIONS: {},
+                client.software_specifications.ConfigurationMetaNames.BASE_SOFTWARE_SPECIFICATION_ID: "guid"
+            }
+
+            sw_spec_details = client.software_specifications.store(meta_props)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -176,26 +172,17 @@ class SwSpec(WMLResource):
 
         return sw_spec_details
 
-
     def list(self, limit=None):
-        """
-           List software specifications.
+        """Print software specifications in a table format.
 
-           **Parameters**
+        :param limit: limit number of fetched records
+        :type limit: int, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all software specifications in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.software_specifications.list()
+            client.software_specifications.list()
         """
 
         if not self._client.WSD_20:
@@ -217,27 +204,19 @@ class SwSpec(WMLResource):
 
     @staticmethod
     def get_id(sw_spec_details):
-        """
-                Get Unique Id of software specification.
+        """Get Unique Id of software specification.
 
-                **Parameters**
+        :param sw_spec_details: metadata of the software specification
+        :type sw_spec_details: dict
 
-                .. important::
+        :return: Unique Id of software specification
+        :rtype: str
 
-                   #. **sw_spec_details**:  Metadata of the software specification\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of software specification \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_uid = client.software_specifications.get_id(sw_spec_details)
+            asset_uid = client.software_specifications.get_id(sw_spec_details)
 
         """
 
@@ -245,27 +224,21 @@ class SwSpec(WMLResource):
 
     @staticmethod
     def get_uid(sw_spec_details):
-        """
-                Get Unique Id of software specification. Deprecated!! Use get_id(sw_spec_details) instead
+        """Get Unique Id of software specification.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id(sw_spec_details)`` instead.
 
-                .. important::
+        :param sw_spec_details: metadata of the software specification
+        :type sw_spec_details: dict
 
-                   #. **sw_spec_details**:  Metadata of the software specification\n
-                      **type**: dict\n
+        :return: Unique Id of software specification
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of software specification \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_uid = client.software_specifications.get_uid(sw_spec_details)
+            asset_uid = client.software_specifications.get_uid(sw_spec_details)
 
         """
         SwSpec._validate_type(sw_spec_details, u'sw_spec_details', object, True)
@@ -275,54 +248,40 @@ class SwSpec(WMLResource):
                                                            [u'metadata', u'asset_id'])
 
     def get_id_by_name(self, sw_spec_name):
-        """
-                Get Unique Id of software specification.
+        """Get Unique Id of software specification.
 
-                **Parameters**
+        :param sw_spec_name: name of the software specification
+        :type sw_spec_name: str
 
-                .. important::
+        :return: Unique Id of software specification
+        :rtype: str
 
-                   #. **sw_spec_name**:  Name of the software specification\n
-                      **type**: str\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of software specification \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_uid = client.software_specifications.get_id_by_name(sw_spec_name)
+            asset_uid = client.software_specifications.get_id_by_name(sw_spec_name)
 
         """
 
         return SwSpec.get_uid_by_name(self, sw_spec_name)
 
     def get_uid_by_name(self, sw_spec_name):
-        """
-                Get Unique Id of software specification. Deprecated!! Use get_id_by_name(self, sw_spec_name) instead
+        """Get Unique Id of software specification.
 
-                **Parameters**
+        *Deprecated:* Use ``get_id_by_name(self, sw_spec_name)`` instead.
 
-                .. important::
+        :param sw_spec_name: name of the software specification
+        :type sw_spec_name: str
 
-                   #. **sw_spec_name**:  Name of the software specification\n
-                      **type**: str\n
+        :return: Unique Id of software specification
+        :rtype: str
 
-                **Output**
+        **Example**
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: Unique Id of software specification \n
-                    **return type**: str\n
-
-                **Example**
-
-
-                 >>> asset_uid = client.software_specifications.get_uid_by_name(sw_spec_name)
+            asset_uid = client.software_specifications.get_uid_by_name(sw_spec_name)
 
         """
 
@@ -346,25 +305,20 @@ class SwSpec(WMLResource):
 
     @staticmethod
     def get_href(sw_spec_details):
-        """
-            Get url of software specification.
+        """Get url of software specification.
 
-           **Parameters**
+        :param sw_spec_details: software specification details
+        :type sw_spec_details: dict
 
-           .. important::
-                #. **sw_spec_details**:  software specification details\n
-                   **type**: dict\n
+        :return: href of software specification
+        :rtype: str
 
-           **Output**
+        **Example**
 
-           .. important::
-                **returns**: href of software specification \n
-                **return type**: str\n
+        .. code-block:: python
 
-           **Example**
-
-             >>> sw_spec_details = client.software_specifications.get_details(sw_spec_uid)
-             >>> sw_spec_href = client.software_specifications.get_href(sw_spec_details)
+            sw_spec_details = client.software_specifications.get_details(sw_spec_uid)
+            sw_spec_href = client.software_specifications.get_href(sw_spec_details)
 
         """
         SwSpec._validate_type(sw_spec_details, u'sw_spec_details', object, True)
@@ -373,24 +327,19 @@ class SwSpec(WMLResource):
         return WMLResource._get_required_element_from_dict(sw_spec_details, u'sw_spec_details', [u'metadata', u'href'])
 
     def delete(self, sw_spec_uid):
-        """
-            Delete a software specification.
+        """Delete a software specification.
 
-            **Parameters**
+        :param sw_spec_uid: Unique Id of software specification
+        :type sw_spec_uid: str
 
-            .. important::
-                #. **sw_spec_uid**: Unique Id of software specification\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.software_specifications.delete(sw_spec_uid)
+            client.software_specifications.delete(sw_spec_uid)
 
         """
         if self._client.WSD_20:
@@ -407,21 +356,18 @@ class SwSpec(WMLResource):
             return self._handle_response(204, u'delete software specification', response)
 
     def add_package_extension(self, sw_spec_uid, pkg_extn_id):
-        """
-                Add a package extension to software specifications existing metadata.
+        """Add a package extension to software specifications existing metadata.
 
-                **Parameters**
+        :param sw_spec_uid: Unique Id of software specification which should be updated
+        :type sw_spec_uid: str
+        :param pkg_extn_id: Unique Id of package extension which should needs to added to software specification
+        :type pkg_extn_id: str
 
-                .. important::
+        **Example**
 
-                    #. **sw_spec_uid**:  Unique Id of software specification which should be updated\n
-                       **type**: str\n
-                    #. **pkg_extn_id**:  Unique Id of package extension which should needs to added to software specification\n
-                       **type**: str\n
+        .. code-block:: python
 
-                **Example**
-
-                >>> client.software_specifications.add_package_extension(sw_spec_uid, pkg_extn_id)
+            client.software_specifications.add_package_extension(sw_spec_uid, pkg_extn_id)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -447,21 +393,18 @@ class SwSpec(WMLResource):
             return self._handle_response(204, u'pkg spec add', response, False)
 
     def delete_package_extension(self, sw_spec_uid, pkg_extn_id):
-        """
-                Delete a package extension from software specifications existing metadata.
+        """Delete a package extension from software specifications existing metadata.
 
-                **Parameters**
+        :param sw_spec_uid: Unique Id of software specification which should be updated
+        :type sw_spec_uid: str
+        :param pkg_extn_id: Unique Id of package extension which should needs to deleted from software specification
+        :type pkg_extn_id: str
 
-                .. important::
+        **Example**
 
-                    #. **sw_spec_uid**:  Unique Id of software specification which should be updated\n
-                       **type**: str\n
-                    #. **pkg_extn_id**:  Unique Id of package extension which should needs to deleted from software specification\n
-                       **type**: str\n
+        .. code-block:: python
 
-                **Example**
-
-                 >>> client.software_specifications.delete_package_extension(sw_spec_uid, pkg_extn_id)
+            client.software_specifications.delete_package_extension(sw_spec_uid, pkg_extn_id)
 
         """
         if self._client.WSD_20:
