@@ -33,9 +33,7 @@ logging.getLogger('lomond').setLevel(logging.CRITICAL)
 
 
 class Training(WMLResource):
-    """
-       Train new models.
-    """
+    """Train new models."""
 
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
@@ -59,24 +57,19 @@ class Training(WMLResource):
         return res is not None
 
     def get_status(self, training_uid):
-        """
-                Get the status of a training created.
+        """Get the status of a training created.
 
-                **Parameters**
+        :param training_uid: training UID
+        :type training_uid: str
 
-                .. important::
-                    #. **training_uid**:  training UID\n
-                       **type**: str\n
+        :return: training_status
+        :rtype: dict
 
-                **Output**
+        **Example**
 
-                .. important::
-                    **returns**: training_status\n
-                    **return type**: dict\n
+        .. code-block:: python
 
-                **Example**
-
-                 >>> training_status = client.training.get_status(training_uid)
+            training_status = client.training.get_status(training_uid)
         """
         Training._validate_type(training_uid, 'training_uid', str, True)
 
@@ -89,52 +82,43 @@ class Training(WMLResource):
 
     def get_details(self, training_uid=None, limit=None, asynchronous=False, get_all=False, training_type=None,
                     state=None, tag_value=None, training_definition_id=None, _internal=False):
-        """
-        Get metadata of training(s). If training_uid is not specified returns all model spaces metadata.
+        """Get metadata of training(s). If training_uid is not specified returns all model spaces metadata.
 
-        **Parameters**
-
-        .. important::
-            #. **training_uid**: Unique Id of Training (optional)\n
-               **type**: str\n
-            #. **limit**:  limit number of fetched records (optional)\n
-               **type**: int\n
-            #. **asynchronous**:  if True, it will work as a generator (optional)\n
-               **type**: bool\n
-            #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-               **type**: bool\n
-            #. **training_type**: Filter the fetched list of trainings based on training type
-                                  [`pipeline` or `experiment`] (optional)\n
-               **type**: str\n
-            #. **state**: Filter the fetched list of training based on their state:
-                          [`queued`, `running`, `completed`, `failed`] (optional)\n
-               **type**: str\n
-            #. **tag_value**: Filter the fetched list of training based on ther tag value (optional)\n
-               **type**: str\n
-            #. **training_definition_id**: Filter the fetched trainings which are using the given training_definition
-                                           (optional)\n
-               **type**: str\n
+        :param training_uid: Unique Id of training
+        :type training_uid: str, optional
+        :param limit: limit number of fetched records
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all:  if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
+        :param training_type: filter the fetched list of trainings based on training type ["pipeline" or "experiment"]
+        :type training_type: str, optional
+        :param state: filter the fetched list of training based on their state:
+            [`queued`, `running`, `completed`, `failed`]
+        :type state: str, optional
+        :param tag_value: filter the fetched list of training based on ther tag value
+        :type tag_value: str, optional
+        :param training_definition_id: filter the fetched trainings which are using the given training definition
+        :type training_definition_id: str, optional
 
 
-        **Output**
+        :return: metadata of training(s)
+        :rtype:
+          - **dict** - if training_uid is not None
+          - **{"resources": [dict]}** - if training_uid is None
 
-        .. important::
-            **returns**: metadata of training(s)\n
-            **return type**: dict\n
-            The output can be {"resources": [dict]} or a dict\n
+        **Examples**
 
-        .. note::
-            If training_uid is not specified, all trainings metadata is fetched\n
+        .. code-block:: python
 
-        **Example**
-
-         >>> training_run_details = client.training.get_details(training_uid)
-         >>> training_runs_details = client.training.get_details()
-         >>> training_runs_details = client.training.get_details(limit=100)
-         >>> training_runs_details = client.training.get_details(limit=100, get_all=True)
-         >>> training_runs_details = []
-         >>> for entry in client.training.get_details(limit=100, asynchronous=True, get_all=True):
-         >>>    training_runs_details.extend(entry)
+            training_run_details = client.training.get_details(training_uid)
+            training_runs_details = client.training.get_details()
+            training_runs_details = client.training.get_details(limit=100)
+            training_runs_details = client.training.get_details(limit=100, get_all=True)
+            training_runs_details = []
+            for entry in client.training.get_details(limit=100, asynchronous=True, get_all=True):
+                training_runs_details.extend(entry)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -172,25 +156,20 @@ class Training(WMLResource):
 
     @staticmethod
     def get_href(training_details):
-        """
-            Get training_href from training details.
+        """Get training href from training details.
 
-            **Parameters**
+        :param training_details:  metadata of the training created
+        :type training_details: dict
 
-            .. important::
-                #. **training_details**:  Metadata of the training created\n
-                   **type**: dict\n
+        :return: training href
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: training href\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-
-             >>> training_details = client.training.get_details(training_uid)
-             >>> run_url = client.training.get_href(training_details)
+            training_details = client.training.get_details(training_uid)
+            run_url = client.training.get_href(training_details)
         """
 
         Training._validate_type(training_details, u'training_details', object, True)
@@ -204,9 +183,8 @@ class Training(WMLResource):
 
     @staticmethod
     def get_uid(training_details):
-        """
-            This method is deprecated, please use get_id() instead."
-        """
+        """This method is deprecated, please use ``get_id()`` instead."""
+
         warn("This method is deprecated, please use get_id()")
         print("This method is deprecated, please use get_id()")
 
@@ -219,25 +197,20 @@ class Training(WMLResource):
 
     @staticmethod
     def get_id(training_details):
-        """
-            Get training_id from training details.
+        """Get training id from training details.
 
-            **Parameters**
+        :param training_details: metadata of the training created
+        :type training_details: dict
 
-            .. important::
-                #. **training_details**:  Metadata of the training created\n
-                   **type**: dict\n
+        :return: Unique id of training
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: Unique id of training\n
-                **return type**: str
+        .. code-block:: python
 
-            **Example**
-
-             >>> training_details = client.training.get_details(training_id)
-             >>> training_id = client.training.get_id(training_details)
+            training_details = client.training.get_details(training_id)
+            training_id = client.training.get_id(training_details)
 
         """
 
@@ -246,160 +219,157 @@ class Training(WMLResource):
                                                            [u'metadata', u'id'])
 
     def run(self, meta_props, asynchronous=True):
-        """
-        Create a new Machine Learning training.
+        """Create a new Machine Learning training.
 
-        **Parameters**
+        :param meta_props:  metadata of the training configuration. To see available meta names use:
 
-        .. important::
+            .. code-block:: python
 
-            #. **meta_props**:  meta data of the training configuration. To see available meta names use:\n
-               >>> client.training.ConfigurationMetaNames.show()
+                client.training.ConfigurationMetaNames.show()
 
-               **type**: str\n
+        :type meta_props: str
+        :param asynchronous:
+            * `True` - training job is submitted and progress can be checked later
+            * `False` - method will wait till job completion and print training stats
+        :type asynchronous: bool, optional
 
-            #. **asynchronous**:\n
-               * True  - training job is submitted and progress can be checked later.\n
-               * False - method will wait till job completion and print training stats.\n
-               **type**: bool\n
+        :return: metadata of the training created
+        :rtype: dict
 
+        .. note::
 
-        **Output**
-
-        .. important::
-
-            **returns**: Metadata of the training created\n
-            **return type**: dict\n
+            You can provide one of the below values for training:
+             * client.training.ConfigurationMetaNames.EXPERIMENT
+             * client.training.ConfigurationMetaNames.PIPELINE
+             * client.training.ConfigurationMetaNames.MODEL_DEFINITION
 
         **Examples**
-         Example meta_props for Training run creation in IBM Cloud Pak® for Data version 3.0.1 or above:\n
-         >>> metadata = {
-         >>>  client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
-         >>>  client.training.ConfigurationMetaNames.DESCRIPTION: 'Hand-written Digit Recognition Training',
-         >>>  client.training.ConfigurationMetaNames.PIPELINE: {
-         >>>                "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
-         >>>                "rev": "12",
-         >>>                "model_type": "string",
-         >>>                "data_bindings": [
-         >>>                  {
-         >>>                    "data_reference_name": "string",
-         >>>                    "node_id": "string"
-         >>>                  }
-         >>>                ],
-         >>>                "nodes_parameters": [
-         >>>                  {
-         >>>                    "node_id": "string",
-         >>>                    "parameters": {}
-         >>>                  }
-         >>>                ],
-         >>>                "hardware_spec": {
-         >>>                  "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
-         >>>                  "rev": "12",
-         >>>                  "name": "string",
-         >>>                  "num_nodes": "2"
-         >>>                }
-         >>>      },
-         >>>  client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
-         >>>          'type': 's3',
-         >>>          'connection': {},
-         >>>          'location': {
-         >>>              'href': 'v2/assets/asset1233456',
-         >>>          }
-         >>>          "schema": "{ \"id\": \"t1\", \"name\": \"Tasks\", \"fields\": [ { \"name\": \"duration\", \"type\": \"number\" } ]}"
-         >>>      }],
-         >>> client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
-         >>>          'id' : 'string',
-         >>>          'connection': {
-         >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
-         >>>              'access_key_id': '***',
-         >>>              'secret_access_key': '***'
-         >>>          },
-         >>>          'location': {
-         >>>              'bucket': 'wml-dev-results',
-         >>>               'path' : "path"
-         >>>          }
-         >>>          'type': 's3'
-         >>>      }
-         >>>   }
 
-         NOTE:  You can provide either one of the below values can be provided for training:\n
-         * client.training.ConfigurationMetaNames.EXPERIMENT\n
-         * client.training.ConfigurationMetaNames.PIPELINE\n
-         * client.training.ConfigurationMetaNames.MODEL_DEFINITION\n
-         Example meta_prop values for  training run creation in other versions:
+        Example meta_props for Training run creation in IBM Cloud Pak® for Data version 3.0.1 or above:
 
-         >>> metadata = {
-         >>>  client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
-         >>>  client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
-         >>>          'connection': {
-         >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
-         >>>              'access_key_id': '***',
-         >>>              'secret_access_key': '***'
-         >>>          },
-         >>>          'source': {
-         >>>              'bucket': 'wml-dev',
-         >>>          }
-         >>>          'type': 's3'
-         >>>      }],
-         >>> client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
-         >>>          'connection': {
-         >>>              'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
-         >>>              'access_key_id': '***',
-         >>>              'secret_access_key': '***'
-         >>>          },
-         >>>          'target': {
-         >>>              'bucket': 'wml-dev-results',
-         >>>          }
-         >>>          'type': 's3'
-         >>>      },
-         >>> client.training.ConfigurationMetaNames.PIPELINE_UID : "/v4/pipelines/<PIPELINE-ID>"
-         >>> }
-         >>> training_details = client.training.run(definition_uid, meta_props=metadata)
-         >>> training_uid = client.training.get_id(training_details)
+        .. code-block:: python
 
-         Example of a Federated Learning training job
-         >>> aggregator_metadata = {
-         >>>       wml_client.training.ConfigurationMetaNames.NAME: 'Federated_Learning_Tensorflow_MNIST',
-         >>>       wml_client.training.ConfigurationMetaNames.DESCRIPTION: 'MNIST digit recognition with Federated Learning using Tensorflow',
-         >>>       wml_client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [],
-         >>>       wml_client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
-         >>>           'type': results_type,
-         >>>           'name': 'outputData',
-         >>>           'connection': {},
-         >>>           'location': {
-         >>>              'path': '/projects/' + PROJECT_ID + '/assets/trainings/'
-         >>>           }
-         >>> 
-         >>>       },
-         >>>       wml_client.training.ConfigurationMetaNames.FEDERATED_LEARNING: {
-         >>>           'model': {
-         >>>               'type': 'tensorflow',
-         >>>               'spec': {
-         >>>                  'id': untrained_model_id
-         >>>               },
-         >>>               'model_file': untrained_model_name
-         >>>           },
-         >>>           'fusion_type': 'iter_avg',
-         >>>           'metrics': 'accuracy',
-         >>>           'epochs': 3,
-         >>>           'rounds': 10,
-         >>>           'remote_training' : {
-         >>>               'quorum': 1.0,
-         >>>               'max_timeout': 3600,
-         >>>               'remote_training_systems': [ { 'id': prime_rts_id }, { 'id': nonprime_rts_id} ]
-         >>>           },
-         >>>           'hardware_spec': {
-         >>>               'name': 'S'
-         >>>           },
-         >>>           'software_spec': {
-         >>>               'name': 'runtime-22.1-py3.9'
-         >>>           }
-         >>>       }
-         >>>   }
-         >>>   
-         >>> 
-         >>> aggregator = wml_client.training.run(aggregator_metadata, asynchronous=True)
-         >>> aggregator_id = wml_client.training.get_id(aggregator)
+            metadata = {
+                client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
+                client.training.ConfigurationMetaNames.DESCRIPTION: 'Hand-written Digit Recognition Training',
+                client.training.ConfigurationMetaNames.PIPELINE: {
+                    "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
+                    "rev": "12",
+                    "model_type": "string",
+                    "data_bindings": [
+                        {
+                            "data_reference_name": "string",
+                            "node_id": "string"
+                        }
+                    ],
+                    "nodes_parameters": [
+                        {
+                            "node_id": "string",
+                            "parameters": {}
+                        }
+                    ],
+                    "hardware_spec": {
+                        "id": "4cedab6d-e8e4-4214-b81a-2ddb122db2ab",
+                        "rev": "12",
+                        "name": "string",
+                        "num_nodes": "2"
+                    }
+                },
+                client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
+                    'type': 's3',
+                    'connection': {},
+                    'location': {'href': 'v2/assets/asset1233456'},
+                    'schema': { 'id': 't1', 'name': 'Tasks', 'fields': [ { 'name': 'duration', 'type': 'number' } ]}
+                }],
+                client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
+                    'id' : 'string',
+                    'connection': {
+                        'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
+                        'access_key_id': '***',
+                        'secret_access_key': '***'
+                    },
+                    'location': {
+                        'bucket': 'wml-dev-results',
+                        'path' : "path"
+                    }
+                    'type': 's3'
+                }
+            }
+
+        Example meta_prop values for training run creation in other version:
+
+        .. code-block:: python
+
+            metadata = {
+                client.training.ConfigurationMetaNames.NAME: 'Hand-written Digit Recognition',
+                client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [{
+                    'connection': {
+                        'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
+                        'access_key_id': '***',
+                        'secret_access_key': '***'
+                    },
+                    'source': {
+                        'bucket': 'wml-dev',
+                    }
+                    'type': 's3'
+                }],
+                client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
+                    'connection': {
+                        'endpoint_url': 'https://s3-api.us-geo.objectstorage.service.networklayer.com',
+                        'access_key_id': '***',
+                        'secret_access_key': '***'
+                    },
+                    'target': {
+                        'bucket': 'wml-dev-results',
+                    }
+                    'type': 's3'
+                },
+                client.training.ConfigurationMetaNames.PIPELINE_UID : "/v4/pipelines/<PIPELINE-ID>"
+            }
+            training_details = client.training.run(definition_uid, meta_props=metadata)
+            training_uid = client.training.get_id(training_details)
+
+        Example of a Federated Learning training job:
+
+        .. code-block:: python
+
+            aggregator_metadata = {
+                wml_client.training.ConfigurationMetaNames.NAME: 'Federated_Learning_Tensorflow_MNIST',
+                wml_client.training.ConfigurationMetaNames.DESCRIPTION: 'MNIST digit recognition with Federated Learning using Tensorflow',
+                wml_client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES: [],
+                wml_client.training.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE: {
+                    'type': results_type,
+                    'name': 'outputData',
+                    'connection': {},
+                    'location': { 'path': '/projects/' + PROJECT_ID + '/assets/trainings/'}
+                },
+                wml_client.training.ConfigurationMetaNames.FEDERATED_LEARNING: {
+                    'model': {
+                        'type': 'tensorflow',
+                        'spec': {
+                        'id': untrained_model_id
+                    },
+                    'model_file': untrained_model_name
+                },
+                'fusion_type': 'iter_avg',
+                'metrics': 'accuracy',
+                'epochs': 3,
+                'rounds': 10,
+                'remote_training' : {
+                    'quorum': 1.0,
+                    'max_timeout': 3600,
+                    'remote_training_systems': [ { 'id': prime_rts_id }, { 'id': nonprime_rts_id} ]
+                },
+                'hardware_spec': {
+                    'name': 'S'
+                },
+                'software_spec': {
+                    'name': 'runtime-22.1-py3.9'
+                }
+            }
+
+            aggregator = wml_client.training.run(aggregator_metadata, asynchronous=True)
+            aggregator_id = wml_client.training.get_id(aggregator)
         """
 
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -574,33 +544,25 @@ class Training(WMLResource):
             return self.get_details(trained_model_guid, _internal=True)
 
     def list(self, limit=None, asynchronous=False, get_all=False):
-        """
-           List stored trainings. If limit is set to None there will be only first 50 records shown.
+        """Print stored trainings in a table format. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        :param limit: limit number of fetched records at once
+        :type limit: int, optional
+        :param asynchronous: if `True`, it will work as a generator
+        :type asynchronous: bool, optional
+        :param get_all: if `True`, it will get all entries in 'limited' chunks
+        :type get_all: bool, optional
 
-           .. important::
-                #. **limit**:  limit number of fetched records at once\n
-                   **type**: int\n
-                #. **asynchronous**:  if True, it will work as a generator (optional)\n
-                   **type**: bool\n
-                #. **get_all**:  if True, it will get all entries in 'limited' chunks (optional)\n
-                   **type**: bool\n
+        **Examples**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all trainings in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.training.list()
-            >>> training_runs_df = client.training.list(limit=100)
-            >>> training_runs_df = client.training.list(limit=100, get_all=True)
-            >>> training_runs_df = []
-            >>> for entry in client.training.list(limit=100, asynchronous=True, get_all=True):
-            >>>    training_runs_df.extend(entry)
+            client.training.list()
+            training_runs_df = client.training.list(limit=100)
+            training_runs_df = client.training.list(limit=100, get_all=True)
+            training_runs_df = []
+            for entry in client.training.list(limit=100, asynchronous=True, get_all=True):
+                training_runs_df.extend(entry)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -621,24 +583,16 @@ class Training(WMLResource):
             return preprocess_details(details)
 
     def list_subtrainings(self, training_uid):
-        """
-           List the sub-trainings.
+        """Print the sub-trainings in a table format.
 
-           **Parameters**
+        :param training_uid: training ID
+        :type training_uid: str
 
-           .. important::
-                #. **training_uid**:  Training ID\n
-                   **type**: str\n
+        **Example**
 
-           **Output**
+        .. code-block:: python
 
-           .. important::
-                This method only prints the list of all sub-trainings associated with a training in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.training.list_subtrainings()
+            client.training.list_subtrainings()
 
         """
         ##For CP4D, check if either spce or project ID is set
@@ -661,29 +615,20 @@ class Training(WMLResource):
         self._list(values, [u'ID (sub_training)', u'STATE', u'CREATED'], None, 50)
 
     def list_intermediate_models(self, training_uid):
-        """
-           List the intermediate_models.
+        """Print the intermediate_models in a table format.
 
-           **Parameters**
+        :param training_uid: training ID
+        :type training_uid: str
 
-           .. important::
-                #. **training_uid**:  Training ID\n
-                   **type**: str\n
+        .. note::
 
-           **Output**
+            This method is not supported for IBM Cloud Pak® for Data.
 
-           .. important::
-                This method only prints the list of all intermediate_models associated with an AUTOAI training in a table format.\n
-                **return type**: None\n
+        **Example**
 
-           .. note::
+        .. code-block:: python
 
-                This method prints the training logs.
-                This method is not supported for IBM Cloud Pak® for Data.
-
-           **Example**
-
-            >>> client.training.list_intermediate_models()
+            client.training.list_intermediate_models()
 
         """
         ##For CP4D, check if either spce or project ID is set
@@ -738,30 +683,25 @@ class Training(WMLResource):
             self._logger.debug("state is not completed")
 
     def cancel(self, training_uid, hard_delete=False):
-        """
-        Cancel a training which is currently running and remove it. This method is also be used to delete metadata
-        details of the completed or canceled training run when hard_delete parameter is set to True.
+        """Cancel a training which is currently running and remove it. This method is also be used to delete metadata
+        details of the completed or canceled training run when `hard_delete` parameter is set to `True`.
 
-        **Parameters**
+        :param training_uid: training UID
+        :type training_uid: str
+        :param hard_delete: specify `True` or `False`:
 
-        .. important::
-            #. **training_uid**:  Training UID\n
-               **type**: str\n
+            * `True` - to delete the completed or canceled training run
+            * `False` - to cancel the currently running training run
+        :type hard_delete: bool, optional
 
-            #. **hard_delete**: specify True or False.
-               True - To delete the completed or canceled training runs.
-               False - To cancel the currently running training run. Default value is False.
-               **type**: Boolean\n
-
-        **Output**
-
-        .. important::
-            **returns**: status ("SUCCESS" or "FAILED")\n
-            **return type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
         **Example**
 
-         >>> client.training.cancel(training_uid)
+        .. code-block:: python
+
+            client.training.cancel(training_uid)
         """
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
@@ -911,30 +851,20 @@ class Training(WMLResource):
                 print("ERROR - Cannot get the location of evaluation-metrics.txt details in the bucket")
 
     def monitor_logs(self, training_uid):
-        """
-            Monitor the logs of a training created.
+        """Print the logs of a training created.
 
-            **Parameters**
+        :param training_uid: training UID
+        :type training_uid: str
 
-            .. important::
-                #. **training_uid**:  Training UID\n
-                   **type**: str\n
+        .. note::
 
-            **Output**
+            This method is not supported for IBM Cloud Pak® for Data.
 
-            .. important::
+        **Example**
 
-                **returns**: None\n
-                **return type**: None\n
+        .. code-block:: python
 
-            .. note::
-
-                This method prints the training logs.
-                This method is not supported for IBM Cloud Pak® for Data.
-
-            **Example**
-
-             >>> client.training.monitor_logs(training_uid)
+            client.training.monitor_logs(training_uid)
 
         """
 
@@ -1002,30 +932,20 @@ class Training(WMLResource):
             websocket.close()
 
     def monitor_metrics(self, training_uid):
-        """
-            Monitor the metrics of a training created.
+        """Print the metrics of a training created.
 
-            **Parameters**
+        :param training_uid: training UID
+        :type training_uid: str
 
-            .. important::
-                #. **training_uid**:  Training UID\n
-                   **type**: str\n
+        .. note::
 
-            **Output**
+            This method is not supported for IBM Cloud Pak® for Data.
 
-            .. important::
+        **Example**
 
-                **returns**: None\n
-                **return type**: None\n
+        .. code-block:: python
 
-            .. note::
-
-                This method prints the training metrics.
-                This method is not supported for IBM Cloud Pak® for Data.
-
-            **Example**
-
-             >>> client.training.monitor_metrics(training_uid)
+            client.training.monitor_metrics(training_uid)
         """
         if self._client.ICP_30 or self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("Metrics monitoring is not supported for IBM Cloud Pak® for Data")
@@ -1088,24 +1008,19 @@ class Training(WMLResource):
             print_text_header_h2('Metric monitor done.')
 
     def get_metrics(self, training_uid):
-        """
-                Get metrics.
+        """Get metrics.
 
-                **Parameters**
+        :param training_uid: training UID
+        :type training_uid: str
 
-                .. important::
-                    #. **training_uid**:  training UID\n
-                       **type**: str\n
+        :return: metrics of a training run
+        :rtype: list of dict
 
-                **Output**
+        **Example**
 
-                .. important::
-                    **returns**: Metrics of a training run\n
-                    **return type**: list of dict\n
+        .. code-block:: python
 
-                **Example**
-
-                 >>> training_status = client.training.get_metrics(training_uid)
+            training_status = client.training.get_metrics(training_uid)
 
         """
         Training._validate_type(training_uid, u'training_uid', str, True)
@@ -1120,19 +1035,20 @@ class Training(WMLResource):
                 raise WMLClientError("No metrics details are available for the given training_uid")
 
     def _get_latest_metrics(self, training_uid):
+        """Get latest metrics values.
+
+        :param training_uid: ID of trained model
+        :type training_uid: str
+
+        :return: metric values
+        :rtype: list of dicts
+
+        **Example**
+
+        .. code-block:: python
+
+            client.training.get_latest_metrics(training_uid)
         """
-             Get latest metrics values.
-
-             :param training_uid: ID of trained model
-             :type training_uid: {0}
-
-             :returns: metric values
-             :rtype: list of dicts
-
-             A way you might use me is:
-
-             >>> client.training.get_latest_metrics(training_uid)
-         """
         Training._validate_type(training_uid, u'training_uid', str, True)
 
         status = self.get_status(training_uid)
