@@ -34,7 +34,9 @@ __all__ = [
     'VisualizationTypes',
     'SamplingTypes',
     'ImputationStrategy',
-    'ForecastingPipelineTypes'
+    'ForecastingPipelineTypes',
+    'TimeseriesAnomalyPredictionPipelineTypes',
+    'TimeseriesAnomalyPredictionAlgorithms'
 ]
 
 
@@ -176,37 +178,48 @@ class ForecastingPipelineTypes(Enum):
 
     @staticmethod
     def get_exogenous():
-        """
-        Get list of pipelines that use supporting features (exogenous pipelines).
+        """Get list of pipelines that use supporting features (exogenous pipelines).
 
-        Returns
-        -------
-        List of pipelines using supporting features.
+        :return: list of pipelines using supporting features
+        :rtype: list[ForecastingPipelineTypes]
         """
         return [pipeline for pipeline in ForecastingPipelineTypes if pipeline.value.startswith('Exogenous')]
 
     @staticmethod
     def get_non_exogenous():
-        """
-        Get list of pipelines not using supporting features (non-exogenous pipelines).
+        """Get list of pipelines not using supporting features (non-exogenous pipelines).
 
-        Returns
-        -------
-        List of pipelines that do not use supporting features.
+        :return: list of pipelines that do not use supporting features
+        :rtype: list[ForecastingPipelineTypes]
         """
         return [pipeline for pipeline in ForecastingPipelineTypes if not pipeline.value.startswith('Exogenous')]
 
 
+class TimeseriesAnomalyPredictionAlgorithms(Enum):
+    """Timeseries Anomaly Prediction algorithms that AutoAI could use for IBM Cloud."""
+    Forecasting = "Forecasting"
+    Window = "Window"
+    Relationship = "Relationship"
+
+
+class TimeseriesAnomalyPredictionPipelineTypes(Enum):
+    """Timeseries Anomaly Prediction pipeline types that AutoAI could use for IBM Cloud."""
+    PointwiseBoundedHoltWintersAdditive = 'PointwiseBoundedHoltWintersAdditive'
+    PointwiseBoundedBATS = 'PointwiseBoundedBATS'
+    PointwiseBoundedBATSForceUpdate = 'PointwiseBoundedBATSForceUpdate'
+    WindowNN = 'WindowNN'
+    WindowPCA = 'WindowPCA'
+    WindowLOF = 'WindowLOF'
+
+
 class PredictionType:
-    """
-        Supported types of learning.
-        OneOf: [BINARY, MULTICLASS, REGRESSION]
-    """
+    """Supported types of learning."""
     CLASSIFICATION = 'classification'
     BINARY = "binary"
     MULTICLASS = "multiclass"
     REGRESSION = "regression"
     FORECASTING = "forecasting"
+    TIMESERIES_ANOMALY_PREDICTION = "timeseries_anomaly_prediction"
 
 
 class PositiveLabelClass:
@@ -227,13 +240,11 @@ class PositiveLabelClass:
 
 
 class Metrics:
-    """
-        Supported types of classification and regression metrics in autoai.
-
-    """
+    """Supported types of classification and regression metrics in autoai."""
     ACCURACY_SCORE = "accuracy"
     ACCURACY_AND_DISPARATE_IMPACT_SCORE = "accuracy_and_disparate_impact"
     AVERAGE_PRECISION_SCORE = "average_precision"
+    BALANCED_ACCURACY = "balanced_accuracy"
     F1_SCORE = "f1"
     LOG_LOSS = "neg_log_loss"
     PRECISION_SCORE = "precision"
@@ -262,9 +273,7 @@ class Metrics:
 
 
 class Transformers:
-    """
-    Supported types of congito transformers names in autoai.
-    """
+    """Supported types of congito transformers names in autoai."""
     SQRT = "sqrt"
     LOG = "log"
     ROUND = "round"
@@ -292,10 +301,7 @@ class Transformers:
 
 
 class DataConnectionTypes:
-    """
-        Supported types of DataConnection.
-        OneOf: [s3, FS]
-    """
+    """Supported types of DataConnection."""
     S3 = "s3"
     FS = 'fs'
     DS = 'data_asset'
@@ -304,17 +310,13 @@ class DataConnectionTypes:
 
 
 class RunStateTypes:
-    """
-        Supported types of AutoAI fit/run.
-    """
+    """Supported types of AutoAI fit/run."""
     COMPLETED = "completed"
     FAILED = "failed"
 
 
 class PipelineTypes:
-    """
-        Supported types of Pipelines.
-    """
+    """Supported types of Pipelines."""
     LALE = "lale"
     SKLEARN = "sklearn"
 
@@ -326,14 +328,13 @@ class Directions:
 
 
 class TShirtSize:
-    """
-    Possible sizes of the AutoAI POD
+    """Possible sizes of the AutoAI POD.
     Depends on the POD size, AutoAI could support different data sets sizes.
 
-    S - small (2vCPUs and 8GB of RAM)
-    M - Medium (4vCPUs and 16GB of RAM)
-    L - Large (8vCPUs and 32GB of RAM))
-    XL - Extra Large (16vCPUs and 64GB of RAM)
+    - S - small (2vCPUs and 8GB of RAM)
+    - M - Medium (4vCPUs and 16GB of RAM)
+    - L - Large (8vCPUs and 32GB of RAM))
+    - XL - Extra Large (16vCPUs and 64GB of RAM)
     """
     S = 's'
     M = 'm'
