@@ -37,14 +37,18 @@ __all__ = [
     'AdditionalParameterIsUnexpected',
     'OBMForNFSIsNotSupported',
     'ForecastPredictionColumnsMissing',
+    'TimeseriesAnomalyPredictionFeatureColumnsMissing',
+    'TimeseriesAnomalyPredictionUnsupportedMetric',
     'NonForecastPredictionColumnMissing',
     'ForecastingCannotBeRunAsLocalScenario',
+    'TimeseriesAnomalyPredictionCannotBeRunAsLocalScenario',
     'ForecastingUnsupportedOperation',
     'OBMMainNodeAlreadySet',
     'InvalidSequenceValue',
     'NoAvailableMetrics',
     'WrongAssetType',
     'TSNotSupported',
+    'TSADNotSupported',
     'InvalidDataAsset',
     'ParamOutOfRange',
     'CannotConnectToWebsocket',
@@ -283,6 +287,17 @@ class ForecastPredictionColumnsMissing(WMLClientError):
                                 "For prediction_type = `forecasting` passing `prediction_columns` is required, while `prediction_column` should be None.")
 
 
+class TimeseriesAnomalyPredictionFeatureColumnsMissing(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self,
+                                "For prediction_type = `timeseries_anomaly_prediction` passing `feature_columns` is required, while `prediction_columns` and `prediction_column` should be None.")
+
+
+class TimeseriesAnomalyPredictionUnsupportedMetric(WMLClientError):
+    def __init__(self, metric):
+        WMLClientError.__init__(self, f"Metric {metric} is unsupported for timeseries anomaly prediction type.")
+
+
 class NonForecastPredictionColumnMissing(WMLClientError):
     def __init__(self, prediction_type):
         WMLClientError.__init__(self,
@@ -294,6 +309,11 @@ class ForecastingCannotBeRunAsLocalScenario(WMLClientError):
         WMLClientError.__init__(self, f"Forecasting cannot be run in local scenario.")
 
 
+class TimeseriesAnomalyPredictionCannotBeRunAsLocalScenario(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self, f"Timeseries anomaly prediction cannot be run in local scenario.")
+
+
 class ForecastingUnsupportedOperation(WMLClientError):
     def __init__(self):
         WMLClientError.__init__(self, f"Operation is unsupported for timeseries forecasting prediction type.")
@@ -326,6 +346,12 @@ class TSNotSupported(WMLClientError):
         WMLClientError.__init__(self, f"Time series forecasting is not supported for CPD 2.5, 3.0 and 3.5.")
 
 
+class TSADNotSupported(WMLClientError):
+    def __init__(self):
+        WMLClientError.__init__(self,
+                                f"Time series anomaly prediction is not supported for CPD 2.5, 3.0, 3.5, 4.0, 4.5 and 4.6.")
+
+
 class InvalidDataAsset(WMLClientError, ValueError):
     def __init__(self, reason='Wrong Data Asset'):
         WMLClientError.__init__(self, "Data Asset without 'connection' is not supported for result store action.",
