@@ -27,20 +27,17 @@ __all__ = [
 
 
 class ProgressBar(TQDM):
-    """
-    Progress Bar class for handling progress bar display. It is based on 'tqdm' class, could be extended.
-
-    Parameters
-    ----------
-    desc: str, optional
-        Description string to be added as a prefix to progress bar.
-
-    total: int, optional
-        Total length of the progress bar.
-    """
+    """Progress Bar class for handling progress bar display. It is based on 'tqdm' class, could be extended."""
 
     def __init__(self, ncols: Union[str, int], position: int = 0, desc: str = None, total: int = 100,
                  leave: bool = True, bar_format: str = '{desc}: {percentage:3.0f}%|{bar}|') -> None:
+        """
+        :param desc: description string to be added as a prefix to progress bar
+        :type desc: str, optional
+
+        :param total: total length of the progress bar
+        :type total: int, optional
+        """
         # note: to see possible progress bar formats please look at super 'bar_format' description
         super().__init__(desc=desc, total=total, leave=leave, position=position, ncols=ncols, file=sys.stdout,
                          bar_format=bar_format)
@@ -50,27 +47,20 @@ class ProgressBar(TQDM):
         self.progress = 0
 
     def increment_counter(self, progress: int = 5) -> None:
-        """
-        Increments internal counter and waits for specified time.
+        """Increment internal counter and waits for specified time.
 
-        Parameters
-        ----------
-        progress: int, optional
-            How many steps at a time progress bar will increment.
+        :param progress: number of steps at a time progress bar
+        :type progress: int, optional
         """
         self.progress = progress
         self.counter += progress
 
     def reset_counter(self) -> None:
-        """
-        Restart internal counter
-        """
+        """Restart internal counter."""
         self.counter = 0
 
     def update(self):
-        """
-        Updates the counter with specific progress.
-        """
+        """Update the counter with specific progress."""
         super().update(n=self.progress)
 
     def last_update(self):
