@@ -52,17 +52,13 @@ def get_project() -> Any:
 
 
 def get_wmls_credentials_and_space_ids(local_path: str) -> Tuple[List[Dict], List[str]]:
-    """
-    Parse project.json file and get WMLS credentials associated with WSD project.
+    """Parse project.json file and get WMLS credentials associated with WSD project.
 
-    Parameters
-    ----------
-    local_path: str, required
-        Path to project.json file with project configuration in WSD.
+    :param local_path: path to project.json file with project configuration in WSD
+    :type local_path: str
 
-    Returns
-    -------
-    Two lists with WMLS credentials and corresponding space_ids.
+    :return: two lists with WMLS credentials and corresponding space_ids
+    :rtype: tuple[list[dict], list[str]]
     """
     try:
         with open(local_path, 'r') as f:
