@@ -36,13 +36,11 @@ if TYPE_CHECKING:
 def save_metadata_for_ui(wml_pipeline_config: Dict, training_details: Dict) -> None:
     """Prepare AutoAI experiment metadata file for UI.
 
-    Parameters
-    ----------
-    wml_pipeline_config: dictionary, required
-        Dictionary with WML pipeline configuration.
+    :param wml_pipeline_config: dictionary with WML pipeline configuration
+    :type wml_pipeline_config: dict
 
-    training_details: dictionary, required
-        Dictionary with training details.
+    :param training_details: dictionary with training details
+    :type training_details: dict
     """
     experiment_id = training_details['entity']['results_reference']['location']['path'].split('/')[-2].split(
         'auto_ml.')[-1]
@@ -189,12 +187,11 @@ def save_metadata_for_ui(wml_pipeline_config: Dict, training_details: Dict) -> N
 def save_computed_pipelines_for_ui(wml_client: 'APIClient', run_id: str) -> None:
     """Download all AutoAI experiments files into the local storage for UI usage.
 
-    Parameters
-    ----------
-    wml_client: APIClient, required
+    :param wml_client: WML API Client
+    :type wml_client: APIClient
 
-    run_id: str, required
-        ID of the training.
+    :param run_id: ID of the training
+    :type run_id: str
     """
     print('Saving all computed pipelines locally for WSD...')
 
@@ -258,26 +255,20 @@ def save_experiment_for_ui(wml_pipeline_config: Dict,
                            asset_name: str) -> None:
     """Prepare AutoAI experiment configuration from wml pipeline config for WSD UI reuse.
 
-    Parameters
-    ----------
-    wml_pipeline_config: dictionary, required
-        Dictionary with WML pipeline configuration.
+    :param wml_pipeline_config: dictionary with WML pipeline configuration
+    :type wml_pipeline_config: dict
 
-    training_details: dictionary, required
-        Dictionary with training details.
+    :param training_details: dictionary with training details
+    :type training_details: dict
 
-    training_data_file_path: str, required
-        Local path to the training data asset.
+    :param training_data_file_path: local path to the training data asset
+    :type training_data_file_path: str
 
-    asset_id: str, required
-        ID of the data asset on WSD.
+    :param asset_id: ID of the data asset on WSD
+    :type asset_id: str
 
-    asset_name: str, required
-        Name of the data asset on WSD.
-
-    Returns
-    -------
-    Dictionary with AutoAI experiment configuration for WSD UI.
+    :param asset_name: name of the data asset on WSD
+    :type asset_name: str
     """
     print('Saving experiment metadata locally for WSD...')
 
@@ -313,7 +304,7 @@ def save_experiment_for_ui(wml_pipeline_config: Dict,
 
 
 def create_dir(path: str) -> None:
-    """Creates entire path of directories if missing."""
+    """Create entire path of directories if missing."""
     try:
         os.mkdir(path)
 
@@ -345,26 +336,23 @@ def prepare_config_auto_ml(wml_pipeline_config: Dict,
                            asset_name: str) -> Dict:
     """Prepare AutoAI experiment configuration from wml pipeline config for WSD UI reuse.
 
-    Parameters
-    ----------
-    wml_pipeline_config: dictionary, required
-        Dictionary with WML pipeline configuration.
+    :param wml_pipeline_config: dictionary with WML pipeline configuration
+    :type wml_pipeline_config: dict
 
-    training_details: dictionary, required
-        Dictionary with training details.
+    :param training_details: dictionary with training details
+    :type training_details: dict
 
-    training_data_file_path: str, required
-        Local path to the training data asset.
+    :param training_data_file_path: local path to the training data asset
+    :type training_data_file_path: str
 
-    asset_id: str, required
-        ID of the data asset on WSD.
+    :param asset_id: ID of the data asset on WSD
+    :type asset_id: str
 
-    asset_name: str, required
-        Name of the data asset on WSD.
+    :param asset_name: name of the data asset on WSD
+    :type asset_name: str
 
-    Returns
-    -------
-    Dictionary with AutoAI experiment configuration for WSD UI.
+    :return: dictionary with AutoAI experiment configuration for WSD UI
+    :rtype: dict
     """
     experiment_id = training_details['entity']['results_reference']['location']['path'].split('/')[-2].split(
         'auto_ml.')[-1]
@@ -444,17 +432,14 @@ def prepare_config_auto_ml(wml_pipeline_config: Dict,
 def prepare_reference_auto_ml(wml_pipeline_config: Dict, training_details: Dict) -> Dict:
     """Prepare AutoAI experiment configuration from wml pipeline config for WSD UI reuse.
 
-    Parameters
-    ----------
-    wml_pipeline_config: dictionary, required
-        Dictionary with WML pipeline configuration.
+    :param wml_pipeline_config: dictionary with WML pipeline configuration
+    :type wml_pipeline_config: dict
 
-    training_details: dictionary, required
-        Dictionary with training details.
+    :param training_details: dictionary with training details
+    :type training_details: dict
 
-    Returns
-    -------
-    Dictionary with AutoAI experiment configuration for WSD UI.
+    :return: dictionary with AutoAI experiment configuration for WSD UI
+    :rtype: dict
     """
 
     completed_at = training_details['entity']['status']['completed_at']
@@ -489,14 +474,12 @@ def prepare_reference_auto_ml(wml_pipeline_config: Dict, training_details: Dict)
 
 def extract_pipelines(training_details: Dict) -> Dict:
     """Extract information about computed pipelines from training details.
-    Parameters
-    ----------
-    training_details: dictionary, required
-        Dictionary with training details.
 
-    Returns
-    -------
-    Dictionary with AutoAI pipelines details.
+    :param training_details: dictionary with training details
+    :type training_details: dict
+
+    :return: dictionary with AutoAI pipelines details
+    :rtype: dict
     """
     pipelines = {}
     stages = training_details['entity']['status'].get('metrics', [])
@@ -519,17 +502,15 @@ def extract_pipelines(training_details: Dict) -> Dict:
 
 def extract_estimators(wml_pipeline_config: Dict, training_details: Dict) -> Dict:
     """Extract information about estimators from training details.
-    Parameters
-    ----------
-    wml_pipeline_config: dictionary, required
-        Dictionary with WML pipeline configuration.
 
-    training_details: dictionary, required
-        Dictionary with training details.
+    :param wml_pipeline_config: dictionary with WML pipeline configuration
+    :type wml_pipeline_config: dict
 
-    Returns
-    -------
-    Dictionary with estimators and scores.
+    :param training_details: dictionary with training details
+    :type training_details: dict
+
+    :return: dictionary with estimators and scores
+    :rtype: dict
     """
     estimators = {}
     parameters = wml_pipeline_config['entity']['document']['pipelines'][0]['nodes'][0]['parameters']
@@ -550,15 +531,13 @@ def extract_estimators(wml_pipeline_config: Dict, training_details: Dict) -> Dic
 
 
 def extract_message_log(training_details: Dict) -> List[Dict]:
-    """Creates message log for training.
-    Parameters
-    ----------
-    training_details: dictionary, required
-        Dictionary with training details.
+    """Create message log for training.
 
-    Returns
-    -------
-    List of dictionaries with messages.
+    :param training_details: dictionary with training details
+    :type training_details: dict
+
+    :return: list of dictionaries with messages
+    :rtype: list[dict]
     """
     steps = {'DAUB': 'feature_engineering',
              'hpo_d': 'model_optimization',
