@@ -396,11 +396,15 @@ def get_file_from_cos(cos_credentials):
 
 
 def extract_model_from_repository(model_uid, client):
-    """
-        Downloads and extracts archived model from wml repository.
-        :param model_uid:
-        :param client:
-        :return: extracted directory path
+    """Download and extract archived model from wml repository.
+
+    :param model_uid: UID of model
+    :type model_uid: str
+    :param client: client instance
+    :type client: APIClient
+
+    :return: extracted directory path
+    :rtype: str
     """
     create_empty_directory(model_uid)
     current_dir = os.getcwd()
@@ -423,11 +427,15 @@ def extract_model_from_repository(model_uid, client):
 
 
 def extract_mlmodel_from_archive(archive_path, model_uid):
-    """
-        Extracts archived model under model uid directory.
-        :param model_uid:
-        :param archive_path:
-        :return: extracted directory path
+    """Extract archived model under model uid directory.
+
+    :param model_uid: UID of model
+    :type model_uid: str
+    :param archive_path: path to archived model
+    :type archive_path: str
+
+    :return: extracted directory path
+    :rtype: str
     """
     create_empty_directory(model_uid)
     current_dir = os.getcwd()
@@ -541,19 +549,16 @@ def is_of_python_basic_type(el):
 
 
 class NextResourceGenerator:
-    """
-    Generator class to produce next list of resources from REST API.
-
-    Parameters
-    ----------
-    wml_client: APIClient, required
-        WML Client Instance
-
-    href: str, required
-        Href to the resource
-    """
+    """Generator class to produce next list of resources from REST API."""
 
     def __init__(self, wml_client: 'APIClient', url: str, href: str, params: dict = None, _all=False) -> None:
+        """
+        :param wml_client: WML Client Instance
+        :type wml_client: APIClient
+
+        :param href: href to the resource
+        :type href: str
+        """
         self.wml_client = wml_client
         self.url = url
         self.next_href = href
@@ -591,16 +596,18 @@ class NextResourceGenerator:
 
 
 class DisableWarningsLogger:
-    """
-       Class which disables logging warnings (for example for silent handling WMLClientErrors in try except).
+    """Class which disables logging warnings (for example for silent handling WMLClientErrors in try except).
+
+    **Example**
+
+    .. code-block:: python
 
-        Example:
-        ----------
         try:
             with DisableWarningsLogger():
                 throw_wml_error()
         except WMLClientError:
             success = False
+
     """
     def __enter__(self):
         logging.disable(logging.WARNING)
@@ -612,20 +619,17 @@ class DisableWarningsLogger:
 def is_lib_installed(lib_name: str, minimum_version: Optional[str] = None, install: Optional[bool] = False) -> bool:
     """Check if provided library is installed on user environment. If not, tries to install it.
 
-    Parameters
-    ----------
-    lib_name: str, required
-        Library name to check.
+    :param lib_name: library name to check
+    :type lib_name: str
 
-    minimum_version: str, optional
-        Minimum version of library to check. Default None, we can check if library is installed in overall.
+    :param minimum_version: minimum version of library to check, default: None - check if library is installed in overall
+    :type minimum_version: str, optional
 
-    install: bool, optional
-        Indicates to install missing or to low version library.
+    :param install: indicates to install missing or to low version library
+    :type install: bool, optional
 
-    Returns
-    -------
-    Bool (true is library is installed, False otherwise)
+    :return: information if library is installed: `True` is library is installed, `False` otherwise
+    :rtype: bool
     """
     if lib_name in sys.modules:
         installed = True
@@ -655,16 +659,14 @@ def is_lib_installed(lib_name: str, minimum_version: Optional[str] = None, insta
 def install_library(lib_name: str, version: Optional[str] = None, strict: Optional[bool] = False) -> None:
     """Try to install library.
 
-    Parameters
-    ----------
-    lib_name: str, required
-        Library name to install.
+    :param lib_name: library name to install
+    :type lib_name: str
 
-    version: str, optional
-        Version of the library to install.
+    :param version: version of the library to install
+    :type version: str, optional
 
-    strict: bool, optional
-        Indicates if we want to install specific version or higher version if available. Default False.
+    :param strict: indicates if we want to install specific version or higher version if available
+    :type strict: bool, optional
     """
     try:
         if version is not None:
@@ -690,17 +692,14 @@ def prepare_interaction_props_for_cos(source_params: dict, file_name: str) -> di
     """If user specified properties for dataset as sheet_name, delimiter etc. we need to
     pass them as interaction properties for Flight Service.
 
-    Parameters
-    ----------
-    source_params: dictionary, required
-        Data source parameters describe data (eg. excel_sheet, encoding etc.)
+    :param source_params: data source parameters describe data (eg. excel_sheet, encoding etc.)
+    :type source_params: dict
 
-    file_name: str, required
-        Name of the file to download, should consist of file extension.
+    :param file_name: name of the file to download, should consist of file extension
+    :type file_name: str
 
-    Returns
-    -------
-    Dictionary with COS interaction properties for Flight Serivce.
+    :return: COS interaction properties for Flight Service
+    :rtype: dict
     """
     interaction_properties = {}
     file_format = None
@@ -735,16 +734,14 @@ def prepare_interaction_props_for_cos(source_params: dict, file_name: str) -> di
 
 
 def modify_details_for_script_and_shiny(details_from_get: dict) -> dict:
-    """
-    Add the href and id of and asset to the same position as it is returned from the POST method
+    """Add the href and id of and asset to the same position as it is returned from the POST method
     it allows the `get_id`/`get_href` method to work with details returned by GET method.
-    Parameters
-    ---
-    details_from_get: dict, required
-        Details of script/shiny app acquired using GET method.
-    Returns
-    ---
-    Dictionary with 'guid' and 'href' key added to 'metadata'.
+
+    :param details_from_get: details of script/shiny app acquired using GET method
+    :type details_from_get: dict
+
+    :return: details with 'guid' and 'href' key added to 'metadata'
+    :rtype: dict
     """
     try:
         details_from_get[u'metadata'][u'href'] = details_from_get[u'href']
