@@ -24,42 +24,35 @@ _DEFAULT_LIST_LENGTH = 50
 
 
 class Volume(WMLResource):
-    """
-    Store and manage your scripts assets.
+    """Store and manage volume assets."""
 
-    """
     ConfigurationMetaNames = VolumeMetaNames()
-    """MetaNames for script Assets creation."""
+    """MetaNames for volume assets creation."""
 
     def __init__(self, client):
         WMLResource.__init__(self, __name__, client)
         self._ICP = client.ICP
 
     def get_details(self, volume_id):
-        """
-            Get Volume  details.
+        """Get volume details.
 
-            **Parameters**
+        :param volume_id: Unique ID of the volume
+        :type volume_id: str
 
-            .. important::
-                #. **volume_id**: Unique ID of the volume.\n
-                   **type**: str\n
+        :return: metadata of the volume details
+        :rtype: dict
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: Metadata of the volume details \n
-                **return type**: dict\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> volume_details = client.volumes.get_details(volume_id)
+            volume_details = client.volumes.get_details(volume_id)
 
         """
         Volume._validate_type(volume_id, u'volume_id', str, True)
 
         params = {'addon_type': 'volumes',
-                  'include_service_status':True
+                  'include_service_status': True
                   }
 
         response = requests.get(self._client.service_instance._href_definitions.volume_href(volume_id),
@@ -72,43 +65,40 @@ class Volume(WMLResource):
             raise WMLClientError("Failed to Get the volume details. Try again.")
 
     def create(self, meta_props):
-        """
-                Creates a Volume asset.
+        """Create a volume asset.
 
-                **Parameters**
+        :param meta_props: metadata of the volume asset
+        :type meta_props: dict
 
-                .. important::
-                   #. **meta_props**:  Name to be given to the Volume asset\n
+        :return: metadata of the created volume details
+        :rtype: dict
 
-                      **type**: dict\n
+        **Examples**
 
-                **Output**
+        Provision new PVC volume:
 
-                .. important::
+        .. code-block:: python
 
-                    **returns**: metadata of the created volume details\n
-                    **return type**: dict\n
+            metadata = {
+                client.volumes.ConfigurationMetaNamess.NAME: 'volume-for-wml-test',
+                client.volumes.ConfigurationMetaNames.NAMESPACE: 'wmldev2',
+                client.volumes.ConfigurationMetaNames.STORAGE_CLASS: 'nfs-client'
+                client.volumes.ConfigurationMetaNames.STORAGE_SIZE: "2G"
+            }
 
-                **Example**
-                Provision new PVC volume :
-                 >>> metadata = {
-                 >>>        client.volumes.ConfigurationMetaNamess.NAME: 'volume-for-wml-test',
-                 >>>        client.volumes.ConfigurationMetaNames.NAMESPACE: 'wmldev2',
-                 >>>        client.volumes.ConfigurationMetaNames.STORAGE_CLASS: 'nfs-client'
-                 >>>        client.volumes.ConfigurationMetaNames.STORAGE_SIZE: "2G"
-                 >>>    }
-                 >>>
-                 >>> asset_details = client.scripts.store(meta_props=metadata)
+            asset_details = client.scripts.store(meta_props=metadata)
 
-               Provision a Existing PVC volume:
+        Provision an existing PVC volume:
 
-                 >>> metadata = {
-                 >>>        client.volumes.ConfigurationMetaNamess.NAME: 'volume-for-wml-test',
-                 >>>        client.volumes.ConfigurationMetaNames.NAMESPACE: 'wmldev2',
-                 >>>        client.volumes.ConfigurationMetaNames.EXISTING_PVC_NAME: 'volume-for-wml-test'
-                 >>>    }
-                 >>>
-                 >>> asset_details = client.scripts.store(meta_props=metadata)
+        .. code-block:: python
+
+            metadata = {
+                client.volumes.ConfigurationMetaNamess.NAME: 'volume-for-wml-test',
+                client.volumes.ConfigurationMetaNames.NAMESPACE: 'wmldev2',
+                client.volumes.ConfigurationMetaNames.EXISTING_PVC_NAME: 'volume-for-wml-test'
+            }
+
+            asset_details = client.scripts.store(meta_props=metadata)
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -189,27 +179,20 @@ class Volume(WMLResource):
             print("Exception: ", {e})
             raise WMLClientError("Failed to create a volume. Try again.")
 
-
-
     def start(self, name):
-        """
-            Start the  volume service.
+        """Start the volume service.
 
-            **Parameters**
+        :param name: unique name of the volume to be started
+        :type name: str
 
-            .. important::
-                #. **volume_name**:  Unique name of the volume to be started
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-                >>> client.volumes.start(volume_name)
+            client.volumes.start(volume_name)
 
         """
 
@@ -242,28 +225,21 @@ class Volume(WMLResource):
             raise WMLClientError("Failed to start the file to  volume. Try again.")
 
     def upload_file(self, name,  file_path):
-        """
-            Upload the data file into stored volume.
+        """Upload the data file into stored volume.
 
-            **Parameters**
+        :param name: unique name of the stored volume
+        :type name: str
+        :param file_path: file to be uploaded into the volume
+        :type file_path: str
 
-                .. important::
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-                #. **name**:  Unique name of the stored volume \n
-                   **type**: str\n
+        **Example**
 
-                #. **file_path**:  File to be uploaded into the volume \n
-                   **type**: str\n
+        .. code-block:: python
 
-            **Output**
-                .. important::
-
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
-
-                **Example**
-
-                    >>> client.volumes.upload_file('testA', 'DRUG.csv')
+            client.volumes.upload_file('testA', 'DRUG.csv')
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -296,24 +272,13 @@ class Volume(WMLResource):
             return "FAILED"
 
     def list(self):
-        """
-           List stored volumes. If limit is set to None there will be only first 50 records shown.
+        """Print stored volumes in a table format. If limit is set to None there will be only first 50 records shown.
 
-           **Parameters**
+        **Example**
 
-           .. important::
-                #. **limit**:  limit number of fetched records\n
-                   **type**: int\n
+        .. code-block:: python
 
-           **Output**
-
-           .. important::
-                This method only prints the list of all script in a table format.\n
-                **return type**: None\n
-
-           **Example**
-
-            >>> client.volumes.list()
+            client.volumes.list()
         """
 
         href = self._client.service_instance._href_definitions.volumes_href()
@@ -333,26 +298,19 @@ class Volume(WMLResource):
 
     @staticmethod
     def get_id(volume_details):
-        """
-                Get Unique Id of stored volume details.
+        """Get unique Id of stored volume details.
 
-                **Parameters**
+        :param volume_details: metadata of the stored volume details
+        :type volume_details: dict
 
-                .. important::
+        :return: unique Id of stored volume asset
+        :rtype: str
 
-                   #. **asset_details**:  Metadata of the stored volume details\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique Id of stored volume asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                     >>> volume_uid = client.volumes.get_id(volume_details)
+            volume_uid = client.volumes.get_id(volume_details)
 
         """
 
@@ -367,26 +325,19 @@ class Volume(WMLResource):
 
     @staticmethod
     def get_name(volume_details):
-        """
-                Get Unique name  of stored volume asset.
+        """Get unique name of stored volume asset.
 
-                **Parameters**
+        :params volume_details: metadata of the stored volume asset
+        :type volume_details: dict
 
-                .. important::
+        :return: unique name of stored volume asset
+        :rtype: str
 
-                   #. **volume_details**:  Metadata of the stored volume asset\n
-                      **type**: dict\n
+        **Example**
 
-                **Output**
+        .. code-block:: python
 
-                .. important::
-
-                    **returns**: Unique name of stored volume asset\n
-                    **return type**: str\n
-
-                **Example**
-
-                 >>> volume_name = client.volumes.get_name(asset_details)
+            volume_name = client.volumes.get_name(asset_details)
 
         """
         Volume._validate_type(volume_details, u'asset_details', object, True)
@@ -399,24 +350,19 @@ class Volume(WMLResource):
                                                            [u'display_name'])
 
     def delete(self, volume_id):
-        """
-            Delete a volume.
+        """Delete a volume.
 
-            **Parameters**
+        :param volume_id: unique ID of the volume
+        :type volume_id: str
 
-            .. important::
-                #. **volume_id**:  Unique ID of the volume.\n
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.volumes.delete(volume_id)
+            client.volumes.delete(volume_id)
 
         """
         Volume._validate_type(volume_id, u'asset_uid', str, True)
@@ -435,24 +381,19 @@ class Volume(WMLResource):
             return "FAILED"
 
     def stop(self, volume_name):
-        """
-            Stop the  volume service.
+        """Stop the volume service.
 
-            **Parameters**
+        :param volume_name: unique name of the volume
+        :type volume_name: str
 
-            .. important::
-                #. **volume_name**:  Unique name of the volume
-                   **type**: str\n
+        :return: status ("SUCCESS" or "FAILED")
+        :rtype: str
 
-            **Output**
+        **Example**
 
-            .. important::
-                **returns**: status ("SUCCESS" or "FAILED")\n
-                **return type**: str\n
+        .. code-block:: python
 
-            **Example**
-
-             >>> client.volumes.stop(volume_name)
+            client.volumes.stop(volume_name)
 
         """
         Volume._validate_type(volume_name, u'asset_uid', str, True)
