@@ -22,39 +22,38 @@ from ..utils.autoai.utils import is_ipython
 
 
 class WorkSpace:
-    """
-    WorkSpace class for WML authentication and project/space manipulation.
-
-    Parameters
-    ----------
-    wml_credentials: dictionary, required
-        Credentials to Watson Machine Learning instance.
-
-    project_id: str, optional
-        ID of the Watson Studio project.
-
-    space_id: str, optional
-        ID of the Watson Studio Space.
-
-    Example
-    -------
-    >>> from ibm_watson_machine_learning.workspace import WorkSpace
-    >>>
-    >>> ws = WorkSpace(
-    >>>        wml_credentials={
-    >>>              "apikey": "...",
-    >>>              "iam_apikey_description": "...",
-    >>>              "iam_apikey_name": "...",
-    >>>              "iam_role_crn": "...",
-    >>>              "iam_serviceid_crn": "...",
-    >>>              "instance_id": "...",
-    >>>              "url": "https://us-south.ml.cloud.ibm.com"
-    >>>            },
-    >>>         project_id="...",
-    >>>         space_id="...")
-    """
+    """WorkSpace class for WML authentication and project/space manipulation."""
 
     def __init__(self, wml_credentials: dict, project_id: str = None, space_id: str = None, verify=None) -> None:
+        """
+        :param wml_credentials: credentials to Watson Machine Learning instance
+        :type wml_credentials: dict
+
+        :param project_id: ID of the Watson Studio project
+        :type project_id: str, optional
+
+        :param space_id: ID of the Watson Studio Space
+        :type space_id: str, optional
+
+        **Example**
+
+        .. code-block: python
+
+            from ibm_watson_machine_learning.workspace import WorkSpace
+
+            ws = WorkSpace(
+                wml_credentials={
+                    "apikey": "...",
+                    "iam_apikey_description": "...",
+                    "iam_apikey_name": "...",
+                    "iam_role_crn": "...",
+                    "iam_serviceid_crn": "...",
+                    "instance_id": "...",
+                    "url": "https://us-south.ml.cloud.ibm.com"
+                },
+                project_id="...",
+                space_id="...")
+        """
         self.wml_credentials = wml_credentials.copy()
         self.project_id = project_id
         self.space_id = space_id
@@ -132,16 +131,13 @@ class WorkSpace:
         return self.__str__()
 
     def restrict_pod_size(self, t_shirt_size: 'TShirtSize') -> 'TShirtSize':
-        """
-        Check t_shirt_size for AutoAI POD. Restrict sizes per environment.
+        """Check t_shirt_size for AutoAI POD. Restrict sizes per environment.
 
-        Parameters
-        ----------
-        t_shirt_size: TShirtSize, required
+        :param t_shirt_size: TShirt size to be validated and restricted
+        :type t_shirt_size: TShirtSize
 
-        Returns
-        -------
-        TShirtSize
+        :return: validated and restricted TShirt size
+        :rtype: TShirtSize
         """
         # note: for testing purposes
         if self.wml_credentials.get('development', False):
